@@ -151,7 +151,7 @@ void BasicIDEShell::ExecuteCurrent( SfxRequest& rReq )
                 {
                     // memorize item because of the adjustments...
                     BasicIDEGlobals::GetExtraData()->SetSearchItem( (const SvxSearchItem&)rItem );
-                    sal_uInt16 nFound = 0;
+                    sal_Int32 nFound = 0;
                     sal_Bool bCanceled = sal_False;
                     if ( ((const SvxSearchItem&)rItem).GetCommand() == SVX_SEARCHCMD_REPLACE_ALL )
                     {
@@ -443,26 +443,11 @@ void BasicIDEShell::ExecuteGlobal( SfxRequest& rReq )
             pWin->EditMacro( rInfo.GetMethod() );
         }
         break;
+
         case SID_BASICIDE_OBJCAT:
-        {
-            if ( bObjectCatalogDisplay )
-            {
-                pModulLayout->GetObjectCatalog().Hide();
-                dynamic_cast<ModulWindow*>(pCurWin)->SetPosPixel( Point( 0, 0 ) );
-                dynamic_cast<ModulWindow*>(pCurWin)->SetSizePixel( Size( pCurWin->GetSizePixel().Width() + OBJCAT_PANE_WIDTH, pCurWin->GetSizePixel().Height() ) );
-                dynamic_cast<ModulWindow*>(pCurWin)->SetObjectCatalogDisplay( false );
-                bObjectCatalogDisplay = sal_False;
-            }
-            else
-            {
-                pModulLayout->GetObjectCatalog().Show();
-                dynamic_cast<ModulWindow*>(pCurWin)->SetPosPixel( Point( OBJCAT_PANE_WIDTH, 0 ) );
-                dynamic_cast<ModulWindow*>(pCurWin)->SetSizePixel( Size( pCurWin->GetSizePixel().Width() - OBJCAT_PANE_WIDTH, pCurWin->GetSizePixel().Height() ) );
-                dynamic_cast<ModulWindow*>(pCurWin)->SetObjectCatalogDisplay( true );
-                bObjectCatalogDisplay = sal_True;
-            }
-        }
-        break;
+            pModulLayout->ToggleObjectCatalog();
+            break;
+
         case SID_BASICIDE_NAMECHANGEDONTAB:
         {
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
@@ -1224,6 +1209,7 @@ void BasicIDEShell::SetCurWindow( IDEBaseWindow* pNewWin, sal_Bool bUpdateTabBar
             GetViewFrame()->GetWindow().SetHelpId( HID_BASICIDE_MODULWINDOW );
             SfxObjectShell::SetCurrentComponent( NULL );
         }
+        pModulLayout->GetObjectCatalog().SetCurrentEntry(pCurWin);
         SetUndoManager( pCurWin ? pCurWin->GetUndoManager() : 0 );
         InvalidateBasicIDESlots();
         EnableScrollbars( pCurWin ? sal_True : sal_False );
