@@ -161,7 +161,7 @@ Reference< document::XFilter > ChartModel::impl_createFilter(
         lcl_getProperty< OUString >( rMediaDescriptor, OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterName" ))));
 
     // if FilterName was found, get Filter from factory
-    if( aFilterName.getLength() > 0 )
+    if( !aFilterName.isEmpty() )
     {
         try
         {
@@ -178,7 +178,7 @@ Reference< document::XFilter > ChartModel::impl_createFilter(
                 OUString aFilterServiceName(
                     lcl_getProperty< OUString >( aProps, OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterService" ))));
 
-                if( aFilterServiceName.getLength())
+                if( !aFilterServiceName.isEmpty())
                 {
                     xFilter.set(
                         m_xContext->getServiceManager()->createInstanceWithContext(
@@ -230,7 +230,7 @@ sal_Bool SAL_CALL ChartModel::hasLocation()
     throw(uno::RuntimeException)
 {
     //@todo guard
-    return m_aResource.getLength()!=0;
+    return !m_aResource.isEmpty();
 }
 
 ::rtl::OUString SAL_CALL ChartModel::getLocation()
@@ -256,9 +256,9 @@ void SAL_CALL ChartModel::store()
 
     ::rtl::OUString aLocation = m_aResource;
 
-    if( aLocation.getLength() == 0 )
+    if( aLocation.isEmpty() )
         throw io::IOException( C2U( "no location specified" ), static_cast< ::cppu::OWeakObject* >(this));
-    //@todo check wether aLocation is something like private:factory...
+    //@todo check whether aLocation is something like private:factory...
     if( m_bReadOnly )
         throw io::IOException( C2U( "document is read only" ), static_cast< ::cppu::OWeakObject* >(this));
 
@@ -312,7 +312,7 @@ void SAL_CALL ChartModel::storeToURL(
     uno::Sequence< beans::PropertyValue > aReducedMediaDescriptor(
         aMediaDescriptorHelper.getReducedForModel() );
 
-    if( rURL.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("private:stream")))
+    if ( rURL == "private:stream" )
     {
         try
         {
