@@ -38,7 +38,6 @@
 #include "CommonConverters.hxx"
 #include "ExplicitCategoriesProvider.hxx"
 #include "servicenames_charttypes.hxx"
-#include "ChartModelHelper.hxx"
 #include "RelativePositionHelper.hxx"
 #include "ControllerLockGuard.hxx"
 #include "NumberFormatterWrapper.hxx"
@@ -95,7 +94,7 @@ DiagramHelper::tTemplateWithServiceName
     Sequence< OUString > aServiceNames( xChartTypeManager->getAvailableServiceNames());
     const sal_Int32 nLength = aServiceNames.getLength();
 
-    bool bHasPreferredTemplate = (rPreferredTemplateName.getLength() > 0);
+    bool bHasPreferredTemplate = !rPreferredTemplateName.isEmpty();
     bool bTemplateFound = false;
 
     if( bHasPreferredTemplate )
@@ -1711,7 +1710,7 @@ bool DiagramHelper::switchDiagramPositioningToExcludingPositioning(
 {
     //return true if something was changed
     const SvtSaveOptions::ODFDefaultVersion nCurrentODFVersion( SvtSaveOptions().GetODFDefaultVersion() );
-    if( nCurrentODFVersion == SvtSaveOptions::ODFVER_LATEST )//#i100778# todo: change this dependent on fileformat evolution
+    if( nCurrentODFVersion > SvtSaveOptions::ODFVER_012 )
     {
         uno::Reference< ::com::sun::star::chart::XChartDocument > xOldDoc( xChartModel, uno::UNO_QUERY ) ;
         if( xOldDoc.is() )
