@@ -205,7 +205,7 @@ Service::createInstanceWithArguments(
         } else if (Arguments.getLength() == 1 && (Arguments[i] >>= nodepath)) {
             // For backwards compatibility, allow a single string argument that
             // denotes nodepath.
-            if (nodepath.getLength() == 0) {
+            if (nodepath.isEmpty()) {
                 badNodePath();
             }
             break;
@@ -222,16 +222,16 @@ Service::createInstanceWithArguments(
         if (name.equalsIgnoreAsciiCaseAsciiL(
                 RTL_CONSTASCII_STRINGPARAM("nodepath")))
         {
-            if (nodepath.getLength() != 0 || !(value >>= nodepath) ||
-                nodepath.getLength() == 0)
+            if (!nodepath.isEmpty() || !(value >>= nodepath) ||
+                nodepath.isEmpty())
             {
                 badNodePath();
             }
         } else if (name.equalsIgnoreAsciiCaseAsciiL(
                        RTL_CONSTASCII_STRINGPARAM("locale")))
         {
-            if (locale.getLength() != 0 || !(value >>= locale) ||
-                locale.getLength() == 0)
+            if (!locale.isEmpty() || !(value >>= locale) ||
+                locale.isEmpty())
             {
                 throw css::uno::Exception(
                     rtl::OUString(
@@ -243,7 +243,7 @@ Service::createInstanceWithArguments(
             }
         }
     }
-    if (nodepath.getLength() == 0) {
+    if (nodepath.isEmpty()) {
         badNodePath();
     }
     // For backwards compatibility, allow a nodepath that misses the leading
@@ -251,20 +251,18 @@ Service::createInstanceWithArguments(
     if (nodepath[0] != '/') {
         nodepath = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/")) + nodepath;
     }
-    if (locale.getLength() == 0) {
+    if (locale.isEmpty()) {
         //TODO: should the Access use the dynamically changing locale_ instead?
         locale = locale_;
-        if (locale.getLength() == 0) {
+        if (locale.isEmpty()) {
             locale = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("en-US"));
         }
     }
     bool update;
-    if (ServiceSpecifier.equalsAsciiL(
-            RTL_CONSTASCII_STRINGPARAM(accessServiceName)))
+    if ( ServiceSpecifier == accessServiceName )
     {
         update = false;
-    } else if (ServiceSpecifier.equalsAsciiL(
-                   RTL_CONSTASCII_STRINGPARAM(updateAccessServiceName)))
+    } else if ( ServiceSpecifier == updateAccessServiceName )
     {
         update = true;
     } else {
@@ -365,9 +363,9 @@ void Service::setLocale(css::lang::Locale const & eLocale)
 css::lang::Locale Service::getLocale() throw (css::uno::RuntimeException) {
     osl::MutexGuard guard(*lock_);
     css::lang::Locale loc;
-    if (locale_.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("*"))) {
+    if ( locale_ == "*" ) {
         loc.Language = locale_;
-    } else if (locale_.getLength() != 0) {
+    } else if (! locale_.isEmpty()) {
         try {
             comphelper::Locale l(locale_);
             loc.Language = l.getLanguage();
@@ -487,8 +485,8 @@ Factory::createInstanceWithArgumentsAndContext(
             if (name.equalsIgnoreAsciiCaseAsciiL(
                     RTL_CONSTASCII_STRINGPARAM("locale")))
             {
-                if (locale.getLength() != 0 || !(value >>= locale) ||
-                    locale.getLength() == 0)
+                if (!locale.isEmpty() || !(value >>= locale) ||
+                    locale.isEmpty())
                 {
                     throw css::uno::Exception(
                         rtl::OUString(
@@ -537,8 +535,10 @@ css::uno::Sequence< rtl::OUString > getSupportedServiceNames() {
 
 css::uno::Reference< css::lang::XSingleComponentFactory >
 createFactory(
-    cppu::ComponentFactoryFunc, rtl::OUString const &,
-    css::uno::Sequence< rtl::OUString > const &, rtl_ModuleCount *)
+    SAL_UNUSED_PARAMETER cppu::ComponentFactoryFunc,
+    SAL_UNUSED_PARAMETER rtl::OUString const &,
+    SAL_UNUSED_PARAMETER css::uno::Sequence< rtl::OUString > const &,
+    SAL_UNUSED_PARAMETER rtl_ModuleCount *)
     SAL_THROW(())
 {
     return new Factory;
