@@ -27,8 +27,6 @@
  ************************************************************************/
 
 
-#include <sal/macros.h>
-
 #include "dsntypes.hxx"
 #include "dbamiscres.hrc"
 #include <unotools/confignode.hxx>
@@ -40,6 +38,7 @@
 #include "core_resource.hxx"
 #include "core_resource.hrc"
 #include <comphelper/documentconstants.hxx>
+#include <comphelper/string.hxx>
 
 //.........................................................................
 namespace dbaccess
@@ -55,7 +54,7 @@ namespace dbaccess
     {
         void lcl_extractHostAndPort(const String& _sUrl,String& _sHostname,sal_Int32& _nPortNumber)
         {
-            if ( _sUrl.GetTokenCount(':') >= 2 )
+            if ( comphelper::string::getTokenCount(_sUrl, ':') >= 2 )
             {
                 _sHostname      = _sUrl.GetToken(0,':');
                 _nPortNumber    = _sUrl.GetToken(1,':').ToInt32();
@@ -172,7 +171,7 @@ bool ODsnTypeCollection::isConnectionUrlRequired(const ::rtl::OUString& _sURL) c
             sOldPattern = *aIter;
         }
     }
-    return sRet.GetChar(sRet.Len()-1) == '*';
+    return sRet.Len() > 0 && sRet.GetChar(sRet.Len()-1) == '*';
 }
 // -----------------------------------------------------------------------------
 String ODsnTypeCollection::getMediaType(const ::rtl::OUString& _sURL) const
@@ -198,7 +197,7 @@ String ODsnTypeCollection::getDatasourcePrefixFromMediaType(const ::rtl::OUStrin
                 sURL = *pIter;
                 break;
             }
-            if ( !sFileExtension.getLength() && _sExtension.getLength() )
+            if ( sFileExtension.isEmpty() && !_sExtension.isEmpty() )
                 sFallbackURL = *pIter;
         }
     }
@@ -229,32 +228,26 @@ void ODsnTypeCollection::extractHostNamePort(const ::rtl::OUString& _rDsn,String
     if ( _rDsn.matchIgnoreAsciiCaseAsciiL("jdbc:oracle:thin:",sizeof("jdbc:oracle:thin:")-1) )
     {
         lcl_extractHostAndPort(sUrl,_rsHostname,_nPortNumber);
-        if ( !_rsHostname.Len() && sUrl.GetTokenCount(':') == 2 )
+        if ( !_rsHostname.Len() && comphelper::string::getTokenCount(sUrl, ':') == 2 )
         {
             _nPortNumber = -1;
             _rsHostname = sUrl.GetToken(0,':');
         }
         if ( _rsHostname.Len() )
-            _rsHostname = _rsHostname.GetToken(_rsHostname.GetTokenCount('@') - 1,'@');
-        _sDatabaseName = sUrl.GetToken(sUrl.GetTokenCount(':') - 1,':');
+            _rsHostname = _rsHostname.GetToken(comphelper::string::getTokenCount(_rsHostname, '@') - 1, '@');
+        _sDatabaseName = sUrl.GetToken(comphelper::string::getTokenCount(sUrl, ':') - 1, ':');
     }
     else if ( _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:address:ldap:",sizeof("sdbc:address:ldap:")-1) )
     {
         lcl_extractHostAndPort(sUrl,_sDatabaseName,_nPortNumber);
     }
-    else if ( _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:adabas:",sizeof("sdbc:adabas:")-1) )
-    {
-        if ( sUrl.GetTokenCount(':') == 2 )
-            _rsHostname = sUrl.GetToken(0,':');
-        _sDatabaseName = sUrl.GetToken(sUrl.GetTokenCount(':') - 1,':');
-    }
     else if ( _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:mysql:mysqlc:",sizeof("sdbc:mysql:mysqlc:")-1) || _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:mysql:jdbc:",sizeof("sdbc:mysql:jdbc:")-1) )
     {
         lcl_extractHostAndPort(sUrl,_rsHostname,_nPortNumber);
 
-        if ( _nPortNumber == -1 && !_rsHostname.Len() && sUrl.GetTokenCount('/') == 2 )
+        if ( _nPortNumber == -1 && !_rsHostname.Len() && comphelper::string::getTokenCount(sUrl, '/') == 2 )
             _rsHostname = sUrl.GetToken(0,'/');
-        _sDatabaseName = sUrl.GetToken(sUrl.GetTokenCount('/') - 1,'/');
+        _sDatabaseName = sUrl.GetToken(comphelper::string::getTokenCount(sUrl, '/') - 1, '/');
     }
     else if ( _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:ado:access:Provider=Microsoft.ACE.OLEDB.12.0;DATA SOURCE=",sizeof("sdbc:ado:access:Provider=Microsoft.ACE.OLEDB.12.0;DATA SOURCE=")-1)
          || _rDsn.matchIgnoreAsciiCaseAsciiL("sdbc:ado:access:PROVIDER=Microsoft.Jet.OLEDB.4.0;DATA SOURCE=",sizeof("sdbc:ado:access:PROVIDER=Microsoft.Jet.OLEDB.4.0;DATA SOURCE=")-1))
@@ -329,11 +322,11 @@ bool ODsnTypeCollection::isEmbeddedDatabase( const ::rtl::OUString& _sURL ) cons
             static const ::rtl::OUString s_sValue(RTL_CONSTASCII_USTRINGPARAM("EmbeddedDatabases/DefaultEmbeddedDatabase/Value"));
 
             aInstalled.getNodeValue(s_sValue) >>= sEmbeddedDatabaseURL;
-            if ( sEmbeddedDatabaseURL.getLength() )
+            if ( !sEmbeddedDatabaseURL.isEmpty() )
                 aInstalled.getNodeValue(s_sValue + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/")) + sEmbeddedDatabaseURL + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/URL"))) >>= sEmbeddedDatabaseURL;
         }
     }
-    if ( !sEmbeddedDatabaseURL.getLength() )
+    if ( sEmbeddedDatabaseURL.isEmpty() )
         sEmbeddedDatabaseURL = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("sdbc:embedded:hsqldb"));
     return sEmbeddedDatabaseURL;
 }
@@ -421,7 +414,6 @@ DATASOURCE_TYPE ODsnTypeCollection::determineType(const String& _rDsn) const
     {
         KnownPrefix( "sdbc:calc:",          DST_CALC,               false ),
         KnownPrefix( "sdbc:flat:",          DST_FLAT,               false ),
-        KnownPrefix( "sdbc:adabas:",        DST_ADABAS,             false ),
         KnownPrefix( "sdbc:odbc:",          DST_ODBC,               false ),
         KnownPrefix( "sdbc:dbase:",         DST_DBASE,              false ),
         KnownPrefix( "sdbc:mysql:odbc:",    DST_MYSQL_ODBC,         false ),
@@ -441,7 +433,7 @@ DATASOURCE_TYPE ODsnTypeCollection::determineType(const String& _rDsn) const
         KnownPrefix( "sdbc:address:macab",              DST_MACAB,              true )
     };
 
-    for ( size_t i=0; i < SAL_N_ELEMENTS( aKnowPrefixes ); ++i )
+    for ( size_t i=0; i < sizeof( aKnowPrefixes ) / sizeof( aKnowPrefixes[0] ); ++i )
     {
         sal_uInt16 nMatchLen = aKnowPrefixes[i].bMatchComplete ? sDsn.Len() : (sal_uInt16)rtl_str_getLength( aKnowPrefixes[i].pAsciiPrefix );
         if ( sDsn.EqualsIgnoreCaseAscii( aKnowPrefixes[i].pAsciiPrefix, 0, nMatchLen ) )
@@ -489,9 +481,6 @@ void ODsnTypeCollection::fillPageIds(const ::rtl::OUString& _sURL,::std::vector<
         case DST_ORACLE_JDBC:
             _rOutPathIds.push_back(PAGE_DBSETUPWIZARD_ORACLE);
             break;
-        case DST_ADABAS:
-            _rOutPathIds.push_back(PAGE_DBSETUPWIZARD_ADABAS);
-            break;
         case DST_LDAP:
             _rOutPathIds.push_back(PAGE_DBSETUPWIZARD_LDAP);
             break;
