@@ -51,7 +51,6 @@
 #include <com/sun/star/sdbcx/XRename.hpp>
 #include <com/sun/star/sdb/ErrorCondition.hpp>
 #include <com/sun/star/sdb/application/DatabaseObject.hpp>
-#include <com/sun/star/sdb/SQLContext.hpp>
 #include <com/sun/star/sdbcx/XTablesSupplier.hpp>
 #include <com/sun/star/sdbcx/XViewsSupplier.hpp>
 #include <com/sun/star/ucb/Command.hpp>
@@ -61,20 +60,17 @@
 #include <com/sun/star/uno/XNamingService.hpp>
 #include <com/sun/star/util/XCloseable.hpp>
 #include <com/sun/star/util/XRefreshable.hpp>
-#include <com/sun/star/lang/XEventListener.hpp>
 /** === end UNO includes === **/
 
 #include <cppuhelper/exc_hlp.hxx>
 #include <connectivity/dbexception.hxx>
 #include <connectivity/dbtools.hxx>
 #include <connectivity/sqlerror.hxx>
-#include <connectivity/dbexception.hxx>
 #include <sfx2/mailmodelapi.hxx>
 #include <svx/dbaexchange.hxx>
 #include <toolkit/unohlp.hxx>
 #include <tools/diagnose_ex.h>
 #include <osl/diagnose.h>
-#include <tools/urlobj.hxx>
 #include <unotools/bootstrap.hxx>
 #include <vcl/mnemonic.hxx>
 #include <vcl/svapp.hxx>
@@ -239,7 +235,7 @@ void OApplicationController::openDialog( const ::rtl::OUString& _sServiceName )
         ::rtl::OUString sInitialSelection;
         if ( getContainer() )
             sInitialSelection = getDatabaseName();
-        if ( sInitialSelection.getLength() )
+        if ( !sInitialSelection.isEmpty() )
         {
             aArgs[ nArgPos++ ] <<= PropertyValue(
                 ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "InitialSelection" ) ), 0,
@@ -331,7 +327,7 @@ void SAL_CALL OApplicationController::propertyChange( const PropertyChangeEvent&
             // if the old name is empty, then this is a newly inserted content. We're notified of it via the
             // elementInserted method, so there's no need to handle it here.
 
-            if ( sOldName.getLength() )
+            if ( !sOldName.isEmpty() )
             {
                 Reference<XChild> xChild(evt.Source,UNO_QUERY);
                 if ( xChild.is() )
