@@ -51,6 +51,7 @@
 #include "com/sun/star/deployment/ExtensionManager.hpp"
 #include "com/sun/star/deployment/LicenseException.hpp"
 #include "com/sun/star/deployment/ui/LicenseDialog.hpp"
+#include <com/sun/star/task/OfficeRestartManager.hpp>
 #include <com/sun/star/task/XJob.hpp>
 #include <com/sun/star/task/XJobExecutor.hpp>
 #include <com/sun/star/task/XInteractionApprove.hpp>
@@ -77,12 +78,15 @@ class SilentCommandEnv
                                       task::XInteractionHandler,
                                       ucb::XProgressHandler >
 {
+    uno::Reference<uno::XComponentContext> mxContext;
     Desktop    *mpDesktop;
     sal_Int32   mnLevel;
     sal_Int32   mnProgress;
 
 public:
-             SilentCommandEnv( Desktop* pDesktop );
+    SilentCommandEnv(
+        uno::Reference<uno::XComponentContext> const & xContext,
+        Desktop* pDesktop );
     virtual ~SilentCommandEnv();
 
     // XCommandEnvironment
@@ -105,12 +109,14 @@ public:
 };
 
 //-----------------------------------------------------------------------------
-SilentCommandEnv::SilentCommandEnv( Desktop* pDesktop )
-{
-    mpDesktop = pDesktop;
-    mnLevel = 0;
-    mnProgress = 25;
-}
+SilentCommandEnv::SilentCommandEnv(
+    uno::Reference<uno::XComponentContext> const & xContext,
+    Desktop* pDesktop ):
+    mxContext( xContext ),
+    mpDesktop( pDesktop ),
+    mnLevel( 0 ),
+    mnProgress( 25 )
+{}
 
 //-----------------------------------------------------------------------------
 SilentCommandEnv::~SilentCommandEnv()
@@ -144,10 +150,9 @@ void SilentCommandEnv::handle( Reference< task::XInteractionRequest> const & xRe
 
     if ( request >>= licExc )
     {
-        uno::Reference< uno::XComponentContext > xContext = comphelper_getProcessComponentContext();
         uno::Reference< ui::dialogs::XExecutableDialog > xDialog(
             deployment::ui::LicenseDialog::create(
-            xContext, VCLUnoHelper::GetInterface( NULL ),
+            mxContext, VCLUnoHelper::GetInterface( NULL ),
             licExc.ExtensionName, licExc.Text ) );
         sal_Int16 res = xDialog->execute();
         if ( res == ui::dialogs::ExecutableDialogResults::CANCEL )
@@ -347,9 +352,9 @@ static void impl_setNeedsCompatCheck()
 // to check if we need checking the dependencies of the extensions again, we compare
 // the build id of the office with the one of the last check
 //------------------------------------------------------------------------------
-bool Desktop::newInstallation()
+static bool impl_needsCompatCheck()
 {
-    bool bNewInst = false;
+    bool bNeedsCheck = false;
     rtl::OUString aLastCheckBuildID;
     rtl::OUString aCurrentBuildID( UNISTRING( "${$BRAND_BASE_DIR/program/" SAL_CONFIGFILE("version") ":buildid}" ) );
     rtl::Bootstrap::expandMacros( aCurrentBuildID );
@@ -371,18 +376,18 @@ bool Desktop::newInstallation()
         result >>= aLastCheckBuildID;
         if ( aLastCheckBuildID != aCurrentBuildID )
         {
-            bNewInst = true;
+            bNeedsCheck = true;
             result <<= aCurrentBuildID;
             pset->setPropertyValue( OUString("LastCompatibilityCheckID"), result );
             Reference< util::XChangesBatch >( pset, UNO_QUERY_THROW )->commitChanges();
         }
 #ifdef DEBUG
-        bNewInst = true;
+        bNeedsCheck = true;
 #endif
     }
     catch (const com::sun::star::uno::Exception&) {}
 
-    return bNewInst;
+    return bNeedsCheck;
 }
 
 //------------------------------------------------------------------------------
@@ -390,6 +395,11 @@ bool Desktop::newInstallation()
 // When there are unresolved issues, we can't continue with startup
 sal_Bool Desktop::CheckExtensionDependencies()
 {
+    if (!impl_needsCompatCheck())
+    {
+        return false;
+    }
+
     uno::Reference< uno::XComponentContext > xContext = comphelper_getProcessComponentContext();
 
     bool bDependenciesValid = impl_checkDependencies( xContext );
@@ -408,10 +418,23 @@ sal_Bool Desktop::CheckExtensionDependencies()
         return false;
 }
 
-void Desktop::SynchronizeExtensionRepositories(bool force)
+void Desktop::SynchronizeExtensionRepositories()
 {
     RTL_LOGFILE_CONTEXT(aLog,"desktop (jl) ::Desktop::SynchronizeExtensionRepositories");
-    dp_misc::syncRepositories( force, new SilentCommandEnv( this ) );
+    uno::Reference< uno::XComponentContext > context(
+        comphelper_getProcessComponentContext());
+    uno::Reference< ucb::XCommandEnvironment > silent(
+        new SilentCommandEnv(context, this));
+    if (m_bCleanedExtensionCache) {
+        deployment::ExtensionManager::get(context)->reinstallDeployedExtensions(
+            true, "user", Reference<task::XAbortChannel>(), silent);
+        task::OfficeRestartManager::get(context)->requestRestart(
+            silent->getInteractionHandler());
+    } else {
+        // reinstallDeployedExtensions above already calls syncRepositories
+        // internally:
+        dp_misc::syncRepositories(m_bCleanedExtensionCache, silent);
+    }
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
