@@ -49,7 +49,6 @@
 #include <comphelper/processfactory.hxx>
 #include <osl/file.hxx>
 #include <rtl/process.h>
-#include <rtl/instance.hxx>
 #include "tools/getprocessworkingdir.hxx"
 
 using namespace desktop;
@@ -220,7 +219,7 @@ bool addArgument(rtl::OStringBuffer &rArguments, char prefix,
 
 }
 
-OfficeIPCThread*    OfficeIPCThread::pGlobalOfficeIPCThread = 0;
+rtl::Reference< OfficeIPCThread > OfficeIPCThread::pGlobalOfficeIPCThread;
     namespace { struct Security : public rtl::Static<osl::Security, Security> {}; }
 
 // Turns a string in aMsg such as file:///home/foo/.libreoffice/3
@@ -233,7 +232,7 @@ String CreateMD5FromString( const OUString& aMsg )
 #endif
 
     rtlDigest handle = rtl_digest_create( rtl_Digest_AlgorithmMD5 );
-    if ( handle > 0 )
+    if ( handle )
     {
         const sal_uInt8* pData = (const sal_uInt8*)aMsg.getStr();
         sal_uInt32       nSize = ( aMsg.getLength() * sizeof( sal_Unicode ));
@@ -317,7 +316,7 @@ oslSignalAction SAL_CALL SalMainPipeExchangeSignal_impl(void* /*pData*/, oslSign
 OUString SAL_CALL OfficeIPCThreadController::getImplementationName()
 throw ( RuntimeException )
 {
-    return OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.OfficeIPCThreadController" ));
+    return OUString( "com.sun.star.comp.OfficeIPCThreadController" );
 }
 
 sal_Bool SAL_CALL OfficeIPCThreadController::supportsService( const OUString& )
@@ -376,7 +375,7 @@ void OfficeIPCThread::SetDowning()
     // requests are executed anymore.
     ::osl::MutexGuard   aGuard( GetMutex() );
 
-    if ( pGlobalOfficeIPCThread )
+    if ( pGlobalOfficeIPCThread.is() )
         pGlobalOfficeIPCThread->mbDowning = true;
 }
 
@@ -387,7 +386,7 @@ void OfficeIPCThread::EnableRequests( bool i_bEnable )
     // switch between just queueing the requests and executing them
     ::osl::MutexGuard   aGuard( GetMutex() );
 
-    if ( pGlobalOfficeIPCThread )
+    if ( pGlobalOfficeIPCThread.is() )
     {
         s_bInEnableRequests = true;
         pGlobalOfficeIPCThread->mbRequestsEnabled = i_bEnable;
@@ -406,7 +405,7 @@ sal_Bool OfficeIPCThread::AreRequestsPending()
 {
     // Give info about pending requests
     ::osl::MutexGuard   aGuard( GetMutex() );
-    if ( pGlobalOfficeIPCThread )
+    if ( pGlobalOfficeIPCThread.is() )
         return ( pGlobalOfficeIPCThread->mnPendingRequests > 0 );
     else
         return sal_False;
@@ -416,7 +415,7 @@ void OfficeIPCThread::RequestsCompleted( int nCount )
 {
     // Remove nCount pending requests from our internal counter
     ::osl::MutexGuard   aGuard( GetMutex() );
-    if ( pGlobalOfficeIPCThread )
+    if ( pGlobalOfficeIPCThread.is() )
     {
         if ( pGlobalOfficeIPCThread->mnPendingRequests > 0 )
             pGlobalOfficeIPCThread->mnPendingRequests -= nCount;
@@ -427,15 +426,15 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
 {
     ::osl::MutexGuard   aGuard( GetMutex() );
 
-    if( pGlobalOfficeIPCThread )
+    if( pGlobalOfficeIPCThread.is() )
         return IPC_STATUS_OK;
 
     ::rtl::OUString aUserInstallPath;
     ::rtl::OUString aDummy;
 
-    OfficeIPCThread* pThread = new OfficeIPCThread;
+    rtl::Reference< OfficeIPCThread > pThread(new OfficeIPCThread);
 
-    pThread->maPipeIdent = OUString( RTL_CONSTASCII_USTRINGPARAM( "SingleOfficeIPC_" ) );
+    pThread->maPipeIdent = OUString( "SingleOfficeIPC_"  );
 
     // The name of the named pipe is created with the hashcode of the user installation directory (without /user). We have to retrieve
     // this information from a unotools implementation.
@@ -444,7 +443,6 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
         aDummy = aUserInstallPath;
     else
     {
-        delete pThread;
         return IPC_STATUS_BOOTSTRAP_ERROR;
     }
 
@@ -462,25 +460,25 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
     if ( lastIndex > 0 )
     {
         aIniName    = aIniName.copy( 0, lastIndex+1 );
-        aIniName    += OUString( RTL_CONSTASCII_USTRINGPARAM( "perftune" ));
+        aIniName    += OUString( "perftune" );
 #if defined(WNT)
-        aIniName    += OUString( RTL_CONSTASCII_USTRINGPARAM( ".ini" ));
+        aIniName    += OUString( ".ini" );
 #else
-        aIniName    += OUString( RTL_CONSTASCII_USTRINGPARAM( "rc" ));
+        aIniName    += OUString( "rc" );
 #endif
     }
 
     ::rtl::Bootstrap aPerfTuneIniFile( aIniName );
 
-    OUString aDefault( RTL_CONSTASCII_USTRINGPARAM( "0" ));
+    OUString aDefault( "0" );
     OUString aPreloadData;
 
-    aPerfTuneIniFile.getFrom( OUString( RTL_CONSTASCII_USTRINGPARAM( "FastPipeCommunication" )), aPreloadData, aDefault );
+    aPerfTuneIniFile.getFrom( OUString( "FastPipeCommunication" ), aPreloadData, aDefault );
 
 
     OUString aUserInstallPathHashCode;
 
-    if ( aPreloadData.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "1" ) ))
+    if ( aPreloadData == "1" )
     {
         sal_Char    szBuffer[32];
         sprintf( szBuffer, "%d", SUPD );
@@ -491,7 +489,7 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
 
 
     // Check result to create a hash code from the user install path
-    if ( aUserInstallPathHashCode.getLength() == 0 )
+    if ( aUserInstallPathHashCode.isEmpty() )
         return IPC_STATUS_BOOTSTRAP_ERROR; // Something completely broken, we cannot create a valid hash code!
 
     pThread->maPipeIdent = pThread->maPipeIdent + aUserInstallPathHashCode;
@@ -521,7 +519,7 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
             TimeValue aTimeValue;
             aTimeValue.Seconds = 0;
             aTimeValue.Nanosec = 10000000; // 10ms
-            osl::Thread::wait( aTimeValue );
+            salhelper::Thread::wait( aTimeValue );
         }
 
     } while ( nPipeMode == PIPEMODE_DONTKNOW );
@@ -530,7 +528,7 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
     {
         // Seems we are the one and only, so start listening thread
         pGlobalOfficeIPCThread = pThread;
-        pThread->create(); // starts thread
+        pThread->launch();
     }
     else
     {
@@ -557,20 +555,21 @@ OfficeIPCThread::Status OfficeIPCThread::EnableOfficeIPCThread()
         aStreamPipe.write(aArguments.getStr(), aArguments.getLength());
         aStreamPipe.write("\0", 1);
 
-        ByteString aToken(sc_aConfirmationSequence);
-        char *aReceiveBuffer = new char[aToken.Len()+1];
-        int n = aStreamPipe.read( aReceiveBuffer, aToken.Len() );
-        aReceiveBuffer[n]='\0';
+        rtl::OString aToken(sc_aConfirmationSequence);
+        char *pReceiveBuffer = new char[aToken.getLength()+1];
+        sal_Int32 n = aStreamPipe.read(pReceiveBuffer, aToken.getLength());
+        pReceiveBuffer[n]='\0';
 
-        delete pThread;
-        if (aToken.CompareTo(aReceiveBuffer)!= COMPARE_EQUAL) {
+        bool bIsConfirmationSequence = aToken.equals(pReceiveBuffer);
+        delete[] pReceiveBuffer;
+
+        if (!bIsConfirmationSequence)
+        {
             // something went wrong
-            delete[] aReceiveBuffer;
             return IPC_STATUS_BOOTSTRAP_ERROR;
-        } else {
-            delete[] aReceiveBuffer;
-            return IPC_STATUS_2ND_OFFICE;
         }
+
+        return IPC_STATUS_2ND_OFFICE;
     }
 
     return IPC_STATUS_OK;
@@ -580,10 +579,11 @@ void OfficeIPCThread::DisableOfficeIPCThread()
 {
     osl::ClearableMutexGuard aMutex( GetMutex() );
 
-    if( pGlobalOfficeIPCThread )
+    if( pGlobalOfficeIPCThread.is() )
     {
-        OfficeIPCThread *pOfficeIPCThread = pGlobalOfficeIPCThread;
-        pGlobalOfficeIPCThread = 0;
+        rtl::Reference< OfficeIPCThread > pOfficeIPCThread(
+            pGlobalOfficeIPCThread);
+        pGlobalOfficeIPCThread.clear();
 
         // send thread a termination message
         // this is done so the subsequent join will not hang
@@ -605,13 +605,11 @@ void OfficeIPCThread::DisableOfficeIPCThread()
 
         // exit gracefully and join
         pOfficeIPCThread->join();
-        delete pOfficeIPCThread;
-
-
     }
 }
 
 OfficeIPCThread::OfficeIPCThread() :
+    Thread( "OfficeIPCThread" ),
     mbDowning( false ),
     mbRequestsEnabled( false ),
     mnPendingRequests( 0 ),
@@ -627,28 +625,21 @@ OfficeIPCThread::~OfficeIPCThread()
         mpDispatchWatcher->release();
     maPipe.close();
     maStreamPipe.close();
-    pGlobalOfficeIPCThread = 0;
+    pGlobalOfficeIPCThread.clear();
 }
 
-static void AddURLToStringList( const rtl::OUString& aURL, rtl::OUString& aStringList )
+void OfficeIPCThread::SetReady(
+    rtl::Reference< OfficeIPCThread > const & pThread)
 {
-    ::rtl::OUStringBuffer aStringListBuf(aStringList);
-    if ( aStringListBuf.getLength() )
-        aStringListBuf.append('\n');
-    aStringListBuf.append(aURL);
-    aStringList = aStringListBuf.makeStringAndClear();
-}
-
-void OfficeIPCThread::SetReady(OfficeIPCThread* pThread)
-{
-    if (pThread == NULL) pThread = pGlobalOfficeIPCThread;
-    if (pThread != NULL)
+    rtl::Reference< OfficeIPCThread > const & t(
+        pThread.is() ? pThread : pGlobalOfficeIPCThread);
+    if (t.is())
     {
-        pThread->cReady.set();
+        t->cReady.set();
     }
 }
 
-void SAL_CALL OfficeIPCThread::run()
+void OfficeIPCThread::execute()
 {
     do
     {
@@ -664,39 +655,41 @@ void SAL_CALL OfficeIPCThread::run()
             cReady.wait();
 
             // we might have decided to shutdown while we were sleeping
-            if (!pGlobalOfficeIPCThread) return;
+            if (!pGlobalOfficeIPCThread.is()) return;
 
             // only lock the mutex when processing starts, othewise we deadlock when the office goes
             // down during wait
             osl::ClearableMutexGuard aGuard( GetMutex() );
 
-            ByteString aArguments;
             // test byte by byte
             const int nBufSz = 2048;
             char pBuf[nBufSz];
             int nBytes = 0;
             int nResult = 0;
+            rtl::OStringBuffer aBuf;
             // read into pBuf until '\0' is read or read-error
             while ((nResult=maStreamPipe.recv( pBuf+nBytes, nBufSz-nBytes))>0) {
                 nBytes += nResult;
                 if (pBuf[nBytes-1]=='\0') {
-                    aArguments += pBuf;
+                    aBuf.append(pBuf);
                     break;
                 }
             }
             // don't close pipe ...
 
+            rtl::OString aArguments = aBuf.makeStringAndClear();
+
             // Is this a lookup message from another application? if so, ignore
-            if ( aArguments.Len() == 0 )
+            if (aArguments.isEmpty())
                 continue;
 
             // is this a termination message ? if so, terminate
-            if(( aArguments.CompareTo( sc_aTerminationSequence, sc_nTSeqLength ) == COMPARE_EQUAL ) ||
-                    mbDowning ) return;
+            if (aArguments.equalsL(sc_aTerminationSequence, sc_nTSeqLength) || mbDowning)
+                return;
             std::auto_ptr< CommandLineArgs > aCmdLineArgs;
             try
             {
-                Parser p( aArguments );
+                Parser p(aArguments);
                 aCmdLineArgs.reset( new CommandLineArgs( p ) );
             }
             catch ( const CommandLineArgs::Supplier::Exception & )
@@ -706,173 +699,194 @@ void SAL_CALL OfficeIPCThread::run()
 #endif
                 continue;
             }
-            const CommandLineArgs &rCurrentCmdLineArgs = Desktop::GetCommandLineArgs();
-
-            if ( aCmdLineArgs->IsQuickstart() )
-            {
-                // we have to use application event, because we have to start quickstart service in main thread!!
-                ApplicationEvent* pAppEvent =
-                    new ApplicationEvent(ApplicationEvent::TYPE_QUICKSTART);
-                ImplPostForeignAppEvent( pAppEvent );
-            }
-
-            // handle request for acceptor
-            OUString aAcceptString;
-            if ( aCmdLineArgs->GetAcceptString(aAcceptString) ) {
-                ApplicationEvent* pAppEvent = new ApplicationEvent(
-                    ApplicationEvent::TYPE_ACCEPT, aAcceptString);
-                ImplPostForeignAppEvent( pAppEvent );
-            }
-            // handle acceptor removal
-            OUString aUnAcceptString;
-            if ( aCmdLineArgs->GetUnAcceptString(aUnAcceptString) ) {
-                ApplicationEvent* pAppEvent = new ApplicationEvent(
-                    ApplicationEvent::TYPE_UNACCEPT, aUnAcceptString);
-                ImplPostForeignAppEvent( pAppEvent );
-            }
-
-#ifndef UNX
-            // only in non-unix version, we need to handle a -help request
-            // in a running instance in order to display  the command line help
-            if ( aCmdLineArgs->IsHelp() ) {
-                ApplicationEvent* pAppEvent =
-                    new ApplicationEvent(ApplicationEvent::TYPE_HELP);
-                ImplPostForeignAppEvent( pAppEvent );
-            }
-#endif
 
             sal_Bool bDocRequestSent = sal_False;
-            ProcessDocumentsRequest* pRequest = new ProcessDocumentsRequest(
-                aCmdLineArgs->getCwdUrl());
-            cProcessed.reset();
-            pRequest->pcProcessed = &cProcessed;
 
-            // Print requests are not dependent on the --invisible cmdline argument as they are
-            // loaded with the "hidden" flag! So they are always checked.
-            bDocRequestSent |= aCmdLineArgs->GetPrintList( pRequest->aPrintList );
-            bDocRequestSent |= ( aCmdLineArgs->GetPrintToList( pRequest->aPrintToList ) &&
-                                    aCmdLineArgs->GetPrinterName( pRequest->aPrinterName )      );
-
-            if ( !rCurrentCmdLineArgs.IsInvisible() )
+            OUString aUnknown( aCmdLineArgs->GetUnknown() );
+            if ( !aUnknown.isEmpty() || aCmdLineArgs->IsHelp() )
             {
-                // Read cmdline args that can open/create documents. As they would open a window
-                // they are only allowed if the "--invisible" is currently not used!
-                bDocRequestSent |= aCmdLineArgs->GetOpenList( pRequest->aOpenList );
-                bDocRequestSent |= aCmdLineArgs->GetViewList( pRequest->aViewList );
-                bDocRequestSent |= aCmdLineArgs->GetStartList( pRequest->aStartList );
-                bDocRequestSent |= aCmdLineArgs->GetForceOpenList( pRequest->aForceOpenList );
-                bDocRequestSent |= aCmdLineArgs->GetForceNewList( pRequest->aForceNewList );
-
-                // Special command line args to create an empty document for a given module
-
-                // #i18338# (lo)
-                // we only do this if no document was specified on the command line,
-                // since this would be inconsistent with the the behaviour of
-                // the first process, see OpenClients() (call to OpenDefault()) in app.cxx
-                if ( aCmdLineArgs->HasModuleParam() && (!bDocRequestSent) )
-                {
-                    SvtModuleOptions aOpt;
-                    SvtModuleOptions::EFactory eFactory = SvtModuleOptions::E_WRITER;
-                    if ( aCmdLineArgs->IsWriter() )
-                        eFactory = SvtModuleOptions::E_WRITER;
-                    else if ( aCmdLineArgs->IsCalc() )
-                        eFactory = SvtModuleOptions::E_CALC;
-                    else if ( aCmdLineArgs->IsDraw() )
-                        eFactory = SvtModuleOptions::E_DRAW;
-                    else if ( aCmdLineArgs->IsImpress() )
-                        eFactory = SvtModuleOptions::E_IMPRESS;
-                    else if ( aCmdLineArgs->IsBase() )
-                        eFactory = SvtModuleOptions::E_DATABASE;
-                    else if ( aCmdLineArgs->IsMath() )
-                        eFactory = SvtModuleOptions::E_MATH;
-                    else if ( aCmdLineArgs->IsGlobal() )
-                        eFactory = SvtModuleOptions::E_WRITERGLOBAL;
-                    else if ( aCmdLineArgs->IsWeb() )
-                        eFactory = SvtModuleOptions::E_WRITERWEB;
-
-                    if ( pRequest->aOpenList.getLength() )
-                        pRequest->aModule = aOpt.GetFactoryName( eFactory );
-                    else
-                        AddURLToStringList( aOpt.GetFactoryEmptyDocumentURL( eFactory ), pRequest->aOpenList );
-                    bDocRequestSent = sal_True;
-                }
+                ApplicationEvent* pAppEvent =
+                    new ApplicationEvent(ApplicationEvent::TYPE_HELP, aUnknown);
+                ImplPostForeignAppEvent( pAppEvent );
             }
-
-            if ( !aCmdLineArgs->IsQuickstart() ) {
-                sal_Bool bShowHelp = sal_False;
-                rtl::OUStringBuffer aHelpURLBuffer;
-                if (aCmdLineArgs->IsHelpWriter()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://swriter/start");
-                } else if (aCmdLineArgs->IsHelpCalc()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://scalc/start");
-                } else if (aCmdLineArgs->IsHelpDraw()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://sdraw/start");
-                } else if (aCmdLineArgs->IsHelpImpress()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://simpress/start");
-                } else if (aCmdLineArgs->IsHelpBase()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://sdatabase/start");
-                } else if (aCmdLineArgs->IsHelpBasic()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://sbasic/start");
-                } else if (aCmdLineArgs->IsHelpMath()) {
-                    bShowHelp = sal_True;
-                    aHelpURLBuffer.appendAscii("vnd.sun.star.help://smath/start");
-                }
-                if (bShowHelp) {
-                    aHelpURLBuffer.appendAscii("?Language=");
-                    aHelpURLBuffer.append(utl::ConfigManager::getLocale());
-#if defined UNX
-                    aHelpURLBuffer.appendAscii("&System=UNX");
-#elif defined WNT
-                    aHelpURLBuffer.appendAscii("&System=WIN");
-#endif
-                    ApplicationEvent* pAppEvent = new ApplicationEvent(
-                        ApplicationEvent::TYPE_OPENHELPURL,
-                        aHelpURLBuffer.makeStringAndClear());
-                    ImplPostForeignAppEvent( pAppEvent );
-                }
-            }
-
-            if ( bDocRequestSent )
-             {
-                // Send requests to dispatch watcher if we have at least one. The receiver
-                // is responsible to delete the request after processing it.
-                if ( aCmdLineArgs->HasModuleParam() )
-                {
-                    SvtModuleOptions    aOpt;
-
-                    // Support command line parameters to start a module (as preselection)
-                    if ( aCmdLineArgs->IsWriter() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SWRITER ) )
-                        pRequest->aModule = aOpt.GetFactoryName( SvtModuleOptions::E_WRITER );
-                    else if ( aCmdLineArgs->IsCalc() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SCALC ) )
-                        pRequest->aModule = aOpt.GetFactoryName( SvtModuleOptions::E_CALC );
-                    else if ( aCmdLineArgs->IsImpress() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SIMPRESS ) )
-                        pRequest->aModule= aOpt.GetFactoryName( SvtModuleOptions::E_IMPRESS );
-                    else if ( aCmdLineArgs->IsDraw() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SDRAW ) )
-                        pRequest->aModule= aOpt.GetFactoryName( SvtModuleOptions::E_DRAW );
-                }
-
-
-                ImplPostProcessDocumentsEvent( pRequest );
+            else if ( aCmdLineArgs->IsVersion() )
+            {
+                ApplicationEvent* pAppEvent =
+                    new ApplicationEvent(ApplicationEvent::TYPE_VERSION);
+                ImplPostForeignAppEvent( pAppEvent );
             }
             else
             {
-                // delete not used request again
-                delete pRequest;
-                pRequest = NULL;
-            }
-            if (( aArguments.CompareTo( sc_aShowSequence, sc_nShSeqLength ) == COMPARE_EQUAL ) ||
-                aCmdLineArgs->IsEmpty() )
-            {
-                // no document was sent, just bring Office to front
-                ApplicationEvent* pAppEvent =
-                    new ApplicationEvent(ApplicationEvent::TYPE_APPEAR);
-                ImplPostForeignAppEvent( pAppEvent );
+                const CommandLineArgs &rCurrentCmdLineArgs = Desktop::GetCommandLineArgs();
+
+                if ( aCmdLineArgs->IsQuickstart() )
+                {
+                    // we have to use application event, because we have to start quickstart service in main thread!!
+                    ApplicationEvent* pAppEvent =
+                        new ApplicationEvent(ApplicationEvent::TYPE_QUICKSTART);
+                    ImplPostForeignAppEvent( pAppEvent );
+                }
+
+                // handle request for acceptor
+                std::vector< rtl::OUString > const & accept = aCmdLineArgs->
+                    GetAccept();
+                for (std::vector< rtl::OUString >::const_iterator i(accept.begin());
+                     i != accept.end(); ++i)
+                {
+                    ApplicationEvent* pAppEvent = new ApplicationEvent(
+                        ApplicationEvent::TYPE_ACCEPT, *i);
+                    ImplPostForeignAppEvent( pAppEvent );
+                }
+                // handle acceptor removal
+                std::vector< rtl::OUString > const & unaccept = aCmdLineArgs->
+                    GetUnaccept();
+                for (std::vector< rtl::OUString >::const_iterator i(
+                         unaccept.begin());
+                     i != unaccept.end(); ++i)
+                {
+                    ApplicationEvent* pAppEvent = new ApplicationEvent(
+                        ApplicationEvent::TYPE_UNACCEPT, *i);
+                    ImplPostForeignAppEvent( pAppEvent );
+                }
+
+                ProcessDocumentsRequest* pRequest = new ProcessDocumentsRequest(
+                    aCmdLineArgs->getCwdUrl());
+                cProcessed.reset();
+                pRequest->pcProcessed = &cProcessed;
+
+                // Print requests are not dependent on the --invisible cmdline argument as they are
+                // loaded with the "hidden" flag! So they are always checked.
+                pRequest->aPrintList = aCmdLineArgs->GetPrintList();
+                bDocRequestSent |= !pRequest->aPrintList.empty();
+                pRequest->aPrintToList = aCmdLineArgs->GetPrintToList();
+                pRequest->aPrinterName = aCmdLineArgs->GetPrinterName();
+                bDocRequestSent |= !( pRequest->aPrintToList.empty() || pRequest->aPrinterName.isEmpty() );
+
+                if ( !rCurrentCmdLineArgs.IsInvisible() )
+                {
+                    // Read cmdline args that can open/create documents. As they would open a window
+                    // they are only allowed if the "--invisible" is currently not used!
+                    pRequest->aOpenList = aCmdLineArgs->GetOpenList();
+                    bDocRequestSent |= !pRequest->aOpenList.empty();
+                    pRequest->aViewList = aCmdLineArgs->GetViewList();
+                    bDocRequestSent |= !pRequest->aViewList.empty();
+                    pRequest->aStartList = aCmdLineArgs->GetStartList();
+                    bDocRequestSent |= !pRequest->aStartList.empty();
+                    pRequest->aForceOpenList = aCmdLineArgs->GetForceOpenList();
+                    bDocRequestSent |= !pRequest->aForceOpenList.empty();
+                    pRequest->aForceNewList = aCmdLineArgs->GetForceNewList();
+                    bDocRequestSent |= !pRequest->aForceNewList.empty();
+
+                    // Special command line args to create an empty document for a given module
+
+                    // #i18338# (lo)
+                    // we only do this if no document was specified on the command line,
+                    // since this would be inconsistent with the the behaviour of
+                    // the first process, see OpenClients() (call to OpenDefault()) in app.cxx
+                    if ( aCmdLineArgs->HasModuleParam() && (!bDocRequestSent) )
+                    {
+                        SvtModuleOptions aOpt;
+                        SvtModuleOptions::EFactory eFactory = SvtModuleOptions::E_WRITER;
+                        if ( aCmdLineArgs->IsWriter() )
+                            eFactory = SvtModuleOptions::E_WRITER;
+                        else if ( aCmdLineArgs->IsCalc() )
+                            eFactory = SvtModuleOptions::E_CALC;
+                        else if ( aCmdLineArgs->IsDraw() )
+                            eFactory = SvtModuleOptions::E_DRAW;
+                        else if ( aCmdLineArgs->IsImpress() )
+                            eFactory = SvtModuleOptions::E_IMPRESS;
+                        else if ( aCmdLineArgs->IsBase() )
+                            eFactory = SvtModuleOptions::E_DATABASE;
+                        else if ( aCmdLineArgs->IsMath() )
+                            eFactory = SvtModuleOptions::E_MATH;
+                        else if ( aCmdLineArgs->IsGlobal() )
+                            eFactory = SvtModuleOptions::E_WRITERGLOBAL;
+                        else if ( aCmdLineArgs->IsWeb() )
+                            eFactory = SvtModuleOptions::E_WRITERWEB;
+
+                        if ( !pRequest->aOpenList.empty() )
+                            pRequest->aModule = aOpt.GetFactoryName( eFactory );
+                        else
+                            pRequest->aOpenList.push_back( aOpt.GetFactoryEmptyDocumentURL( eFactory ) );
+                        bDocRequestSent = sal_True;
+                    }
+                }
+
+                if ( !aCmdLineArgs->IsQuickstart() ) {
+                    sal_Bool bShowHelp = sal_False;
+                    rtl::OUStringBuffer aHelpURLBuffer;
+                    if (aCmdLineArgs->IsHelpWriter()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://swriter/start");
+                    } else if (aCmdLineArgs->IsHelpCalc()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://scalc/start");
+                    } else if (aCmdLineArgs->IsHelpDraw()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://sdraw/start");
+                    } else if (aCmdLineArgs->IsHelpImpress()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://simpress/start");
+                    } else if (aCmdLineArgs->IsHelpBase()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://sdatabase/start");
+                    } else if (aCmdLineArgs->IsHelpBasic()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://sbasic/start");
+                    } else if (aCmdLineArgs->IsHelpMath()) {
+                        bShowHelp = sal_True;
+                        aHelpURLBuffer.appendAscii("vnd.sun.star.help://smath/start");
+                    }
+                    if (bShowHelp) {
+                        aHelpURLBuffer.appendAscii("?Language=");
+                        aHelpURLBuffer.append(utl::ConfigManager::getLocale());
+#if defined UNX
+                        aHelpURLBuffer.appendAscii("&System=UNX");
+#elif defined WNT
+                        aHelpURLBuffer.appendAscii("&System=WIN");
+#endif
+                        ApplicationEvent* pAppEvent = new ApplicationEvent(
+                            ApplicationEvent::TYPE_OPENHELPURL,
+                            aHelpURLBuffer.makeStringAndClear());
+                        ImplPostForeignAppEvent( pAppEvent );
+                    }
+                }
+
+                if ( bDocRequestSent )
+                {
+                    // Send requests to dispatch watcher if we have at least one. The receiver
+                    // is responsible to delete the request after processing it.
+                    if ( aCmdLineArgs->HasModuleParam() )
+                    {
+                        SvtModuleOptions    aOpt;
+
+                        // Support command line parameters to start a module (as preselection)
+                        if ( aCmdLineArgs->IsWriter() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SWRITER ) )
+                            pRequest->aModule = aOpt.GetFactoryName( SvtModuleOptions::E_WRITER );
+                        else if ( aCmdLineArgs->IsCalc() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SCALC ) )
+                            pRequest->aModule = aOpt.GetFactoryName( SvtModuleOptions::E_CALC );
+                        else if ( aCmdLineArgs->IsImpress() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SIMPRESS ) )
+                            pRequest->aModule= aOpt.GetFactoryName( SvtModuleOptions::E_IMPRESS );
+                        else if ( aCmdLineArgs->IsDraw() && aOpt.IsModuleInstalled( SvtModuleOptions::E_SDRAW ) )
+                            pRequest->aModule= aOpt.GetFactoryName( SvtModuleOptions::E_DRAW );
+                    }
+
+                    ImplPostProcessDocumentsEvent( pRequest );
+                }
+                else
+                {
+                    // delete not used request again
+                    delete pRequest;
+                    pRequest = NULL;
+                }
+                if (aArguments.equalsL(sc_aShowSequence, sc_nShSeqLength) ||
+                    aCmdLineArgs->IsEmpty())
+                {
+                    // no document was sent, just bring Office to front
+                    ApplicationEvent* pAppEvent =
+                        new ApplicationEvent(ApplicationEvent::TYPE_APPEAR);
+                    ImplPostForeignAppEvent( pAppEvent );
+                }
             }
 
             // we don't need the mutex any longer...
@@ -894,7 +908,7 @@ void SAL_CALL OfficeIPCThread::run()
             TimeValue tval;
             tval.Seconds = 1;
             tval.Nanosec = 0;
-            wait( tval );
+            salhelper::Thread::wait( tval );
         }
     } while( schedule() );
 }
@@ -902,29 +916,23 @@ void SAL_CALL OfficeIPCThread::run()
 static void AddToDispatchList(
     DispatchWatcher::DispatchList& rDispatchList,
     boost::optional< rtl::OUString > const & cwdUrl,
-    const OUString& aRequestList,
+    std::vector< rtl::OUString > const & aRequestList,
     DispatchWatcher::RequestType nType,
     const OUString& aParam,
     const OUString& aFactory )
 {
-    if ( aRequestList.getLength() > 0 )
+    for (std::vector< rtl::OUString >::const_iterator i(aRequestList.begin());
+         i != aRequestList.end(); ++i)
     {
-        sal_Int32 nIndex = 0;
-        do
-        {
-            OUString aToken = aRequestList.getToken( 0, '\n', nIndex );
-            if ( aToken.getLength() > 0 )
-                rDispatchList.push_back(
-                    DispatchWatcher::DispatchRequest( nType, aToken, cwdUrl, aParam, aFactory ));
-        }
-        while ( nIndex >= 0 );
+        rDispatchList.push_back(
+            DispatchWatcher::DispatchRequest( nType, *i, cwdUrl, aParam, aFactory ));
     }
 }
 
 static void AddConversionsToDispatchList(
     DispatchWatcher::DispatchList& rDispatchList,
     boost::optional< rtl::OUString > const & cwdUrl,
-    const OUString& rRequestList,
+    std::vector< rtl::OUString > const & rRequestList,
     const OUString& rParam,
     const OUString& rPrinterName,
     const OUString& rFactory,
@@ -933,7 +941,7 @@ static void AddConversionsToDispatchList(
     DispatchWatcher::RequestType nType;
     OUString aParam( rParam );
 
-    if( rParam.getLength() )
+    if( !rParam.isEmpty() )
     {
         nType = DispatchWatcher::REQUEST_CONVERSION;
         aParam = rParam;
@@ -951,28 +959,22 @@ static void AddConversionsToDispatchList(
     if( !::osl::FileBase::getAbsoluteFileURL( aPWD, rParamOut, aOutDir ) )
         ::osl::FileBase::getSystemPathFromFileURL( aOutDir, aOutDir );
 
-    if( rParamOut.trim().getLength() )
+    if( !rParamOut.trim().isEmpty() )
     {
-        aParam += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(";"));
+        aParam += ::rtl::OUString(";");
         aParam += aOutDir;
     }
     else
     {
         ::osl::FileBase::getSystemPathFromFileURL( aPWD, aPWD );
-        aParam += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ";" )) + aPWD;
+        aParam += ::rtl::OUString(";" ) + aPWD;
     }
 
-    if ( rRequestList.getLength() > 0 )
+    for (std::vector< rtl::OUString >::const_iterator i(rRequestList.begin());
+         i != rRequestList.end(); ++i)
     {
-        sal_Int32 nIndex = 0;
-        do
-        {
-            OUString aToken = rRequestList.getToken( 0, '\n', nIndex );
-            if ( aToken.getLength() > 0 )
-                rDispatchList.push_back(
-                    DispatchWatcher::DispatchRequest( nType, aToken, cwdUrl, aParam, rFactory ));
-        }
-        while ( nIndex >= 0 );
+        rDispatchList.push_back(
+            DispatchWatcher::DispatchRequest( nType, *i, cwdUrl, aParam, rFactory ));
     }
 }
 
@@ -997,7 +999,7 @@ sal_Bool OfficeIPCThread::ExecuteCmdLineRequests( ProcessDocumentsRequest& aRequ
     AddConversionsToDispatchList( aDispatchList, aRequest.aCwdUrl, aRequest.aConversionList, aRequest.aConversionParams, aRequest.aPrinterName, aRequest.aModule, aRequest.aConversionOut );
     sal_Bool bShutdown( sal_False );
 
-    if ( pGlobalOfficeIPCThread )
+    if ( pGlobalOfficeIPCThread.is() )
     {
         if( ! pGlobalOfficeIPCThread->AreRequestsEnabled() )
             return bShutdown;
