@@ -65,6 +65,7 @@
 #include <list>
 #include <boost/unordered_map.hpp>
 #include <algorithm>
+#include <set>
 
 namespace deploy = com::sun::star::deployment;
 namespace lang  = com::sun::star::lang;
@@ -1205,9 +1206,10 @@ uno::Sequence< uno::Sequence<Reference<deploy::XPackage> > >
    }
 }
 
-//only to be called from unopkg!!!
+// Only to be called from unopkg or soffice bootstrap (with force=true in the
+// latter case):
 void ExtensionManager::reinstallDeployedExtensions(
-    OUString const & repository,
+    sal_Bool force, OUString const & repository,
     Reference<task::XAbortChannel> const & xAbortChannel,
     Reference<ucb::XCommandEnvironment> const & xCmdEnv )
     throw (deploy::DeploymentException,
@@ -1219,11 +1221,37 @@ void ExtensionManager::reinstallDeployedExtensions(
         Reference<deploy::XPackageManager>
             xPackageManager = getPackageManager(repository);
 
+        std::set< OUString > disabledExts;
+        {
+            const uno::Sequence< Reference<deploy::XPackage> > extensions(
+                xPackageManager->getDeployedPackages(xAbortChannel, xCmdEnv));
+            for ( sal_Int32 pos = 0; pos < extensions.getLength(); ++pos )
+            {
+                try
+                {
+                    beans::Optional< beans::Ambiguous< sal_Bool > > registered(
+                        extensions[pos]->isRegistered(xAbortChannel, xCmdEnv));
+                    if (registered.IsPresent &&
+                        !(registered.Value.IsAmbiguous ||
+                          registered.Value.Value))
+                    {
+                        const OUString id = dp_misc::getIdentifier(extensions[ pos ]);
+                        OSL_ASSERT(!id.isEmpty());
+                        disabledExts.insert(id);
+                    }
+                }
+                catch (const lang::DisposedException &)
+                {
+                }
+            }
+        }
+
         ::osl::MutexGuard guard(getMutex());
-        xPackageManager->reinstallDeployedPackages(xAbortChannel, xCmdEnv);
+        xPackageManager->reinstallDeployedPackages(
+            force, xAbortChannel, xCmdEnv);
         //We must sync here, otherwise we will get exceptions when extensions
         //are removed.
-        dp_misc::syncRepositories(false, xCmdEnv);
+        dp_misc::syncRepositories(force, xCmdEnv);
         const uno::Sequence< Reference<deploy::XPackage> > extensions(
             xPackageManager->getDeployedPackages(xAbortChannel, xCmdEnv));
 
@@ -1234,7 +1262,9 @@ void ExtensionManager::reinstallDeployedExtensions(
                 const OUString id =  dp_misc::getIdentifier(extensions[ pos ]);
                 const OUString fileName = extensions[ pos ]->getName();
                 OSL_ASSERT(!id.isEmpty());
-                activateExtension(id, fileName, false, true, xAbortChannel, xCmdEnv );
+                activateExtension(
+                    id, fileName, disabledExts.find(id) != disabledExts.end(),
+                    true, xAbortChannel, xCmdEnv );
             }
             catch (const lang::DisposedException &)
             {
@@ -1258,64 +1288,6 @@ void ExtensionManager::reinstallDeployedExtensions(
     }
 }
 
-/** Works on the bundled repository. That is using the variables
-    BUNDLED_EXTENSIONS and BUNDLED_EXTENSIONS_USER.
- */
-void ExtensionManager::synchronizeBundledPrereg(
-    Reference<task::XAbortChannel> const & xAbortChannel,
-    Reference<ucb::XCommandEnvironment> const & xCmdEnv )
-    throw (deploy::DeploymentException,
-           uno::RuntimeException)
-{
-    try
-    {
-        String sSynchronizingBundled(StrSyncRepository::get());
-        sSynchronizingBundled.SearchAndReplaceAllAscii( "%NAME", OUSTR("bundled"));
-        dp_misc::ProgressLevel progressBundled(xCmdEnv, sSynchronizingBundled);
-
-        Reference<deploy::XPackageManagerFactory> xPackageManagerFactory(
-            deploy::thePackageManagerFactory::get(m_xContext));
-
-        Reference<deploy::XPackageManager> xMgr =
-            xPackageManagerFactory->getPackageManager(OUSTR("bundled_prereg"));
-        xMgr->synchronize(xAbortChannel, xCmdEnv);
-        progressBundled.update(OUSTR("\n\n"));
-
-        uno::Sequence<Reference<deploy::XPackage> > extensions = xMgr->getDeployedPackages(
-            xAbortChannel, xCmdEnv);
-        try
-        {
-            for (sal_Int32 i = 0; i < extensions.getLength(); i++)
-            {
-                extensions[i]->registerPackage(true, xAbortChannel, xCmdEnv);
-            }
-        }
-        catch (...)
-        {
-            OSL_ASSERT(0);
-        }
-        OUString lastSyncBundled(RTL_CONSTASCII_USTRINGPARAM(
-                                     "$BUNDLED_EXTENSIONS_PREREG/lastsynchronized"));
-        writeLastModified(lastSyncBundled, xCmdEnv);
-
-    } catch ( const deploy::DeploymentException& ) {
-        throw;
-    } catch ( const ucb::CommandFailedException & ) {
-        throw;
-    } catch ( const ucb::CommandAbortedException & ) {
-        throw;
-    } catch (const lang::IllegalArgumentException &) {
-        throw;
-    } catch (const uno::RuntimeException &) {
-        throw;
-    } catch (...) {
-        uno::Any exc = ::cppu::getCaughtException();
-        throw deploy::DeploymentException(
-            OUSTR("Extension Manager: exception in synchronize"),
-            static_cast<OWeakObject*>(this), exc);
-    }
-}
-
 sal_Bool ExtensionManager::synchronize(
     Reference<task::XAbortChannel> const & xAbortChannel,
     Reference<ucb::XCommandEnvironment> const & xCmdEnv )
@@ -1342,14 +1314,15 @@ sal_Bool ExtensionManager::synchronize(
         bModified |= getBundledRepository()->synchronize(xAbortChannel, xCmdEnv);
         progressBundled.update(OUSTR("\n\n"));
 
-        //Always determine the active extension. This is necessary for the
-        //first-start optimization. The setup creates the registration data for the
-        //bundled extensions (brand_layer/share/prereg/bundled), which is copied to the user
-        //installation (user_installation/extension/bundled) when a user starts OOo
-        //for the first time after running setup. All bundled extensions are registered
-        //at that moment. However, extensions with the same identifier can be in the
-        //shared or user repository, in which case the respective bundled extensions must
-        //be revoked.
+        //Always determine the active extension.
+        //TODO: Is this still necessary?  (It used to be necessary for the
+        // first-start optimization:  The setup created the registration data
+        // for the bundled extensions (share/prereg/bundled) which was copied to
+        // the user installation when a user started OOo for the first time
+        // after running setup.  All bundled extensions were registered at that
+        // moment.  However, extensions with the same identifier could be in the
+        // shared or user repository, in which case the respective bundled
+        // extensions had to be revoked.)
         try
         {
             const uno::Sequence<uno::Sequence<Reference<deploy::XPackage> > >
