@@ -130,13 +130,13 @@ XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
         case SVX_CASEMAP_KAPITAELCHEN:
         case SVX_CASEMAP_VERSALIEN:
         {
-            aCharClass.toUpper( aTxt );
+            aTxt = aCharClass.uppercase( aTxt );
             break;
         }
 
         case SVX_CASEMAP_GEMEINE:
         {
-            aCharClass.toLower( aTxt );
+            aTxt = aCharClass.lowercase( aTxt );
             break;
         }
         case SVX_CASEMAP_TITEL:
@@ -155,7 +155,7 @@ XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
                     if( bBlank )
                     {
                         String aTemp( aTxt.GetChar( i ) );
-                        aCharClass.toUpper( aTemp );
+                        aTemp = aCharClass.uppercase( aTemp );
                         aTxt.Replace( i, 1, aTemp );
                     }
                     bBlank = sal_False;
@@ -199,6 +199,8 @@ public:
         : pOut(_pOut), rTxt(_rTxt), nIdx(_nIdx), nLen(_nLen)
         { }
 
+    virtual ~SvxDoCapitals() {}
+
     virtual void DoSpace( const sal_Bool bDraw );
     virtual void SetSpace();
     virtual void Do( const XubString &rTxt,
@@ -215,9 +217,6 @@ void SvxDoCapitals::DoSpace( const sal_Bool /*bDraw*/ ) { }
 
 void SvxDoCapitals::SetSpace() { }
 
-void SvxDoCapitals::Do( const XubString &/*_rTxt*/, const xub_StrLen /*_nIdx*/,
-    const xub_StrLen /*_nLen*/, const sal_Bool /*bUpper*/ ) { }
-
 /*************************************************************************
  *                  SvxFont::DoOnCapitals() const
  * Decomposes the String into uppercase and lowercase letters and then
@@ -478,37 +477,6 @@ Size SvxFont::GetTxtSize( const OutputDevice *pOut, const XubString &rTxt,
 }
 
 
-void SvxFont::DrawText( OutputDevice *pOut,
-               const Point &rPos, const XubString &rTxt,
-               const xub_StrLen nIdx, const xub_StrLen nLen ) const
-{
-    if( !nLen || !rTxt.Len() )  return;
-    xub_StrLen nTmp = nLen;
-    if ( nTmp == STRING_LEN )   // already initialized?
-        nTmp = rTxt.Len();
-    Point aPos( rPos );
-    if ( nEsc )
-    {
-        Size aSize = (this->GetSize());
-        aPos.Y() -= ((nEsc*long(aSize.Height()))/ 100L);
-    }
-    Font aOldFont( ChgPhysFont( pOut ) );
-
-    if ( IsCapital() )
-        DrawCapital( pOut, aPos, rTxt, nIdx, nTmp );
-    else
-    {
-        Size aSize = GetPhysTxtSize( pOut, rTxt, nIdx, nTmp );
-
-        if ( !IsCaseMap() )
-            pOut->DrawStretchText( aPos, aSize.Width(), rTxt, nIdx, nTmp );
-        else
-            pOut->DrawStretchText( aPos, aSize.Width(), CalcCaseMap( rTxt ),
-                                   nIdx, nTmp );
-    }
-    pOut->SetFont(aOldFont);
-}
-
 void SvxFont::QuickDrawText( OutputDevice *pOut,
     const Point &rPos, const XubString &rTxt,
     const xub_StrLen nIdx, const xub_StrLen nLen, const sal_Int32* pDXArray ) const
@@ -654,6 +622,8 @@ public:
               nKern( _nKrn )
             { }
 
+    virtual ~SvxDoGetCapitalSize() {}
+
     virtual void Do( const XubString &rTxt, const xub_StrLen nIdx,
                      const xub_StrLen nLen, const sal_Bool bUpper );
 
@@ -718,6 +688,7 @@ public:
           aSpacePos( rPos ),
           nKern( nKrn )
         { }
+    virtual ~SvxDoDrawCapital() {}
     virtual void DoSpace( const sal_Bool bDraw );
     virtual void SetSpace();
     virtual void Do( const XubString &rTxt, const xub_StrLen nIdx,
