@@ -221,10 +221,7 @@ BibFrameController_Impl::~BibFrameController_Impl()
 
 sal_Bool SAL_CALL BibFrameController_Impl::supportsService( const ::rtl::OUString& sServiceName ) throw (::com::sun::star::uno::RuntimeException)
 {
-    return (
-            sServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.frame.Bibliography")) ||
-            sServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.frame.Controller"))
-           );
+    return ( sServiceName == "com.sun.star.frame.Bibliography" || sServiceName == "com.sun.star.frame.Controller" );
 }
 
 ::com::sun::star::uno::Sequence< ::rtl::OUString > SAL_CALL BibFrameController_Impl::getSupportedServiceNames() throw (::com::sun::star::uno::RuntimeException)
@@ -406,7 +403,7 @@ sal_Bool BibFrameController_Impl::SaveModified(const Reference< form::runtime::X
                 _xCursor->updateRow();
             bResult = sal_True;
         }
-        catch(Exception&)
+        catch(const Exception&)
         {
             OSL_FAIL("SaveModified: Exception occurred!");
         }
@@ -450,7 +447,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
         else if(aCommand.EqualsAscii("Bib/sdbsource"))
         {
             rtl::OUString aURL = pDatMan->CreateDBChangeDialog(pParent);
-            if(aURL.getLength())
+            if(!aURL.isEmpty())
             {
                 try
                 {
@@ -563,7 +560,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                 {
                     FeatureStateEvent  aEvent;
                     aEvent.FeatureURL = pObj->aURL;
-                    aEvent.IsEnabled  = 0 != pDatMan->getParser()->getFilter().getLength();
+                    aEvent.IsEnabled  = !pDatMan->getParser()->getFilter().isEmpty();
                     aEvent.Requery    = sal_False;
                     aEvent.Source     = (XDispatch *) this;
                     pObj->xListener->statusChanged( aEvent );
@@ -574,8 +571,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
         {
             RemoveFilter();
         }
-        else if(_rURL.Complete.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("slot:5503")) ||
-                aCommand.EqualsAscii("CloseDoc"))
+        else if( _rURL.Complete == "slot:5503" || aCommand.EqualsAscii("CloseDoc") )
         {
             Application::PostUserEvent( STATIC_LINK( this, BibFrameController_Impl,
                                         DisposeHdl ), 0 );
@@ -594,7 +590,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                     Reference< XResultSetUpdate >  xUpdateCursor( pDatMan->getForm(), UNO_QUERY );
                     xUpdateCursor->moveToInsertRow();
                 }
-                catch(Exception&)
+                catch(const Exception&)
                 {
                     OSL_FAIL("Exception in last() or moveToInsertRow()");
                 }
@@ -634,7 +630,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                     if (bSuccess)
                         xUpdateCursor->deleteRow();
                 }
-                catch(Exception&)
+                catch(const Exception&)
                 {
                     bSuccess = sal_False;
                 }
@@ -654,7 +650,7 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                                 // Datensatz bewegen um Stati neu zu setzen
                                 xCursor->first();
                         }
-                        catch(Exception&)
+                        catch(const Exception&)
                         {
                             OSL_FAIL("DeleteRecord : exception caught !");
                         }
@@ -740,10 +736,10 @@ void BibFrameController_Impl::addStatusListener(
         uno::Sequence<rtl::OUString> aStringSeq=pDatMan->getDataSources();
         aEvent.State.setValue(&aStringSeq,::getCppuType((uno::Sequence<rtl::OUString>*)0));
     }
-    else if(aURL.Path == C2U("Bib/sdbsource") ||
-            aURL.Path == C2U("Bib/Mapping") ||
-            aURL.Path == C2U("Bib/autoFilter") ||
-            aURL.Path.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Bib/standardFilter")))
+    else if( aURL.Path == "Bib/sdbsource" ||
+             aURL.Path == "Bib/Mapping" ||
+             aURL.Path == "Bib/autoFilter" ||
+             aURL.Path == "Bib/standardFilter" )
     {
         aEvent.IsEnabled  = sal_True;
     }
@@ -755,7 +751,7 @@ void BibFrameController_Impl::addStatusListener(
     else if (aURL.Path == C2U("Bib/removeFilter") )
     {
         rtl::OUString aFilterStr=pDatMan->getFilter();
-        aEvent.IsEnabled  = (aFilterStr.getLength() > 0);
+        aEvent.IsEnabled  = !aFilterStr.isEmpty();
     }
     else if(aURL.Path == C2U("Cut"))
     {
@@ -800,7 +796,7 @@ void BibFrameController_Impl::addStatusListener(
                         uno::Any aData = xDataObj->getTransferData( aFlavor );
                         ::rtl::OUString aText;
                         aData >>= aText;
-                        aEvent.IsEnabled  = aText.getLength() > 0;
+                        aEvent.IsEnabled  = !aText.isEmpty();
                     }
                     catch( const uno::Exception& )
                     {
@@ -845,7 +841,7 @@ void BibFrameController_Impl::removeStatusListener(
             BibStatusDispatch *pObj = aStatusListeners[n];
             sal_Bool bFlag=pObj->xListener.is();
             if (!bFlag || (pObj->xListener == aObject &&
-                ( !aURL.Complete.getLength() || pObj->aURL.Path == aURL.Path  )))
+                ( aURL.Complete.isEmpty() || pObj->aURL.Path == aURL.Path  )))
             {
                 aStatusListeners.DeleteAndDestroy( n );
                 break;
