@@ -126,8 +126,13 @@ namespace pcr
         ::osl::MutexGuard aGuard( getMutex() );
         if ( !s_pNotifier.is() )
         {
-            s_pNotifier.set( new ::comphelper::AsyncEventNotifier );
-            s_pNotifier->create();
+            s_pNotifier.set(
+                new ::comphelper::AsyncEventNotifier("browserlistbox"));
+            s_pNotifier->launch();
+                //TODO: a protocol is missing how to join with the launched
+                // thread before exit(3), to ensure the thread is no longer
+                // relying on any infrastructure while that infrastructure is
+                // being shut down in atexit handlers
         }
         return s_pNotifier;
     }
@@ -1149,7 +1154,7 @@ namespace pcr
 
             if ( _rPropertyData.HasPrimaryButton )
             {
-                if ( _rPropertyData.PrimaryButtonImageURL.getLength() )
+                if ( !_rPropertyData.PrimaryButtonImageURL.isEmpty() )
                     rLine.pLine->ShowBrowseButton( _rPropertyData.PrimaryButtonImageURL, true );
                 else if ( _rPropertyData.PrimaryButtonImage.is() )
                     rLine.pLine->ShowBrowseButton( Image( _rPropertyData.PrimaryButtonImage ), true );
@@ -1158,7 +1163,7 @@ namespace pcr
 
                 if ( _rPropertyData.HasSecondaryButton )
                 {
-                    if ( _rPropertyData.SecondaryButtonImageURL.getLength() )
+                    if ( !_rPropertyData.SecondaryButtonImageURL.isEmpty() )
                         rLine.pLine->ShowBrowseButton( _rPropertyData.SecondaryButtonImageURL, false );
                     else if ( _rPropertyData.SecondaryButtonImage.is() )
                         rLine.pLine->ShowBrowseButton( Image( _rPropertyData.SecondaryButtonImage ), false );
