@@ -102,9 +102,11 @@ void xforms_booleanFromStringFunction(xmlXPathParserContextPtr ctxt, int nargs)
     xmlChar *pString = xmlXPathPopString(ctxt);
     if (xmlXPathCheckError(ctxt)) XP_ERROR(XPATH_INVALID_TYPE);
     ::rtl::OUString aString((char*)pString, strlen((char*)pString), RTL_TEXTENCODING_UTF8);
-    if (aString.equalsIgnoreAsciiCaseAscii("true") || aString.equalsIgnoreAsciiCaseAscii("1"))
+    if (aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("true")) ||
+        aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("1")))
         xmlXPathReturnTrue(ctxt);
-    else if (aString.equalsIgnoreAsciiCaseAscii("false") || aString.equalsIgnoreAsciiCaseAscii("0"))
+    else if (aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("false")) ||
+             aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("0")))
         xmlXPathReturnFalse(ctxt);
     else
         XP_ERROR(XPATH_NUMBER_ERROR);
@@ -232,9 +234,9 @@ void xforms_propertyFunction(xmlXPathParserContextPtr ctxt, int nargs)
     xmlChar* pString = xmlXPathPopString(ctxt);
     if (xmlXPathCheckError(ctxt)) XP_ERROR(XPATH_INVALID_TYPE);
     ::rtl::OUString aString((char*)pString, strlen((char*)pString), RTL_TEXTENCODING_UTF8);
-    if (aString.equalsIgnoreAsciiCaseAscii("version"))
+    if (aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("version")))
         xmlXPathReturnString(ctxt, (xmlChar*)_version);
-    else if (aString.equalsIgnoreAsciiCaseAscii("conformance-level"))
+    else if (aString.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("conformance-level")))
         xmlXPathReturnString(ctxt, (xmlChar*)_conformance);
     else
         xmlXPathReturnEmptyString(ctxt);
@@ -309,9 +311,6 @@ static sal_Bool parseDateTime(const ::rtl::OUString& aString, DateTime& aDateTim
     sal_Int32 nDateLength = 10;
     sal_Int32 nTimeLength = 8;
 
-    ::rtl::OUString aDateTimeSep(RTL_CONSTASCII_USTRINGPARAM("T"));
-    ::rtl::OUString aDateSep(RTL_CONSTASCII_USTRINGPARAM("-"));
-    ::rtl::OUString aTimeSep(RTL_CONSTASCII_USTRINGPARAM(":"));
     ::rtl::OUString aUTCString(RTL_CONSTASCII_USTRINGPARAM("Z"));
 
     ::rtl::OUString aDateString = aDateTimeString.copy(0, nDateLength);
@@ -528,7 +527,7 @@ void xforms_instanceFuction(xmlXPathParserContextPtr ctxt, int nargs)
                 xmlNodePtr pNode = reinterpret_cast< xmlNodePtr >( aTunnel->getSomething(Sequence< sal_Int8 >()) );
                 xmlXPathObjectPtr pObject = xmlXPathNewNodeSet(pNode);
                 xmlXPathReturnNodeSet(ctxt, pObject->nodesetval);
-            } catch (RuntimeException&)
+            } catch (const RuntimeException&)
             {
                 xmlXPathReturnEmptyNodeSet(ctxt);
             }
@@ -556,7 +555,7 @@ void xforms_currentFunction(xmlXPathParserContextPtr ctxt, int nargs)
             xmlXPathObjectPtr pObject = xmlXPathNewNodeSet(pNode);
             xmlXPathReturnNodeSet(ctxt, pObject->nodesetval);
         }
-        catch (RuntimeException&)
+        catch (const RuntimeException&)
         {
             xmlXPathReturnEmptyNodeSet(ctxt);
         }
