@@ -130,7 +130,6 @@ static const sal_Int32 ITEM_DESCRIPTOR_VISIBLE_LEN     = RTL_CONSTASCII_LENGTH(I
 static const sal_Int32 ITEM_DESCRIPTOR_WIDTH_LEN       = RTL_CONSTASCII_LENGTH(ITEM_DESCRIPTOR_WIDTH);
 static const sal_Int32 ITEM_DESCRIPTOR_STYLE_LEN       = RTL_CONSTASCII_LENGTH(ITEM_DESCRIPTOR_STYLE);
 
-static const char   HELPID_PREFIX[]                 = "helpid:";
 static const char   HELPID_PREFIX_TESTTOOL[]        = ".HelpId:";
 static const sal_uInt16 STARTID_CUSTOMIZE_POPUPMENU     = 1000;
 
@@ -190,7 +189,7 @@ static ::com::sun::star::uno::Reference< ::com::sun::star::frame::XLayoutManager
     {
         try
         {
-            xPropSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" ))) >>= xLayoutManager;
+            xPropSet->getPropertyValue( ::rtl::OUString( "LayoutManager" )) >>= xLayoutManager;
         }
         catch (const RuntimeException&)
         {
@@ -281,11 +280,10 @@ ToolBarManager::ToolBarManager( const Reference< XMultiServiceFactory >& rServic
     // enables a menu for clipped items and customization
     SvtCommandOptions aCmdOptions;
     sal_uInt16 nMenuType = TOOLBOX_MENUTYPE_CLIPPEDITEMS;
-    if ( !aCmdOptions.Lookup( SvtCommandOptions::CMDOPTION_DISABLED, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("CreateDialog"))))
+    if ( !aCmdOptions.Lookup( SvtCommandOptions::CMDOPTION_DISABLED, ::rtl::OUString("CreateDialog")))
          nMenuType |= TOOLBOX_MENUTYPE_CUSTOMIZE;
-    //added for issue33668 by shizhoubo
+
     m_pToolBar->SetCommandHdl( LINK( this, ToolBarManager, Command ) );
-    //end
     m_pToolBar->SetMenuType( nMenuType );
     m_pToolBar->SetMenuButtonHdl( LINK( this, ToolBarManager, MenuButton ) );
     m_pToolBar->GetMenu()->SetSelectHdl( LINK( this, ToolBarManager, MenuSelect ) );
@@ -423,9 +421,9 @@ void ToolBarManager::UpdateImageOrientation()
         Sequence< rtl::OUString > aSeqMirrorCmd;
         Sequence< rtl::OUString > aSeqRotateCmd;
         m_xUICommandLabels->getByName(
-            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( UICOMMANDDESCRIPTION_NAMEACCESS_COMMANDMIRRORIMAGELIST ))) >>= aSeqMirrorCmd;
+            rtl::OUString( UICOMMANDDESCRIPTION_NAMEACCESS_COMMANDMIRRORIMAGELIST )) >>= aSeqMirrorCmd;
         m_xUICommandLabels->getByName(
-            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( UICOMMANDDESCRIPTION_NAMEACCESS_COMMANDROTATEIMAGELIST ))) >>= aSeqRotateCmd;
+            rtl::OUString( UICOMMANDDESCRIPTION_NAMEACCESS_COMMANDROTATEIMAGELIST )) >>= aSeqRotateCmd;
 
         CommandToInfoMap::iterator pIter;
         for ( i = 0; i < aSeqMirrorCmd.getLength(); i++ )
@@ -478,7 +476,7 @@ void ToolBarManager::UpdateControllers()
         Reference< XLayoutManager > xLayoutManager;
         Reference< XPropertySet > xFramePropSet( m_xFrame, UNO_QUERY );
         if ( xFramePropSet.is() )
-            a = xFramePropSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" )));
+            a = xFramePropSet->getPropertyValue( ::rtl::OUString( "LayoutManager" ));
         a >>= xLayoutManager;
         Reference< XDockableWindow > xDockable( VCLUnoHelper::GetInterface( m_pToolBar ), UNO_QUERY );
         if ( xLayoutManager.is() && xDockable.is() )
@@ -511,7 +509,8 @@ void ToolBarManager::UpdateControllers()
     }
     m_bUpdateControllers = sal_False;
 }
-//for update toolbar controller via Support Visible by shizhoubo
+
+//for update toolbar controller via Support Visible
 void ToolBarManager::UpdateController( ::com::sun::star::uno::Reference< ::com::sun::star::frame::XToolbarController > xController)
 {
     RTL_LOGFILE_CONTEXT( aLog, "framework (cd100003) ::ToolBarManager::UpdateControllers" );
@@ -535,7 +534,7 @@ void ToolBarManager::UpdateController( ::com::sun::star::uno::Reference< ::com::
     }
     m_bUpdateControllers = sal_False;
 }
-//end
+
 void ToolBarManager::frameAction( const FrameActionEvent& Action )
 throw ( RuntimeException )
 {
@@ -551,7 +550,7 @@ throw ( ::com::sun::star::uno::RuntimeException )
     if ( m_bDisposed )
         return;
 
-    if ( Event.FeatureURL.Complete.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(".uno:ImageOrientation")) )
+    if ( Event.FeatureURL.Complete == ".uno:ImageOrientation" )
     {
         SfxImageItem aItem( 1, 0 );
         aItem.PutValue( Event.State );
@@ -846,7 +845,7 @@ uno::Sequence< beans::PropertyValue > ToolBarManager::GetPropsForCommand( const
             m_bModuleIdentified = sal_True;
             m_aModuleIdentifier = xModuleManager->identify( xIfac );
 
-            if ( m_aModuleIdentifier.getLength() > 0 )
+            if ( !m_aModuleIdentifier.isEmpty() )
             {
                 Reference< XNameAccess > xNameAccess( m_xServiceManager->createInstance( SERVICENAME_UICOMMANDDESCRIPTION ), UNO_QUERY );
                 if ( xNameAccess.is() )
@@ -856,7 +855,7 @@ uno::Sequence< beans::PropertyValue > ToolBarManager::GetPropsForCommand( const
 
         if ( m_xUICommandLabels.is() )
         {
-            if ( rCmdURL.getLength() > 0 )
+            if ( !rCmdURL.isEmpty() )
                 m_xUICommandLabels->getByName( rCmdURL ) >>= aPropSeq;
         }
     }
@@ -876,7 +875,7 @@ uno::Sequence< beans::PropertyValue > ToolBarManager::GetPropsForCommand( const
     aPropSeq = GetPropsForCommand( aCmdURL );
     for ( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
     {
-        if ( aPropSeq[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Name")) )
+        if ( aPropSeq[i].Name == "Name" )
         {
             aPropSeq[i].Value >>= aLabel;
             break;
@@ -894,7 +893,7 @@ sal_Int32 ToolBarManager::RetrievePropertiesFromCommand( const ::rtl::OUString&
     aPropSeq = GetPropsForCommand( aCmdURL );
     for ( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
     {
-        if ( aPropSeq[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Properties")) )
+        if ( aPropSeq[i].Name == "Properties" )
         {
             aPropSeq[i].Value >>= nProperties;
             break;
@@ -917,7 +916,7 @@ void ToolBarManager::CreateControllers()
     SvtCommandOptions   aCmdOptions;
 
     if ( xProps.is() )
-        xProps->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ))) >>= xComponentContext;
+        xProps->getPropertyValue( rtl::OUString( "DefaultContext" )) >>= xComponentContext;
 
     for ( sal_uInt16 i = 0; i < m_pToolBar->GetItemCount(); i++ )
     {
@@ -925,7 +924,7 @@ void ToolBarManager::CreateControllers()
         if ( nId == 0 )
             continue;
 
-        rtl::OUString                aLoadURL( RTL_CONSTASCII_USTRINGPARAM( ".uno:OpenUrl" ));
+        rtl::OUString                aLoadURL( ".uno:OpenUrl" );
         rtl::OUString                aCommandURL( m_pToolBar->GetItemCommand( nId ));
         sal_Bool                     bInit( sal_True );
         sal_Bool                     bCreate( sal_True );
@@ -955,22 +954,22 @@ void ToolBarManager::CreateControllers()
                 PropertyValue aPropValue;
                 std::vector< Any > aPropertyVector;
 
-                aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ModuleName" ));
+                aPropValue.Name     = rtl::OUString( "ModuleName" );
                 aPropValue.Value    <<= m_aModuleIdentifier;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Frame" ));
+                aPropValue.Name     = rtl::OUString( "Frame" );
                 aPropValue.Value    <<= m_xFrame;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ServiceManager" ));
+                aPropValue.Name     = rtl::OUString( "ServiceManager" );
                 aPropValue.Value    <<= m_xServiceManager;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ParentWindow" ));
+                aPropValue.Name     = rtl::OUString( "ParentWindow" );
                 aPropValue.Value    <<= xToolbarWindow;
                 aPropertyVector.push_back( makeAny( aPropValue ));
 
                 if ( nWidth > 0 )
                 {
-                    aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Width" ));
+                    aPropValue.Name     = rtl::OUString( "Width" );
                     aPropValue.Value    <<= nWidth;
                     aPropertyVector.push_back( makeAny( aPropValue ));
                 }
@@ -1040,7 +1039,7 @@ void ToolBarManager::CreateControllers()
         if ( xSubToolBar.is() && xSubToolBar->opensSubToolbar() )
         {
             rtl::OUString aSubToolBarName = xSubToolBar->getSubToolbarName();
-            if ( aSubToolBarName.getLength() != 0 )
+            if ( !aSubToolBarName.isEmpty() )
             {
                 SubToolBarToSubToolBarControllerMap::iterator pIter =
                     m_aSubToolBarControllerMap.find( aSubToolBarName );
@@ -1065,43 +1064,41 @@ void ToolBarManager::CreateControllers()
                 PropertyValue aPropValue;
                 std::vector< Any > aPropertyVector;
 
-                aPropValue.Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Frame" ));
+                aPropValue.Name = ::rtl::OUString( "Frame" );
                 aPropValue.Value <<= m_xFrame;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "CommandURL" ));
+                aPropValue.Name = ::rtl::OUString( "CommandURL" );
                 aPropValue.Value <<= aCommandURL;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ServiceManager" ));
+                aPropValue.Name = ::rtl::OUString( "ServiceManager" );
                 aPropValue.Value <<= m_xServiceManager;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ParentWindow" ));
+                aPropValue.Name = rtl::OUString( "ParentWindow" );
                 aPropValue.Value <<= xToolbarWindow;
                 aPropertyVector.push_back( makeAny( aPropValue ));
-                aPropValue.Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ModuleName" ));
+                aPropValue.Name = rtl::OUString( "ModuleName" );
                 aPropValue.Value <<= m_aModuleIdentifier;
                 aPropertyVector.push_back( makeAny( aPropValue ));
 
                 if ( nWidth > 0 )
                 {
-                    aPropValue.Name     = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Width" ));
+                    aPropValue.Name     = rtl::OUString( "Width" );
                     aPropValue.Value    <<= nWidth;
                     aPropertyVector.push_back( makeAny( aPropValue ));
                 }
 
                 Sequence< Any > aArgs( comphelper::containerToSequence( aPropertyVector ));
                 xInit->initialize( aArgs );
-                //for Support Visiblitly by shizhoubo
+
                 if (pController)
                 {
-                    if(aCommandURL == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:SwitchXFormsDesignMode" )) ||
-                       aCommandURL == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ViewDataSourceBrowser" )) ||
-                       aCommandURL == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ParaLeftToRight" )) ||
-                       aCommandURL == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ParaRightToLeft" ))
+                    if(aCommandURL == rtl::OUString( ".uno:SwitchXFormsDesignMode" ) ||
+                       aCommandURL == rtl::OUString( ".uno:ViewDataSourceBrowser" ) ||
+                       aCommandURL == rtl::OUString( ".uno:ParaLeftToRight" ) ||
+                       aCommandURL == rtl::OUString( ".uno:ParaRightToLeft" )
                        )
                         pController->setFastPropertyValue_NoBroadcast(1,makeAny(sal_True));
                 }
-
-                //end
             }
 
             // Request a item window from the toolbar controller and set it at the VCL toolbar
@@ -1122,14 +1119,15 @@ void ToolBarManager::CreateControllers()
                 }
             }
         }
-        //for update Controller via support visiable state by shizhoubo
+
+        //for update Controller via support visiable state
         Reference< XPropertySet > xPropSet( xController, UNO_QUERY );
         if ( xPropSet.is() )
         {
             try
             {
                 sal_Bool bSupportVisible = sal_True;
-                Any a( xPropSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SupportsVisible" ))) );
+                Any a( xPropSet->getPropertyValue( ::rtl::OUString( "SupportsVisible" )) );
                 a >>= bSupportVisible;
                 if (bSupportVisible)
                 {
@@ -1145,8 +1143,6 @@ void ToolBarManager::CreateControllers()
             {
             }
         }
-        //end
-
     }
 
     AddFrameActionListener();
@@ -1175,7 +1171,7 @@ void ToolBarManager::AddImageOrientationListener()
         m_xImageOrientationListener = Reference< XComponent >( static_cast< ::cppu::OWeakObject *>(
                                         pImageOrientation ), UNO_QUERY );
         pImageOrientation->addStatusListener(
-            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ImageOrientation" )));
+            rtl::OUString( ".uno:ImageOrientation" ));
         pImageOrientation->bindListener();
     }
 }
@@ -1216,7 +1212,6 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
         return;
 
     sal_uInt16    nId( 1 );
-    ::rtl::OUString  aHelpIdPrefix( RTL_CONSTASCII_USTRINGPARAM( HELPID_PREFIX ));
 
     Reference< XModuleManager > xModuleManager( Reference< XModuleManager >(
                                                     m_xServiceManager->createInstance( SERVICENAME_MODULEMANAGER ), UNO_QUERY ));
@@ -1286,7 +1281,7 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
             {
                 for ( int i = 0; i < aProp.getLength(); i++ )
                 {
-                    if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_COMMANDURL)) )
+                    if ( aProp[i].Name == ITEM_DESCRIPTOR_COMMANDURL )
                     {
                         aProp[i].Value >>= aCommandURL;
                         if ( aCommandURL.compareToAscii(MENUPREFIX, RTL_CONSTASCII_LENGTH(MENUPREFIX) ) == 0  )
@@ -1307,7 +1302,7 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
                                     xMenuContainer->getByIndex(0) >>= aProps;
                                     for ( sal_Int32 index=0; index<aProps.getLength(); ++index )
                                     {
-                                        if ( aProps[ index ].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_CONTAINER)) )
+                                        if ( aProps[ index ].Name == ITEM_DESCRIPTOR_CONTAINER )
 
                                         {
                                             aProps[ index ].Value >>= aMenuDesc;
@@ -1321,23 +1316,23 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
                             }
                         }
                     }
-                    else if (  aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_HELPURL)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_HELPURL )
                         aProp[i].Value >>= aHelpURL;
-                    else if (  aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_TOOLTIP)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_TOOLTIP )
                         aProp[i].Value >>= aTooltip;
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_LABEL)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_LABEL )
                         aProp[i].Value >>= aLabel;
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_TYPE)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_TYPE )
                         aProp[i].Value >>= nType;
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_VISIBLE)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_VISIBLE )
                         aProp[i].Value >>= bIsVisible;
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_WIDTH)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_WIDTH )
                         aProp[i].Value >>= nWidth;
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_STYLE)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_STYLE )
                         aProp[i].Value >>= nStyle;
                 }
 
-                if (( nType == ::com::sun::star::ui::ItemType::DEFAULT ) && ( aCommandURL.getLength() > 0 ))
+                if (( nType == ::com::sun::star::ui::ItemType::DEFAULT ) && !aCommandURL.isEmpty() )
                 {
                     ::rtl::OUString aString( RetrieveLabelFromCommand( aCommandURL ));
 
@@ -1346,7 +1341,7 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
                         m_aMenuMap[ nId ] = aMenuDesc;
                     m_pToolBar->InsertItem( nId, aString, nItemBits );
                     m_pToolBar->SetItemCommand( nId, aCommandURL );
-                    if ( aTooltip.getLength() )
+                    if ( !aTooltip.isEmpty() )
                     {
                         m_pToolBar->SetQuickHelpText( nId, aTooltip );
                     }
@@ -1356,15 +1351,15 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
                          ::rtl::OUString sShortCut;
                          if( RetrieveShortcut( aCommandURL, sShortCut ) )
                          {
-                             sQuickHelp += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( " (" ) );
+                             sQuickHelp += rtl::OUString( " ("  );
                              sQuickHelp += sShortCut;
-                             sQuickHelp += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ")" ) );
+                             sQuickHelp += rtl::OUString( ")" );
                          }
 
                         m_pToolBar->SetQuickHelpText( nId, sQuickHelp );
                     }
 
-                    if ( aLabel.getLength() > 0 )
+                    if ( !aLabel.isEmpty() )
                     {
                         m_pToolBar->SetItemText( nId, aLabel );
                     }
@@ -1497,8 +1492,8 @@ void ToolBarManager::FillToolbar( const Reference< XIndexAccess >& rItemContaine
         try
         {
             rtl::OUString aUIName;
-            xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "UIName" ))) >>= aUIName;
-            if ( aUIName.getLength() > 0 )
+            xPropSet->getPropertyValue( rtl::OUString( "UIName" )) >>= aUIName;
+            if ( !aUIName.isEmpty() )
                 m_pToolBar->SetText( aUIName );
         }
         catch (const Exception&)
@@ -1617,12 +1612,12 @@ long ToolBarManager::HandleClick(void ( SAL_CALL XToolbarController::*_pClick )(
     return 1;
 }
 
-IMPL_LINK( ToolBarManager, Click, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, Click)
 {
     return HandleClick(&XToolbarController::click);
 }
 
-IMPL_LINK( ToolBarManager, DropdownClick, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, DropdownClick)
 {
     ResetableGuard aGuard( m_aLock );
 
@@ -1645,7 +1640,7 @@ IMPL_LINK( ToolBarManager, DropdownClick, ToolBox*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( ToolBarManager, DoubleClick, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, DoubleClick)
 {
     return HandleClick(&XToolbarController::doubleClick);
 }
@@ -1728,7 +1723,6 @@ bool ToolBarManager::MenuItemAllowed( sal_uInt16 ) const
     return true;
 }
 
-//added for i33668 by shizhoubo : 200804
 PopupMenu * ToolBarManager::GetToolBarCustomMenu(ToolBox* pToolBar)
 {
     // update the list of hidden tool items first
@@ -1743,7 +1737,7 @@ PopupMenu * ToolBarManager::GetToolBarCustomMenu(ToolBox* pToolBar)
     if ( m_xFrame.is() )
     {
         Reference< XDispatchProvider > xProv( m_xFrame, UNO_QUERY );
-        aURL.Complete = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ConfigureDialog" ));
+        aURL.Complete = ::rtl::OUString( ".uno:ConfigureDialog" );
         m_xURLTransformer->parseStrict( aURL );
         if ( xProv.is() )
             xDisp = xProv->queryDispatch( aURL, ::rtl::OUString(), 0 );
@@ -1787,13 +1781,8 @@ PopupMenu * ToolBarManager::GetToolBarCustomMenu(ToolBox* pToolBar)
         }
 
         // Disable menu item CLOSE if the toolbar has no closer
-        //added for issue64028  by shizhoubo
         if( !(pToolBar->GetFloatStyle() & WB_CLOSEABLE) )
             aPopupMenu.EnableItem(MENUITEM_TOOLBAR_CLOSE, sal_False);
-        //end
-
-        pItemMenu->SetMenuFlags (pItemMenu->GetMenuFlags () |
-                                 MENU_FLAG_SHOWCHECKIMAGES);
 
         for ( nPos = 0; nPos < m_pToolBar->GetItemCount(); ++nPos )
         {
@@ -1839,9 +1828,6 @@ PopupMenu * ToolBarManager::GetToolBarCustomMenu(ToolBox* pToolBar)
         // create an own submenu to avoid auto-delete when resource menu is deleted
         PopupMenu *pItemMenu = new PopupMenu();
 
-        pItemMenu->SetMenuFlags (pItemMenu->GetMenuFlags () |
-                                 MENU_FLAG_SHOWCHECKIMAGES);
-
         for( i=0; i< aPopupMenu.GetPopupMenu( 1 )->GetItemCount(); i++)
             pItemMenu->CopyItem( *aPopupMenu.GetPopupMenu( 1 ), i, MENU_APPEND );
 
@@ -1854,7 +1840,6 @@ PopupMenu * ToolBarManager::GetToolBarCustomMenu(ToolBox* pToolBar)
     return pMenu;
 }
 
-// addd for 33668  by shizhoubo
 IMPL_LINK( ToolBarManager, Command, CommandEvent*, pCmdEvt )
 {
     ResetableGuard aGuard( m_aLock );
@@ -1875,7 +1860,6 @@ IMPL_LINK( ToolBarManager, Command, CommandEvent*, pCmdEvt )
 
     return 0;
 }
-//end
 
 IMPL_LINK( ToolBarManager, MenuButton, ToolBox*, pToolBar )
 {
@@ -1883,10 +1867,12 @@ IMPL_LINK( ToolBarManager, MenuButton, ToolBox*, pToolBar )
 
     if ( m_bDisposed )
         return 1;
-    //modify for i33668 by shizhoubo:2008:04
-    GetToolBarCustomMenu(pToolBar);
-    //end
-     return 0;
+
+    pToolBar->UpdateCustomMenu();
+    // remove all entries that do not come from the toolbar itself (fdo#38276)
+    ImplClearPopupMenu( pToolBar );
+
+    return 0;
  }
 
 IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
@@ -1912,7 +1898,7 @@ IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
                 if ( m_xFrame.is() )
                 {
                     Reference< XDispatchProvider > xProv( m_xFrame, UNO_QUERY );
-                    aURL.Complete = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:ConfigureDialog" ));
+                    aURL.Complete = ::rtl::OUString( ".uno:ConfigureDialog" );
                     m_xURLTransformer->parseStrict( aURL );
                     if ( xProv.is() )
                         xDisp = xProv->queryDispatch( aURL, ::rtl::OUString(), 0 );
@@ -1923,7 +1909,7 @@ IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
                     Sequence< PropertyValue > aPropSeq( 1 );
 
                     aPropSeq[ 0 ].Name =
-                        rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("ResourceURL"));
+                        rtl::OUString( "ResourceURL");
                     aPropSeq[ 0 ].Value <<= m_aResourceName;
 
                     xDisp->dispatch( aURL, aPropSeq );
@@ -2009,11 +1995,11 @@ IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
                                 {
                                     for ( sal_Int32 j = 0; j < aProp.getLength(); j++ )
                                     {
-                                        if ( aProp[j].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_COMMANDURL)) )
+                                        if ( aProp[j].Name == ITEM_DESCRIPTOR_COMMANDURL )
                                         {
                                             aProp[j].Value >>= aCommandURL;
                                         }
-                                        else if ( aProp[j].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_VISIBLE)) )
+                                        else if ( aProp[j].Name == ITEM_DESCRIPTOR_VISIBLE )
                                         {
                                             aProp[j].Value >>= bVisible;
                                             nVisibleIndex = j;
@@ -2033,7 +2019,7 @@ IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
                                             if ( xPropSet.is() )
                                             {
                                                 Reference< XUIConfigurationPersistence > xUICfgMgr;
-                                                if (( xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("ConfigurationSource" ))) >>= xUICfgMgr ) && ( xUICfgMgr.is() ))
+                                                if (( xPropSet->getPropertyValue( rtl::OUString( "ConfigurationSource" )) >>= xUICfgMgr ) && ( xUICfgMgr.is() ))
                                                     xUICfgMgr->store();
                                             }
                                         }
@@ -2060,7 +2046,7 @@ IMPL_LINK( ToolBarManager, MenuSelect, Menu*, pMenu )
     return 1;
 }
 
-IMPL_LINK( ToolBarManager, Select, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, Select)
 {
     if ( m_bDisposed )
         return 1;
@@ -2080,12 +2066,12 @@ IMPL_LINK( ToolBarManager, Select, ToolBox*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( ToolBarManager, Activate, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, Activate)
 {
     return 1;
 }
 
-IMPL_LINK( ToolBarManager, Deactivate, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, Deactivate)
 {
     return 1;
 }
@@ -2143,13 +2129,13 @@ IMPL_LINK( ToolBarManager, DataChanged, DataChangedEvent*, pDataChangedEvent  )
     return 1;
 }
 
-IMPL_LINK(ToolBarManager, MiscOptionsChanged, void*, EMPTYARG)
+IMPL_LINK_NOARG(ToolBarManager, MiscOptionsChanged)
 {
     CheckAndUpdateImages();
     return 0;
 }
 
-IMPL_LINK( ToolBarManager, AsyncUpdateControllersHdl, Timer *, EMPTYARG )
+IMPL_LINK_NOARG(ToolBarManager, AsyncUpdateControllersHdl)
 {
     // The guard must be in its own context as the we can get destroyed when our
     // own xInterface reference get destroyed!
@@ -2176,7 +2162,7 @@ IMPL_STATIC_LINK_NOINSTANCE( ToolBarManager, ExecuteHdl_Impl, ExecuteInfo*, pExe
             ( pExecuteInfo->xLayoutManager.is() ) &&
             ( pExecuteInfo->xWindow.is() ))
         {
-            // Use docking window close to close the toolbar. The layout manager is
+            // Use docking window close to close the toolbar. The toolbar layout manager is
             // listener and will react correctly according to the context sensitive
             // flag of our toolbar.
             Window* pWin = VCLUnoHelper::GetWindow( pExecuteInfo->xWindow );
