@@ -30,7 +30,7 @@
 
 #include <comphelper/newarray.hxx>
 
-#include "list.hxx"
+#include <list>
 
 #include "hwpfile.h"
 #include "hbox.h"
@@ -309,7 +309,7 @@ int TxtBox::Read(HWPFile & hwpf)
     }
     if (ncell == 1)
         style.cell = &cell[0];
-    plists = ::comphelper::newArray_null< LinkedList< HWPPara > >(ncell);
+    plists = ::comphelper::newArray_null< std::list< HWPPara* > >(ncell);
     if (!plists) {
         return hwpf.SetState(HWP_InvalidFileFormat);
     }
@@ -363,7 +363,7 @@ int TxtBox::Read(HWPFile & hwpf)
                 }
           }
           for( ii = 0 ; ii < ncell ; ii++ ){
-                tbl->cells.insert(pArr[ii]);
+                tbl->cells.push_back(pArr[ii]);
           }
           tbl->box = this;
           hwpf.AddTable(tbl);
