@@ -130,8 +130,7 @@ const std::vector<LayoutAtomPtr>& ConditionAtom::getChildren() const
 {
     bool bDecisionVar=true;
     // HACK
-    if( maCond.mnFunc==XML_var && maCond.mnArg==XML_dir &&
-        maCond.mnOp==XML_equ && !maCond.msVal.equalsAscii("norm") )
+    if( maCond.mnFunc == XML_var && maCond.mnArg == XML_dir && maCond.mnOp == XML_equ && maCond.msVal != "norm" )
         bDecisionVar=false;
 
     if( bDecisionVar )
@@ -394,8 +393,8 @@ bool LayoutNode::setupShape( const ShapePtr& rShape, const Diagram& rDgm, sal_uI
 {
     // find the data node to grab text from
     DiagramData::PointsNameMap::const_iterator aDataNode=rDgm.getData()->getPointsPresNameMap().find(msName);
-    if( aDataNode->second.size() > nIdx &&
-        aDataNode != rDgm.getData()->getPointsPresNameMap().end() )
+    if( aDataNode != rDgm.getData()->getPointsPresNameMap().end() &&
+        aDataNode->second.size() > nIdx )
     {
         OSL_TRACE( "Filling content from %d th layout node named \"%s\", modelId \"%s\"",
                    nIdx,
@@ -468,7 +467,7 @@ bool LayoutNode::setupShape( const ShapePtr& rShape, const Diagram& rDgm, sal_uI
         // TODO(Q1): apply styling & coloring - taking
         // layout node's styleLbl for both style & color
         // now, but docs are a bit unclear on this
-        if( msStyleLabel.getLength() )
+        if( !msStyleLabel.isEmpty() )
         {
             OSL_TRACE("setting style with label %s",
                       OUSTRING_TO_CSTR( msStyleLabel ) );
