@@ -130,6 +130,16 @@ static void call_callbackCharacters( void *userData , const XML_Char *s , int nL
     pFastParser->callbackCharacters( s, nLen );
 }
 
+static void call_callbackEntityDecl(void *userData, const XML_Char *entityName,
+        int is_parameter_entity, const XML_Char *value, int value_length,
+        const XML_Char *base, const XML_Char *systemId,
+        const XML_Char *publicId, const XML_Char *notationName)
+{
+    FastSaxParser* pFastParser = reinterpret_cast<FastSaxParser*>(userData);
+    pFastParser->callbackEntityDecl(entityName, is_parameter_entity, value,
+            value_length, base, systemId, publicId, notationName);
+}
+
 static int call_callbackExternalEntityRef( XML_Parser parser,
         const XML_Char *openEntityNames, const XML_Char *base, const XML_Char *systemId, const XML_Char *publicId )
 {
@@ -443,21 +453,22 @@ void FastSaxParser::parseStream( const InputSource& maStructSource) throw (SAXEx
     entity.maStructSource = maStructSource;
 
     if( !entity.maStructSource.aInputStream.is() )
-        throw SAXException( OUString( RTL_CONSTASCII_USTRINGPARAM( "No input source" ) ), Reference< XInterface >(), Any() );
+        throw SAXException( OUString(  "No input source" ), Reference< XInterface >(), Any() );
 
     entity.maConverter.setInputStream( entity.maStructSource.aInputStream );
-    if( entity.maStructSource.sEncoding.getLength() )
+    if( !entity.maStructSource.sEncoding.isEmpty() )
         entity.maConverter.setEncoding( OUStringToOString( entity.maStructSource.sEncoding, RTL_TEXTENCODING_ASCII_US ) );
 
     // create parser with proper encoding
     entity.mpParser = XML_ParserCreate( 0 );
     if( !entity.mpParser )
-        throw SAXException( OUString( RTL_CONSTASCII_USTRINGPARAM( "Couldn't create parser" ) ), Reference< XInterface >(), Any() );
+        throw SAXException( OUString( "Couldn't create parser" ), Reference< XInterface >(), Any() );
 
     // set all necessary C-Callbacks
     XML_SetUserData( entity.mpParser, this );
     XML_SetElementHandler( entity.mpParser, call_callbackStartElement, call_callbackEndElement );
     XML_SetCharacterDataHandler( entity.mpParser, call_callbackCharacters );
+    XML_SetEntityDeclHandler(entity.mpParser, call_callbackEntityDecl);
     XML_SetExternalEntityRefHandler( entity.mpParser, call_callbackExternalEntityRef );
 
     pushEntity( entity );
@@ -555,14 +566,14 @@ void FastSaxParser::setLocale( const Locale & Locale ) throw (RuntimeException)
 Sequence< OUString > FastSaxParser::getSupportedServiceNames_Static(void)
 {
     Sequence<OUString> aRet(1);
-    aRet.getArray()[0] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(PARSER_SERVICE_NAME) );
+    aRet.getArray()[0] = ::rtl::OUString( PARSER_SERVICE_NAME );
     return aRet;
 }
 
 // XServiceInfo
 OUString FastSaxParser::getImplementationName() throw (RuntimeException)
 {
-    return OUString(RTL_CONSTASCII_USTRINGPARAM( PARSER_IMPLEMENTATION_NAME ));
+    return OUString( PARSER_IMPLEMENTATION_NAME );
 }
 
 // XServiceInfo
@@ -583,7 +594,7 @@ Sequence< OUString > FastSaxParser::getSupportedServiceNames(void) throw (Runtim
 {
 
     Sequence<OUString> seq(1);
-    seq.getArray()[0] = OUString(RTL_CONSTASCII_USTRINGPARAM( PARSER_SERVICE_NAME ));
+    seq.getArray()[0] = OUString( PARSER_SERVICE_NAME );
     return seq;
 }
 
@@ -776,7 +787,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
         // #158414# second: fill attribute list with other attributes
         for( ::std::vector< AttributeData >::const_iterator aIt = aAttribs.begin(), aEnd = aAttribs.end(); aIt != aEnd; ++aIt )
         {
-            if( aIt->maPrefix.getLength() > 0 )
+            if( !aIt->maPrefix.isEmpty() )
             {
                 sal_Int32 nAttributeToken = GetTokenWithPrefix( aIt->maPrefix, aIt->maName );
                 if( nAttributeToken != FastToken::DONTKNOW )
@@ -798,7 +809,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
         splitName( pwName, pPrefix, nPrefixLen, pName, nNameLen );
         if( nPrefixLen > 0 )
             nElementToken = GetTokenWithPrefix( pPrefix, nPrefixLen, pName, nNameLen );
-        else if( rEntity.maContextStack.top()->maNamespace.getLength() > 0 )
+        else if( !rEntity.maContextStack.top()->maNamespace.isEmpty() )
             nElementToken = GetTokenWithNamespaceURL( rEntity.maContextStack.top()->maNamespace, pName, nNameLen );
         else
             nElementToken = GetToken( pName );
@@ -847,7 +858,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
     }
 }
 
-void FastSaxParser::callbackEndElement( const XML_Char* )
+void FastSaxParser::callbackEndElement( SAL_UNUSED_PARAMETER const XML_Char* )
 {
     Entity& rEntity = getEntity();
     OSL_ENSURE( !rEntity.maContextStack.empty(), "FastSaxParser::callbackEndElement - no context" );
@@ -887,8 +898,35 @@ void FastSaxParser::callbackCharacters( const XML_Char* s, int nLen )
     }
 }
 
-int FastSaxParser::callbackExternalEntityRef( XML_Parser parser,
-        const XML_Char *context, const XML_Char * /*base*/, const XML_Char *systemId, const XML_Char *publicId )
+void FastSaxParser::callbackEntityDecl(
+    SAL_UNUSED_PARAMETER const XML_Char * /*entityName*/,
+    SAL_UNUSED_PARAMETER int /*is_parameter_entity*/,
+    const XML_Char *value, SAL_UNUSED_PARAMETER int /*value_length*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*base*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*systemId*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*publicId*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*notationName*/)
+{
+    if (value) { // value != 0 means internal entity
+        OSL_TRACE("FastSaxParser: internal entity declaration, stopping");
+        XML_StopParser(getEntity().mpParser, XML_FALSE);
+        getEntity().maSavedException <<= SAXParseException(
+            ::rtl::OUString(
+                    "FastSaxParser: internal entity declaration, stopping"),
+            static_cast<OWeakObject*>(this), Any(),
+            mxDocumentLocator->getPublicId(),
+            mxDocumentLocator->getSystemId(),
+            mxDocumentLocator->getLineNumber(),
+            mxDocumentLocator->getColumnNumber() );
+    } else {
+        OSL_TRACE("FastSaxParser: ignoring external entity declaration");
+    }
+}
+
+int FastSaxParser::callbackExternalEntityRef(
+    XML_Parser parser, const XML_Char *context,
+    SAL_UNUSED_PARAMETER const XML_Char * /*base*/, const XML_Char *systemId,
+    const XML_Char *publicId )
 {
     bool bOK = true;
     InputSource source;
