@@ -481,6 +481,15 @@ void ScDrawLayer::ScCopyPage( sal_uInt16 nOldPos, sal_uInt16 nNewPos, sal_Bool b
 
 void ScDrawLayer::ResetTab( SCTAB nStart, SCTAB nEnd )
 {
+    SCTAB nPageSize = static_cast<SCTAB>(GetPageCount());
+    if (nPageSize < 0)
+        // No drawing pages exist.
+        return;
+
+    if (nEnd >= nPageSize)
+        // Avoid iterating beyond the last existing page.
+        nEnd = nPageSize - 1;
+
     for (SCTAB i = nStart; i <= nEnd; ++i)
     {
         SdrPage* pPage = GetPage(static_cast<sal_uInt16>(i));
@@ -629,7 +638,7 @@ void ScDrawLayer::RecalcPos( SdrObject* pObj, ScDrawObjData& rData, bool bNegati
                 where cell note is already deleted (thus document cannot find
                 the note object anymore). The caption will be deleted later
                 with drawing undo. */
-            if( ScPostIt* pNote = pDoc->GetNote( rData.maStart ) )
+            if( ScPostIt* pNote = pDoc->GetNotes( rData.maStart.Tab() )->findByAddress( rData.maStart ) )
                 pNote->UpdateCaptionPos( rData.maStart );
         return;
     }
@@ -1639,7 +1648,7 @@ inline sal_Bool IsNamedObject( SdrObject* pObj, const String& rName )
     //  sal_True if rName is the object's Name or PersistName
     //  (used to find a named object)
 
-    return ( pObj->GetName() == rName ||
+    return ( pObj->GetName().equals(rName) ||
             ( pObj->GetObjIdentifier() == OBJ_OLE2 &&
               static_cast<SdrOle2Obj*>(pObj)->GetPersistName() == rName ) );
 }
@@ -1716,7 +1725,7 @@ void ScDrawLayer::EnsureGraphicNames()
 
             while (pObject)
             {
-                if ( pObject->GetObjIdentifier() == OBJ_GRAF && pObject->GetName().Len() == 0 )
+                if ( pObject->GetObjIdentifier() == OBJ_GRAF && pObject->GetName().isEmpty())
                     pObject->SetName( GetNewGraphicName( &nCounter ) );
 
                 pObject = aIter.Next();
@@ -1827,7 +1836,7 @@ ScDrawObjData* ScDrawLayer::GetObjData( SdrObject* pObj, sal_Bool bCreate )
     if( pObj && bCreate )
     {
         ScDrawObjData* pData = new ScDrawObjData;
-        pObj->InsertUserData( pData, 0 );
+        pObj->AppendUserData(pData);
         return pData;
     }
     return 0;
@@ -1936,7 +1945,7 @@ ScMacroInfo* ScDrawLayer::GetMacroInfo( SdrObject* pObj, sal_Bool bCreate )
     if ( bCreate )
     {
         ScMacroInfo* pData = new ScMacroInfo;
-        pObj->InsertUserData( pData, 0 );
+        pObj->AppendUserData(pData);
         return pData;
     }
     return 0;
