@@ -238,6 +238,7 @@ FltError ImportExcel::Read( void )
                     case 0x08:  Row25(); break;         // ROW          [ 2  5]
                     case 0x0A:                          // EOF          [ 2345]
                         rNumFmtBfr.CreateScFormats();
+                        rNameMgr.ConvertAllTokens();
                         Eof();
                         eAkt = Z_Ende;
                         break;
@@ -300,6 +301,7 @@ FltError ImportExcel::Read( void )
 
                     case 0x0A:                          // EOF          [ 2345]
                         rNumFmtBfr.CreateScFormats();
+                        rNameMgr.ConvertAllTokens();
                         Eof();
                         eAkt = Z_Ende;
                         break;
@@ -370,6 +372,7 @@ FltError ImportExcel::Read( void )
 
                     case 0x0A:                          // EOF          [ 2345]
                         rNumFmtBfr.CreateScFormats();
+                        rNameMgr.ConvertAllTokens();
                         Eof();
                         eAkt = Z_Ende;
                         break;
@@ -424,6 +427,7 @@ FltError ImportExcel::Read( void )
                 switch( nOpcode )
                 {
                     case 0x0A:                          // EOF          [ 2345]
+                        rNameMgr.ConvertAllTokens();
                         eAkt = Z_Ende;
                         break;
                     case 0x12:  DocProtect(); break;    // PROTECT      [    5]
@@ -487,6 +491,7 @@ FltError ImportExcel::Read( void )
                     case EXC_ID_RK:             ReadRk();               break;
 
                     case 0x0A:                          // EOF          [ 2345]
+                        rNameMgr.ConvertAllTokens();
                         Eof();
                         eAkt = Z_Biff4E;
                     break;
@@ -584,6 +589,7 @@ FltError ImportExcel::Read( void )
                     case 0x0A:                          // EOF          [ 2345]
                         rNumFmtBfr.CreateScFormats();
                         rXFBfr.CreateUserStyles();
+                        rNameMgr.ConvertAllTokens();
                         eAkt = Z_Biff5E;
                         break;
                     case 0x18:  rNameMgr.ReadName( maStrm );            break;
@@ -658,9 +664,9 @@ FltError ImportExcel::Read( void )
                     case EXC_ID3_BOOLERR:       ReadBoolErr();          break;
                     case EXC_ID_RK:             ReadRk();               break;
 
-                    case 0x0006:
-                    case 0x0206:
-                    case 0x0406:  Formula25(); break;
+                    case EXC_ID2_FORMULA:
+                    case EXC_ID3_FORMULA:
+                    case EXC_ID4_FORMULA:       Formula25(); break;
                     case 0x0A:  Eof(); eAkt = Z_Biff5E;                 break;
                     case 0x14:
                     case 0x15:  rPageSett.ReadHeaderFooter( maStrm );   break;
@@ -1001,6 +1007,7 @@ FltError ImportExcel8::Read( void )
                             rNumFmtBfr.CreateScFormats();
                             rXFBfr.CreateUserStyles();
                             rPTableMgr.ReadPivotCaches( maStrm );
+                            rNameMgr.ConvertAllTokens();
                             eAkt = EXC_STATE_BEFORE_SHEET;
                         }
                     break;
@@ -1177,9 +1184,9 @@ FltError ImportExcel8::Read( void )
                     case EXC_ID3_BOOLERR:       ReadBoolErr();          break;
                     case EXC_ID_RK:             ReadRk();               break;
 
-                    case 0x0006:
-                    case 0x0206:
-                    case 0x0406:    Formula25();            break;  // FORMULA      [ 2  5   ]
+                    case EXC_ID2_FORMULA:
+                    case EXC_ID3_FORMULA:
+                    case EXC_ID4_FORMULA:       Formula25();            break;
                     case 0x000C:    Calccount();            break;  // CALCCOUNT
                     case 0x0010:    Delta();                break;  // DELTA
                     case 0x0011:    Iteration();            break;  // ITERATION
