@@ -30,7 +30,7 @@
 
 #include <com/sun/star/embed/XEmbeddedObject.hpp>
 #include <com/sun/star/frame/XComponentLoader.hpp>
- 
+
 
 using namespace ::com::sun::star;
 
@@ -67,6 +67,7 @@ using namespace ::com::sun::star;
 #include <sfx2/passwd.hxx>
 #include <sfx2/filedlghelper.hxx>
 #include <sfx2/docinsert.hxx>
+#include "sfx2/dispatch.hxx"
 #include <svl/PasswordHelper.hxx>
 #include <svl/documentlockfile.hxx>
 #include <svl/sharecontrolfile.hxx>
@@ -131,9 +132,6 @@ using namespace ::com::sun::star;
         ((SvxSetItem&)(set).Get(ATTR_PAGE_FOOTERSET)).GetItemSet(). \
             Get(ATTR_PAGE_SHARED)).GetValue()
 
-#define IS_AVAILABLE(WhichId,ppItem) \
-    (pReqArgs->GetItemState((WhichId), sal_True, ppItem ) == SFX_ITEM_SET)
-
 #define SC_PREVIEW_SIZE_X   10000
 #define SC_PREVIEW_SIZE_Y   12400
 
@@ -159,10 +157,10 @@ void ScDocShell::Execute( SfxRequest& rReq )
             const SfxPoolItem* pRowItem;
             const SfxPoolItem* pTabItem;
             const SfxPoolItem* pTextItem;
-            if( pReqArgs && IS_AVAILABLE( FN_PARAM_1, &pColItem ) &&
-                            IS_AVAILABLE( FN_PARAM_2, &pRowItem ) &&
-                            IS_AVAILABLE( FN_PARAM_3, &pTabItem ) &&
-                            IS_AVAILABLE( SID_SC_SETTEXT, &pTextItem ) )
+            if( pReqArgs && pReqArgs->HasItem( FN_PARAM_1, &pColItem ) &&
+                            pReqArgs->HasItem( FN_PARAM_2, &pRowItem ) &&
+                            pReqArgs->HasItem( FN_PARAM_3, &pTabItem ) &&
+                            pReqArgs->HasItem( SID_SC_SETTEXT, &pTextItem ) )
             {
                 //  Parameter sind 1-based !!!
                 SCCOL nCol = ((SfxInt16Item*)pColItem)->GetValue() - 1;
@@ -185,12 +183,16 @@ void ScDocShell::Execute( SfxRequest& rReq )
                     }
                     else                // geschuetzte Zelle
                     {
+#ifndef DISABLE_SCRIPTING
                         SbxBase::SetError( SbxERR_BAD_PARAMETER );      //! welchen Fehler ?
+#endif
                         break;
                     }
                 }
             }
+#ifndef DISABLE_SCRIPTING
             SbxBase::SetError( SbxERR_NO_OBJECT );
+#endif
         }
         break;
 
@@ -291,18 +293,18 @@ void ScDocShell::Execute( SfxRequest& rReq )
                 sal_Bool bRowInit = false;
                 sal_Bool bAddRange = (nSlot == SID_CHART_ADDSOURCE);
 
-                if( IS_AVAILABLE( SID_CHART_NAME, &pItem ) )
+                if( pReqArgs->HasItem( SID_CHART_NAME, &pItem ) )
                     aChartName = ((const SfxStringItem*)pItem)->GetValue();
 
-                if( IS_AVAILABLE( SID_CHART_SOURCE, &pItem ) )
+                if( pReqArgs->HasItem( SID_CHART_SOURCE, &pItem ) )
                     aRangeName = ((const SfxStringItem*)pItem)->GetValue();
 
-                if( IS_AVAILABLE( FN_PARAM_1, &pItem ) )
+                if( pReqArgs->HasItem( FN_PARAM_1, &pItem ) )
                 {
                     bColHeaders = ((const SfxBoolItem*)pItem)->GetValue();
                     bColInit = sal_True;
                 }
-                if( IS_AVAILABLE( FN_PARAM_2, &pItem ) )
+                if( pReqArgs->HasItem( FN_PARAM_2, &pItem ) )
                 {
                     bRowHeaders = ((const SfxBoolItem*)pItem)->GetValue();
                     bRowInit = sal_True;
@@ -720,7 +722,7 @@ void ScDocShell::Execute( SfxRequest& rReq )
                         pSet->Put( SfxStringItem( SID_FILE_FILTEROPTIONS, aOptions ) );
                     if ( nVersion != 0 )
                         pSet->Put( SfxInt16Item( SID_VERSION, nVersion ) );
-                    pMed = new SfxMedium( aFileName, STREAM_STD_READ, false, pFilter, pSet );
+                    pMed = new SfxMedium( aFileName, STREAM_STD_READ, pFilter, pSet );
                 }
                 else
                 {
@@ -1014,11 +1016,11 @@ void ScDocShell::Execute( SfxRequest& rReq )
                                             uno::Sequence< ::rtl::OUString > aData = aLockFile.GetLockData();
                                             if ( aData.getLength() > LOCKFILE_SYSUSERNAME_ID )
                                             {
-                                                if ( aData[LOCKFILE_OOOUSERNAME_ID].getLength() > 0 )
+                                                if ( !aData[LOCKFILE_OOOUSERNAME_ID].isEmpty() )
                                                 {
                                                     aUserName = aData[LOCKFILE_OOOUSERNAME_ID];
                                                 }
-                                                else if ( aData[LOCKFILE_SYSUSERNAME_ID].getLength() > 0 )
+                                                else if ( !aData[LOCKFILE_SYSUSERNAME_ID].isEmpty() )
                                                 {
                                                     aUserName = aData[LOCKFILE_SYSUSERNAME_ID];
                                                 }
@@ -1095,14 +1097,24 @@ void ScDocShell::Execute( SfxRequest& rReq )
             }
             break;
 
+        case SID_OPEN_CALC:
+        {
+            SfxStringItem aApp(SID_DOC_SERVICE, rtl::OUString("com.sun.star.sheet.SpreadsheetDocument"));
+            SfxStringItem aTarget(SID_TARGETNAME, rtl::OUString("_blank"));
+            GetViewData()->GetDispatcher().Execute(
+                SID_OPENDOC, SFX_CALLMODE_API|SFX_CALLMODE_SYNCHRON, &aApp, &aTarget, 0L);
+        }
+        break;
         default:
         {
             // kleiner (?) Hack -> forward der Slots an TabViewShell
             ScTabViewShell* pSh = GetBestViewShell();
             if ( pSh )
                 pSh->Execute( rReq );
+#ifndef DISABLE_SCRIPTING
             else
                 SbxBase::SetError( SbxERR_NO_ACTIVE_OBJECT );
+#endif
         }
     }
 }
@@ -1131,7 +1143,7 @@ bool ScDocShell::ExecuteChangeProtectionDialog( Window* _pParent, sal_Bool bJust
     ScChangeTrack* pChangeTrack = aDocument.GetChangeTrack();
     if ( pChangeTrack )
     {
-        sal_Bool bProtected = pChangeTrack->IsProtected();
+        bool bProtected = pChangeTrack->IsProtected();
         if ( bJustQueryIfProtected && !bProtected )
             return true;
 
@@ -1223,7 +1235,7 @@ void ScDocShell::DoRecalc( bool bApi )
         //  doppelt gepainted werden.
 
         ScChartListenerCollection* pCharts = aDocument.GetChartListenerCollection();
-        if ( pCharts && pCharts->GetCount() )
+        if ( pCharts && pCharts->hasListeners() )
             PostPaintGridAll();
         else
             PostDataChanged();
@@ -1351,9 +1363,12 @@ void ScDocShell::NotifyStyle( const SfxStyleSheetHint& rHint )
                 aOldName = ((SfxStyleSheetHintExtended&)rHint).GetOldName();
             if ( aNewName != aOldName )
             {
-                ScConditionalFormatList* pList = aDocument.GetCondFormList();
-                if (pList)
-                    pList->RenameCellStyle( aOldName,aNewName );
+                for(SCTAB i = 0; i < aDocument.GetTableCount(); ++i)
+                {
+                    ScConditionalFormatList* pList = aDocument.GetCondFormList(i);
+                    if (pList)
+                        pList->RenameCellStyle( aOldName,aNewName );
+                }
             }
         }
     }
@@ -1773,10 +1788,17 @@ void ScDocShell::GetStatePageStyle( SfxViewShell&   /* rCaller */,
 
 void ScDocShell::GetState( SfxItemSet &rSet )
 {
+    bool bTabView = GetBestViewShell(true) != NULL;
+
     SfxWhichIter aIter(rSet);
-    sal_uInt16 nWhich = aIter.FirstWhich();
-    while ( nWhich )
+    for (sal_uInt16 nWhich = aIter.FirstWhich(); nWhich; nWhich = aIter.NextWhich())
     {
+        if (!bTabView)
+        {
+            rSet.DisableItem(nWhich);
+            continue;
+        }
+
         switch (nWhich)
         {
             case FID_AUTO_CALC:
@@ -1841,8 +1863,6 @@ void ScDocShell::GetState( SfxItemSet &rSet )
                 }
                 break;
         }
-
-        nWhich = aIter.NextWhich();
     }
 }
 
@@ -2079,7 +2099,7 @@ long ScDocShell::DdeSetData( const String& rItem,
     ScRangeName* pRange = aDocument.GetRangeName();
     if( pRange )
     {
-        const ScRangeData* pData = pRange->findByUpperName(ScGlobal::pCharClass->upper(aPos));
+        const ScRangeData* pData = pRange->findByUpperName(ScGlobal::pCharClass->uppercase(aPos));
         if (pData)
         {
             if( pData->HasType( RT_REFAREA )
