@@ -135,7 +135,7 @@ ScRangeData* ScNamedRangeObj::GetRangeData_Impl()
             pNames = pDocShell->GetDocument()->GetRangeName();
         if (pNames)
         {
-            pRet = pNames->findByUpperName(ScGlobal::pCharClass->upper(aName));
+            pRet = pNames->findByUpperName(ScGlobal::pCharClass->uppercase(aName));
             if (pRet)
                 pRet->ValidateTabRefs();        // adjust relative tab refs to valid tables
         }
@@ -178,7 +178,7 @@ void ScNamedRangeObj::Modify_Impl( const String* pNewName, const ScTokenArray* p
     if (!pNames)
         return;
 
-    const ScRangeData* pOld = pNames->findByUpperName(ScGlobal::pCharClass->upper(aName));
+    const ScRangeData* pOld = pNames->findByUpperName(ScGlobal::pCharClass->uppercase(aName));
     if (!pOld)
         return;
 
@@ -212,8 +212,7 @@ void ScNamedRangeObj::Modify_Impl( const String* pNewName, const ScTokenArray* p
     pNewRanges->erase(*pOld);
     if (pNewRanges->insert(pNew))
     {
-        ScDocFunc aFunc(*pDocShell);
-        aFunc.SetNewRangeNames(pNewRanges, mxParent->IsModifyAndBroadcast(), nTab);
+        pDocShell->GetDocFunc().SetNewRangeNames(pNewRanges, mxParent->IsModifyAndBroadcast(), nTab);
 
         aName = aInsName;   //! broadcast?
     }
@@ -265,14 +264,6 @@ void SAL_CALL ScNamedRangeObj::setContent( const rtl::OUString& aContent )
     Modify_Impl( NULL, NULL, &aContStr, NULL, NULL,formula::FormulaGrammar::GRAM_PODF_A1 );
 }
 
-void ScNamedRangeObj::SetContentWithGrammar( const ::rtl::OUString& aContent,
-                                    const formula::FormulaGrammar::Grammar eGrammar )
-                                throw(::com::sun::star::uno::RuntimeException)
-{
-    String aContStr(aContent);
-    Modify_Impl( NULL, NULL, &aContStr, NULL, NULL, eGrammar );
-}
-
 table::CellAddress SAL_CALL ScNamedRangeObj::getReferencePosition()
                                                 throw(uno::RuntimeException)
 {
@@ -405,7 +396,7 @@ void SAL_CALL ScNamedRangeObj::setPropertyValue(
                         uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    if ( rPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( SC_UNONAME_ISSHAREDFMLA ) ) )
+    if ( rPropertyName == SC_UNONAME_ISSHAREDFMLA )
     {
         bool bIsShared = false;
         if( aValue >>= bIsShared )
@@ -422,21 +413,21 @@ uno::Any SAL_CALL ScNamedRangeObj::getPropertyValue( const rtl::OUString& rPrope
 {
     SolarMutexGuard aGuard;
     uno::Any aRet;
-    if ( rPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( SC_UNO_LINKDISPBIT ) ) )
+    if ( rPropertyName == SC_UNO_LINKDISPBIT )
     {
         //  no target bitmaps for individual entries (would be all equal)
         // ScLinkTargetTypeObj::SetLinkTargetBitmap( aRet, SC_LINKTARGETTYPE_RANGENAME );
     }
-    else if ( rPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( SC_UNO_LINKDISPNAME ) ) )
+    else if ( rPropertyName == SC_UNO_LINKDISPNAME )
         aRet <<= rtl::OUString( aName );
-    else if ( rPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( SC_UNONAME_TOKENINDEX ) ) )
+    else if ( rPropertyName == SC_UNONAME_TOKENINDEX )
     {
         // get index for use in formula tokens (read-only)
         ScRangeData* pData = GetRangeData_Impl();
         if (pData)
             aRet <<= static_cast<sal_Int32>(pData->GetIndex());
     }
-    else if ( rPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( SC_UNONAME_ISSHAREDFMLA ) ) )
+    else if ( rPropertyName == SC_UNONAME_ISSHAREDFMLA )
     {
         if( ScRangeData* pData = GetRangeData_Impl() )
             aRet <<= static_cast< bool >( pData->HasType( RT_SHARED ) );
@@ -554,7 +545,7 @@ void SAL_CALL ScNamedRangesObj::addNewByName( const rtl::OUString& aName,
     {
         ScDocument* pDoc = pDocShell->GetDocument();
         ScRangeName* pNames = GetRangeName_Impl();
-        if (pNames && !pNames->findByUpperName(ScGlobal::pCharClass->upper(aName)))
+        if (pNames && !pNames->findByUpperName(ScGlobal::pCharClass->uppercase(aName)))
         {
             ScRangeName* pNewRanges = new ScRangeName( *pNames );
             // GRAM_PODF_A1 for API compatibility.
@@ -562,8 +553,7 @@ void SAL_CALL ScNamedRangesObj::addNewByName( const rtl::OUString& aName,
                                                 aPos, nNewType,formula::FormulaGrammar::GRAM_PODF_A1 );
             if ( pNewRanges->insert(pNew) )
             {
-                ScDocFunc aFunc(*pDocShell);
-                aFunc.SetNewRangeNames(pNewRanges, mbModifyAndBroadcast, GetTab_Impl());
+                pDocShell->GetDocFunc().SetNewRangeNames(pNewRanges, mbModifyAndBroadcast, GetTab_Impl());
                 bDone = true;
             }
             else
@@ -599,10 +589,7 @@ void SAL_CALL ScNamedRangesObj::addNewFromTitles( const table::CellRangeAddress&
     if (bRight)  nFlags |= NAME_RIGHT;
 
     if (nFlags)
-    {
-        ScDocFunc aFunc(*pDocShell);
-        aFunc.CreateNames( aRange, nFlags, sal_True, GetTab_Impl() );
-    }
+        pDocShell->GetDocFunc().CreateNames( aRange, nFlags, sal_True, GetTab_Impl() );
 }
 
 void SAL_CALL ScNamedRangesObj::removeByName( const rtl::OUString& aName )
@@ -615,13 +602,12 @@ void SAL_CALL ScNamedRangesObj::removeByName( const rtl::OUString& aName )
         ScRangeName* pNames = GetRangeName_Impl();
         if (pNames)
         {
-            const ScRangeData* pData = pNames->findByUpperName(ScGlobal::pCharClass->upper(aName));
+            const ScRangeData* pData = pNames->findByUpperName(ScGlobal::pCharClass->uppercase(aName));
             if (pData && lcl_UserVisibleName(*pData))
             {
                 ScRangeName* pNewRanges = new ScRangeName(*pNames);
                 pNewRanges->erase(*pData);
-                ScDocFunc aFunc(*pDocShell);
-                aFunc.SetNewRangeNames( pNewRanges, mbModifyAndBroadcast, GetTab_Impl());
+                pDocShell->GetDocFunc().SetNewRangeNames( pNewRanges, mbModifyAndBroadcast, GetTab_Impl());
                 bDone = true;
             }
         }
@@ -637,10 +623,7 @@ void SAL_CALL ScNamedRangesObj::outputList( const table::CellAddress& aOutputPos
     SolarMutexGuard aGuard;
     ScAddress aPos( (SCCOL)aOutputPosition.Column, (SCROW)aOutputPosition.Row, aOutputPosition.Sheet );
     if (pDocShell)
-    {
-        ScDocFunc aFunc(*pDocShell);
-        aFunc.InsertNameList( aPos, sal_True );
-    }
+        pDocShell->GetDocFunc().InsertNameList( aPos, sal_True );
 }
 
 // container::XEnumerationAccess
@@ -710,7 +693,7 @@ void SAL_CALL ScNamedRangesObj::setPropertyValue(
                         lang::IllegalArgumentException, lang::WrappedTargetException,
                         uno::RuntimeException)
 {
-    if (rPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(SC_UNO_MODIFY_BROADCAST)))
+    if ( rPropertyName == SC_UNO_MODIFY_BROADCAST )
     {
         aValue >>= mbModifyAndBroadcast;
     }
@@ -721,7 +704,7 @@ Any SAL_CALL ScNamedRangesObj::getPropertyValue( const rtl::OUString& rPropertyN
                         uno::RuntimeException)
 {
     Any aRet;
-    if (rPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(SC_UNO_MODIFY_BROADCAST)))
+    if ( rPropertyName == SC_UNO_MODIFY_BROADCAST )
     {
         aRet <<= mbModifyAndBroadcast;
     }
@@ -777,7 +760,7 @@ sal_Bool SAL_CALL ScNamedRangesObj::hasByName( const rtl::OUString& aName )
         ScRangeName* pNames = GetRangeName_Impl();
         if (pNames)
         {
-            const ScRangeData* pData = pNames->findByUpperName(ScGlobal::pCharClass->upper(aName));
+            const ScRangeData* pData = pNames->findByUpperName(ScGlobal::pCharClass->uppercase(aName));
             if (pData && lcl_UserVisibleName(*pData))
                 return sal_True;
         }
