@@ -68,8 +68,6 @@ using namespace ::com::sun::star::accessibility;
 
 class SfxViewFrame;
 
-#define A2S(pString) (::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(pString)))
-
 namespace accessibility {
 
 
@@ -166,8 +164,7 @@ AccessiblePageShape* AccessibleDrawDocumentView::CreateDrawPageShape (void)
             uno::Reference<lang::XMultiServiceFactory> xFactory (mxModel, uno::UNO_QUERY);
             uno::Reference<drawing::XShape> xRectangle;
             if (xFactory.is())
-                xRectangle = uno::Reference<drawing::XShape>(xFactory->createInstance (
-                    OUString (RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.RectangleShape"))),
+                xRectangle = uno::Reference<drawing::XShape>(xFactory->createInstance ("com.sun.star.drawing.RectangleShape"),
                     uno::UNO_QUERY);
 
             // Set the shape's size and position.
@@ -179,19 +176,15 @@ AccessiblePageShape* AccessibleDrawDocumentView::CreateDrawPageShape (void)
 
                 // Set size and position of the shape to those of the draw
                 // page.
-                aValue = xSet->getPropertyValue (
-                    OUString (RTL_CONSTASCII_USTRINGPARAM("BorderLeft")));
+                aValue = xSet->getPropertyValue ("BorderLeft");
                 aValue >>= aPosition.X;
-                aValue = xSet->getPropertyValue (
-                    OUString (RTL_CONSTASCII_USTRINGPARAM("BorderTop")));
+                aValue = xSet->getPropertyValue ("BorderTop");
                 aValue >>= aPosition.Y;
                 xRectangle->setPosition (aPosition);
 
-                aValue = xSet->getPropertyValue (
-                    OUString (RTL_CONSTASCII_USTRINGPARAM("Width")));
+                aValue = xSet->getPropertyValue ("Width");
                 aValue >>= aSize.Width;
-                aValue = xSet->getPropertyValue (
-                    OUString (RTL_CONSTASCII_USTRINGPARAM("Height")));
+                aValue = xSet->getPropertyValue ("Height");
                 aValue >>= aSize.Height;
                 xRectangle->setSize (aSize);
 
@@ -258,8 +251,7 @@ uno::Reference<XAccessible> SAL_CALL
     }
     else
         throw lang::IndexOutOfBoundsException (
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("no accessible child with index "))
-            + rtl::OUString::valueOf(nIndex),
+            "no accessible child with index " + rtl::OUString::valueOf(nIndex),
             static_cast<uno::XWeak*>(this));
 }
 
@@ -298,7 +290,7 @@ void SAL_CALL
     AccessibleDocumentViewBase::propertyChange (rEventObject);
 
     OSL_TRACE ("AccessibleDrawDocumentView::propertyChange");
-    if (rEventObject.PropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("CurrentPage")))
+    if ( rEventObject.PropertyName == "CurrentPage" )
     {
         OSL_TRACE ("    current page changed");
 
@@ -333,7 +325,7 @@ void SAL_CALL
         else
             OSL_TRACE ("View invalid");
     }
-    else if (rEventObject.PropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("VisibleArea")))
+    else if ( rEventObject.PropertyName == "VisibleArea" )
     {
         OSL_TRACE ("    visible area changed");
         if (mpChildrenManager != NULL)
@@ -356,8 +348,7 @@ void SAL_CALL
     AccessibleDrawDocumentView::getImplementationName (void)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-        "AccessibleDrawDocumentView"));
+    return ::rtl::OUString("AccessibleDrawDocumentView");
 }
 
 
@@ -375,8 +366,7 @@ void SAL_CALL
 
     // ...and add additional names.
     aServiceNames.realloc (nCount + 1);
-    static const OUString sAdditionalServiceName (RTL_CONSTASCII_USTRINGPARAM(
-        "com.sun.star.drawing.AccessibleDrawDocumentView"));
+    static const OUString sAdditionalServiceName ("com.sun.star.drawing.AccessibleDrawDocumentView");
     aServiceNames[nCount] = sAdditionalServiceName;
 
     return aServiceNames;
@@ -397,33 +387,32 @@ void SAL_CALL
     {
         uno::Sequence< ::rtl::OUString > aServices( xInfo->getSupportedServiceNames() );
         OUString sFirstService = aServices[0];
-        if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.DrawingDocumentDrawView")))
+        if ( sFirstService == "com.sun.star.drawing.DrawingDocumentDrawView" )
         {
-            if( aServices.getLength() >= 2 &&
-                aServices[1].equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.PresentationView")))
+            if( aServices.getLength() >= 2 && aServices[1] == "com.sun.star.presentation.PresentationView")
             {
                 SolarMutexGuard aGuard;
 
-                sName = String( SdResId(SID_SD_A11Y_I_DRAWVIEW_N) );
+                sName = SD_RESSTR(SID_SD_A11Y_I_DRAWVIEW_N);
             }
             else
             {
                 SolarMutexGuard aGuard;
 
-                sName = String( SdResId(SID_SD_A11Y_D_DRAWVIEW_N) );
+                sName = SD_RESSTR(SID_SD_A11Y_D_DRAWVIEW_N);
             }
         }
-        else if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.NotesView")))
+        else if ( sFirstService == "com.sun.star.presentation.NotesView" )
         {
             SolarMutexGuard aGuard;
 
-            sName = String( SdResId(SID_SD_A11Y_I_NOTESVIEW_N) );
+            sName = SD_RESSTR(SID_SD_A11Y_I_NOTESVIEW_N);
         }
-        else if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.HandoutView")))
+        else if ( sFirstService == "com.sun.star.presentation.HandoutView" )
         {
             SolarMutexGuard aGuard;
 
-            sName = String( SdResId(SID_SD_A11Y_I_HANDOUTVIEW_N) );
+            sName = SD_RESSTR(SID_SD_A11Y_I_HANDOUTVIEW_N);
         }
         else
         {
@@ -432,7 +421,7 @@ void SAL_CALL
     }
     else
     {
-        sName = OUString(RTL_CONSTASCII_USTRINGPARAM("AccessibleDrawDocumentView"));
+        sName = "AccessibleDrawDocumentView";
     }
     return sName;
 }
@@ -454,33 +443,32 @@ void SAL_CALL
     {
         uno::Sequence< ::rtl::OUString > aServices( xInfo->getSupportedServiceNames() );
         OUString sFirstService = aServices[0];
-        if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.DrawingDocumentDrawView")))
+        if ( sFirstService == "com.sun.star.drawing.DrawingDocumentDrawView" )
         {
-            if( aServices.getLength() >= 2 &&
-                aServices[1].equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.PresentationView")))
+            if( aServices.getLength() >= 2 && aServices[1] == "com.sun.star.presentation.PresentationView")
             {
                 SolarMutexGuard aGuard;
 
-                sDescription = String( SdResId(SID_SD_A11Y_I_DRAWVIEW_D) );
+                sDescription = SD_RESSTR(SID_SD_A11Y_I_DRAWVIEW_D);
             }
             else
             {
                 SolarMutexGuard aGuard;
 
-                sDescription = String( SdResId(SID_SD_A11Y_D_DRAWVIEW_D) );
+                sDescription = SD_RESSTR(SID_SD_A11Y_D_DRAWVIEW_D);
             }
         }
-        else if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.NotesView")))
+        else if ( sFirstService == "com.sun.star.presentation.NotesView" )
         {
             SolarMutexGuard aGuard;
 
-            sDescription = String( SdResId(SID_SD_A11Y_I_NOTESVIEW_D) );
+            sDescription = SD_RESSTR(SID_SD_A11Y_I_NOTESVIEW_D);
         }
-        else if (sFirstService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.HandoutView")))
+        else if ( sFirstService == "com.sun.star.presentation.HandoutView" )
         {
             SolarMutexGuard aGuard;
 
-            sDescription = String( SdResId(SID_SD_A11Y_I_HANDOUTVIEW_D) );
+            sDescription = SD_RESSTR(SID_SD_A11Y_I_HANDOUTVIEW_D);
         }
         else
         {
@@ -489,7 +477,7 @@ void SAL_CALL
     }
     else
     {
-        sDescription = OUString(RTL_CONSTASCII_USTRINGPARAM("Accessible Draw Document"));
+        sDescription = "Accessible Draw Document";
     }
     return sDescription;
 }
@@ -694,7 +682,7 @@ void SAL_CALL AccessibleDrawDocumentView::disposing (void)
 void AccessibleDrawDocumentView::UpdateAccessibleName (void)
 {
     OUString sNewName (CreateAccessibleName());
-    sNewName += A2S(": ");
+    sNewName += ": ";
 
     // Add the number of the current slide.
     uno::Reference<drawing::XDrawView> xView (mxController, uno::UNO_QUERY);
@@ -705,7 +693,7 @@ void AccessibleDrawDocumentView::UpdateAccessibleName (void)
             try
             {
                 sal_Int16 nPageNumber (0);
-                if (xProperties->getPropertyValue(A2S("Number")) >>= nPageNumber)
+                if (xProperties->getPropertyValue("Number") >>= nPageNumber)
                 {
                     sNewName += OUString::valueOf(sal_Int32(nPageNumber));
                 }
@@ -722,7 +710,7 @@ void AccessibleDrawDocumentView::UpdateAccessibleName (void)
         Reference<container::XIndexAccess> xPages (xPagesSupplier->getDrawPages(), UNO_QUERY);
         if (xPages.is())
         {
-            sNewName += A2S(" / ");
+            sNewName += " / ";
             sNewName += OUString::valueOf(xPages->getCount());
         }
     }
