@@ -80,8 +80,6 @@ using namespace ::com::sun::star::drawing::framework;
 
 extern String getUiNameFromPageApiNameImpl( const ::rtl::OUString& rApiName );
 
-#define C2U(x) OUString( RTL_CONSTASCII_USTRINGPARAM(x) )
-
 
 namespace {
     /** This local version of the work window overloads DataChanged() so that it
@@ -182,13 +180,21 @@ rtl::Reference< SlideShow > SlideShow::GetSlideShow( SdDrawDocument* pDocument )
     rtl::Reference< SlideShow > xRet;
 
     if( pDocument )
-        xRet = rtl::Reference< SlideShow >( dynamic_cast< SlideShow* >( pDocument->getPresentation().get() ) );
+        xRet = GetSlideShow( *pDocument );
 
     return xRet;
 }
 
 // --------------------------------------------------------------------
 
+rtl::Reference< SlideShow > SlideShow::GetSlideShow( SdDrawDocument& rDocument )
+{
+    return rtl::Reference< SlideShow >(
+        dynamic_cast< SlideShow* >( rDocument.getPresentation().get() ) );
+}
+
+// --------------------------------------------------------------------
+
 rtl::Reference< SlideShow > SlideShow::GetSlideShow( ViewShellBase& rBase )
 {
     return GetSlideShow( rBase.GetDocument() );
@@ -269,7 +275,7 @@ void SlideShow::CreateController(  ViewShell* pViewSh, ::sd::View* pView, ::Wind
 
 OUString SAL_CALL SlideShow::getImplementationName(  ) throw(RuntimeException)
 {
-    return OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.sd.SlideShow") );
+    return OUString( "com.sun.star.comp.sd.SlideShow" );
 }
 
 // --------------------------------------------------------------------
@@ -283,7 +289,7 @@ sal_Bool SAL_CALL SlideShow::supportsService( const OUString& ServiceName ) thro
 
 Sequence< OUString > SAL_CALL SlideShow::getSupportedServiceNames(  ) throw(RuntimeException)
 {
-    OUString aService( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.presentation.Presentation") );
+    OUString aService( "com.sun.star.presentation.Presentation" );
     Sequence< OUString > aSeq( &aService, 1 );
     return aSeq;
 }
@@ -814,7 +820,7 @@ void SAL_CALL SlideShow::end() throw(RuntimeException)
                     if( xProvider.is() )
                     {
                         util::URL aURL;
-                        aURL.Complete = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:CloseFrame"));
+                        aURL.Complete = ".uno:CloseFrame";
 
                         uno::Reference< frame::XDispatch > xDispatch(
                             xProvider->queryDispatch(
@@ -837,7 +843,7 @@ void SAL_CALL SlideShow::end() throw(RuntimeException)
 void SAL_CALL SlideShow::rehearseTimings() throw(RuntimeException)
 {
     Sequence< PropertyValue > aArguments(1);
-    aArguments[0].Name = C2U("RehearseTimings");
+    aArguments[0].Name = "RehearseTimings";
     aArguments[0].Value <<= sal_True;
     startWithArguments( aArguments );
 }
@@ -955,20 +961,20 @@ bool SlideShow::startPreview( const Reference< XDrawPage >& xDrawPage, const Ref
 {
     Sequence< PropertyValue > aArguments(4);
 
-    aArguments[0].Name = C2U("Preview");
+    aArguments[0].Name = "Preview";
     aArguments[0].Value <<= sal_True;
 
-    aArguments[1].Name = C2U("FirstPage");
+    aArguments[1].Name = "FirstPage";
     aArguments[1].Value <<= xDrawPage;
 
-    aArguments[2].Name = C2U("AnimationNode");
+    aArguments[2].Name = "AnimationNode";
     aArguments[2].Value <<= xAnimationNode;
 
     Reference< XWindow > xParentWindow;
     if( pParent )
         xParentWindow = VCLUnoHelper::GetInterface( pParent );
 
-    aArguments[3].Name = C2U("ParentWindow");
+    aArguments[3].Name = "ParentWindow";
     aArguments[3].Value <<= xParentWindow;
 
     startWithArguments( aArguments );
@@ -1157,7 +1163,7 @@ void SlideShow::StartInPlacePresentationConfigurationCallback()
 
 // ---------------------------------------------------------
 
-IMPL_LINK( SlideShow, StartInPlacePresentationConfigurationHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG(SlideShow, StartInPlacePresentationConfigurationHdl)
 {
     mnInPlaceConfigEvent = 0;
     StartInPlacePresentation();
@@ -1290,11 +1296,9 @@ sal_Int32 SlideShow::GetDisplay()
             Reference<XMultiServiceFactory > xFactory(
                 ::comphelper::getProcessServiceFactory(), UNO_QUERY_THROW);
             Reference<XPropertySet> xMonitorProperties(
-                xFactory->createInstance(
-                    OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.DisplayAccess"))),
+                xFactory->createInstance( "com.sun.star.awt.DisplayAccess" ),
                 UNO_QUERY_THROW);
-            const OUString sPropertyName (RTL_CONSTASCII_USTRINGPARAM("DefaultDisplay"));
-            xMonitorProperties->getPropertyValue(sPropertyName) >>= nDisplay;
+            xMonitorProperties->getPropertyValue("ExternalDisplay") >>= nDisplay;
         }
         catch( Exception& )
         {
