@@ -62,11 +62,7 @@
 #include "basegfx/tools/canvastools.hxx"
 #include "basegfx/tools/unopolypolygon.hxx"
 
-#include <boost/bind.hpp>
-#include <boost/preprocessor/stringize.hpp>
 #include <boost/scoped_ptr.hpp>
-#include <boost/scoped_array.hpp>
-
 #include <boost/unordered_map.hpp>
 #include <string.h>
 #ifdef WNT
@@ -598,7 +594,7 @@ void Parser::readFont()
         {
             uno::Reference< beans::XMaterialHolder > xMat(
                 m_xContext->getServiceManager()->createInstanceWithArgumentsAndContext(
-                    rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.FontIdentificator" ) ),
+                    rtl::OUString( "com.sun.star.awt.FontIdentificator"  ),
                     aArgs,
                     m_xContext ),
                 uno::UNO_QUERY );
@@ -621,10 +617,10 @@ void Parser::readFont()
         {
         }
 
-        if( !aResult.familyName.getLength() )
+        if( aResult.familyName.isEmpty() )
         {
             // last fallback
-            aResult.familyName  = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Arial" ) );
+            aResult.familyName  = ::rtl::OUString( "Arial"  );
             aResult.isUnderline = false;
         }
 
@@ -638,17 +634,13 @@ void Parser::readFont()
 uno::Sequence<beans::PropertyValue> Parser::readImageImpl()
 {
     static const rtl::OString aJpegMarker( "JPEG" );
-    static const rtl::OString aPbmMarker(  "PBM" );
-    static const rtl::OString aPpmMarker(  "PPM" );
-    static const rtl::OString aPngMarker(  "PNG" );
-    static const rtl::OUString aJpegFile(
-        RTL_CONSTASCII_USTRINGPARAM( "DUMMY.JPEG" ));
-    static const rtl::OUString aPbmFile(
-        RTL_CONSTASCII_USTRINGPARAM( "DUMMY.PBM" ));
-    static const rtl::OUString aPpmFile(
-        RTL_CONSTASCII_USTRINGPARAM( "DUMMY.PPM" ));
-    static const rtl::OUString aPngFile(
-        RTL_CONSTASCII_USTRINGPARAM( "DUMMY.PNG" ));
+    static const rtl::OString aPbmMarker( "PBM" );
+    static const rtl::OString aPpmMarker( "PPM" );
+    static const rtl::OString aPngMarker( "PNG" );
+    static const rtl::OUString aJpegFile( "DUMMY.JPEG" );
+    static const rtl::OUString aPbmFile( "DUMMY.PBM" );
+    static const rtl::OUString aPpmFile( "DUMMY.PPM" );
+    static const rtl::OUString aPngFile( "DUMMY.PNG" );
 
     rtl::OString aToken = readNextToken();
     const sal_Int32 nImageSize( readInt32() );
@@ -676,19 +668,19 @@ uno::Sequence<beans::PropertyValue> Parser::readImageImpl()
     uno::Reference< uno::XComponentContext > xContext( m_xContext, uno::UNO_SET_THROW );
     uno::Reference< lang::XMultiComponentFactory > xFactory( xContext->getServiceManager(), uno::UNO_SET_THROW );
     uno::Reference< io::XInputStream > xDataStream( xFactory->createInstanceWithArgumentsAndContext(
-        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.io.SequenceInputStream" ) ),
+        ::rtl::OUString( "com.sun.star.io.SequenceInputStream"  ),
         aStreamCreationArgs, m_xContext ), uno::UNO_QUERY_THROW );
 
     uno::Sequence<beans::PropertyValue> aSequence(3);
-    aSequence[0] = beans::PropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("URL")),
+    aSequence[0] = beans::PropertyValue( ::rtl::OUString("URL"),
                                          0,
                                          uno::makeAny(aFileName),
                                          beans::PropertyState_DIRECT_VALUE );
-    aSequence[1] = beans::PropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("InputStream")),
+    aSequence[1] = beans::PropertyValue( ::rtl::OUString("InputStream"),
                                          0,
                                          uno::makeAny( xDataStream ),
                                          beans::PropertyState_DIRECT_VALUE );
-    aSequence[2] = beans::PropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("InputSequence")),
+    aSequence[2] = beans::PropertyValue( ::rtl::OUString("InputSequence"),
                                          0,
                                          uno::makeAny(aDataSequence),
                                          beans::PropertyState_DIRECT_VALUE );
@@ -935,44 +927,56 @@ static bool checkEncryption( const rtl::OUString&
             o_rIsEncrypted = pPDFFile->isEncrypted();
             if( o_rIsEncrypted )
             {
-                bool bAuthenticated = false;
-                if( io_rPwd.getLength() )
+                if( pPDFFile->usesSupportedEncryptionFormat() )
                 {
-                    rtl::OString aIsoPwd = rtl::OUStringToOString( io_rPwd,
-                                                                   RTL_TEXTENCODING_ISO_8859_1 );
-                    bAuthenticated = pPDFFile->setupDecryptionData( aIsoPwd.getStr() );
-                    // trash password string on heap
-                    rtl_zeroMemory( (void*)aIsoPwd.getStr(), aIsoPwd.getLength() );
-                }
-                if( bAuthenticated )
-                    bSuccess = true;
-                else
-                {
-                    if( i_xIHdl.is() )
+                    bool bAuthenticated = false;
+                    if( !io_rPwd.isEmpty() )
                     {
-                        bool bEntered = false;
-                        do
-                        {
-                            bEntered = getPassword( i_xIHdl, io_rPwd, ! bEntered, i_rDocName );
-                            rtl::OString aIsoPwd = rtl::OUStringToOString( io_rPwd,
-                                                                           RTL_TEXTENCODING_ISO_8859_1 );
-                            bAuthenticated = pPDFFile->setupDecryptionData( aIsoPwd.getStr() );
-                            // trash password string on heap
-                            rtl_zeroMemory( (void*)aIsoPwd.getStr(), aIsoPwd.getLength() );
-                        } while( bEntered && ! bAuthenticated );
+                        rtl::OString aIsoPwd = rtl::OUStringToOString( io_rPwd,
+                                                                       RTL_TEXTENCODING_ISO_8859_1 );
+                        bAuthenticated = pPDFFile->setupDecryptionData( aIsoPwd.getStr() );
+                        // trash password string on heap
+                        rtl_zeroMemory( (void*)aIsoPwd.getStr(), aIsoPwd.getLength() );
                     }
+                    if( bAuthenticated )
+                        bSuccess = true;
+                    else
+                    {
+                        if( i_xIHdl.is() )
+                        {
+                            bool bEntered = false;
+                            do
+                            {
+                                bEntered = getPassword( i_xIHdl, io_rPwd, ! bEntered, i_rDocName );
+                                rtl::OString aIsoPwd = rtl::OUStringToOString( io_rPwd,
+                                                                               RTL_TEXTENCODING_ISO_8859_1 );
+                                bAuthenticated = pPDFFile->setupDecryptionData( aIsoPwd.getStr() );
+                                // trash password string on heap
+                                rtl_zeroMemory( (void*)aIsoPwd.getStr(), aIsoPwd.getLength() );
+                            } while( bEntered && ! bAuthenticated );
+                        }
 
-                    OSL_TRACE( "password: %s", bAuthenticated ? "matches" : "does not match" );
-                    bSuccess = bAuthenticated;
+                        OSL_TRACE( "password: %s", bAuthenticated ? "matches" : "does not match" );
+                        bSuccess = bAuthenticated;
+                    }
+                    // trash password string on heap
+                    rtl_zeroMemory( (void*)io_rPwd.getStr(), io_rPwd.getLength()*sizeof(sal_Unicode) );
+                    if( bAuthenticated )
+                    {
+                        rtl::OUStringBuffer aBuf( 128 );
+                        aBuf.appendAscii( "_OOO_pdfi_Credentials_" );
+                        aBuf.append( pPDFFile->getDecryptionKey() );
+                        io_rPwd = aBuf.makeStringAndClear();
+                    }
                 }
-                // trash password string on heap
-                rtl_zeroMemory( (void*)io_rPwd.getStr(), io_rPwd.getLength()*sizeof(sal_Unicode) );
-                if( bAuthenticated )
+                else if( i_xIHdl.is() )
                 {
-                    rtl::OUStringBuffer aBuf( 128 );
-                    aBuf.appendAscii( "_OOO_pdfi_Credentials_" );
-                    aBuf.append( pPDFFile->getDecryptionKey() );
-                    io_rPwd = aBuf.makeStringAndClear();
+                    reportUnsupportedEncryptionFormat( i_xIHdl );
+                        //TODO: this should either be handled further down the
+                        // call stack, or else information that this has already
+                        // been handled should be passed down the call stack, so
+                        // that SfxBaseModel::load does not show an additional
+                        // "General Error" message box
                 }
             }
             else
@@ -1001,24 +1005,23 @@ bool xpdf_ImportFromFile( const ::rtl::OUString&                             rUR
     if( checkEncryption( aSysUPath, xIHdl, aPwd, bIsEncrypted, aDocName ) == false )
         return false;
 
-    rtl::OUStringBuffer converterURL = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("xpdfimport"));
+    rtl::OUStringBuffer converterURL = rtl::OUString("xpdfimport");
 
     // retrieve package location url (xpdfimport executable is located there)
     // ---------------------------------------------------
     uno::Reference<deployment::XPackageInformationProvider> xProvider(
         xContext->getValueByName(
-            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/singletons/com.sun.star.deployment.PackageInformationProvider"))),
+            rtl::OUString("/singletons/com.sun.star.deployment.PackageInformationProvider")),
         uno::UNO_QUERY);
     if( xProvider.is() )
     {
         converterURL.insert(
             0,
-            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/")));
+            rtl::OUString("/"));
         converterURL.insert(
             0,
             xProvider->getPackageLocation(
-                rtl::OUString::createFromAscii(
-                    BOOST_PP_STRINGIZE(PDFI_IMPL_IDENTIFIER))));
+                rtl::OUString::createFromAscii(PDFI_IMPL_IDENTIFIER)));
     }
 
     // spawn separate process to keep LGPL/GPL code apart.
@@ -1027,7 +1030,7 @@ bool xpdf_ImportFromFile( const ::rtl::OUString&                             rUR
     sal_uInt32 nEnv = 0;
 
     #if defined UNX && ! defined MACOSX
-    rtl::OUString aStr( RTL_CONSTASCII_USTRINGPARAM( "$URE_LIB_DIR" ) );
+    rtl::OUString aStr( "$URE_LIB_DIR"  );
     rtl_bootstrap_expandMacros( &aStr.pData );
     rtl::OUString aSysPath;
     osl_getSystemPathFromFileURL( aStr.pData, &aSysPath.pData );
