@@ -468,10 +468,7 @@ SfxTabDialog::SfxTabDialog
 
 SfxTabDialog::~SfxTabDialog()
 {
-    // save settings (screen position and current page)
-    SvtViewOptions aDlgOpt( E_TABDIALOG, String::CreateFromInt32( nResId ) );
-    aDlgOpt.SetWindowState(OStringToOUString(GetWindowState(WINDOWSTATE_MASK_POS),RTL_TEXTENCODING_ASCII_US));
-    aDlgOpt.SetPageID( aTabCtrl.GetCurPageId() );
+    SavePosAndId();
 
     const sal_uInt16 nCount = pImpl->pData->Count();
     for ( sal_uInt16 i = 0; i < nCount; ++i )
@@ -877,6 +874,14 @@ SfxTabPage* SfxTabDialog::GetTabPage( sal_uInt16 nPageId ) const
     return NULL;
 }
 
+void SfxTabDialog::SavePosAndId()
+{
+    // save settings (screen position and current page)
+    SvtViewOptions aDlgOpt( E_TABDIALOG, String::CreateFromInt32( nResId ) );
+    aDlgOpt.SetWindowState(OStringToOUString(GetWindowState(WINDOWSTATE_MASK_POS),RTL_TEXTENCODING_ASCII_US));
+    aDlgOpt.SetPageID( aTabCtrl.GetCurPageId() );
+}
+
 // -----------------------------------------------------------------------
 
 short SfxTabDialog::Ok()
@@ -884,6 +889,10 @@ short SfxTabDialog::Ok()
 /*  [Description]
 
     Ok handler for the Dialogue.
+
+    Dialog's current location and current page are saved for the next time
+    the dialog is shown.
+
     The OutputSet is created and for each page this or the special OutputSet
     is set by calling the method <SfxTabPage::FillItemSet(SfxItemSet &)>, to
     insert the entered data by the user into the set.
@@ -895,6 +904,8 @@ short SfxTabDialog::Ok()
 */
 
 {
+    SavePosAndId(); //See fdo#38828 "Apply" resetting window position
+
     pImpl->bInOK = sal_True;
 
     if ( !pOutSet )
