@@ -56,7 +56,6 @@
 #include <sfx2/dispatch.hxx>
 #include "workwin.hxx"
 #include "guisaveas.hxx"
-#include <sfx2/viewfrm.hxx>
 #include <cppuhelper/implbase5.hxx>
 #include <vcl/salbtype.hxx>
 #include <svtools/ehdl.hxx>
@@ -133,7 +132,7 @@ public:
     ~SfxInPlaceClient_Impl();
 
     void SizeHasChanged();
-    DECL_LINK           (TimerHdl, Timer*);
+    DECL_LINK(TimerHdl, void *);
     uno::Reference < frame::XFrame > GetFrame() const;
 
     // XEmbeddedClient
@@ -201,7 +200,7 @@ void SAL_CALL SfxInPlaceClient_Impl::notifyEvent( const document::EventObject& a
 {
     SolarMutexGuard aGuard;
 
-    if ( m_pClient && aEvent.EventName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("OnVisAreaChanged")) && m_nAspect != embed::Aspects::MSOLE_ICON )
+    if ( m_pClient && aEvent.EventName == "OnVisAreaChanged" && m_nAspect != embed::Aspects::MSOLE_ICON )
     {
         m_pClient->FormatChanged(); // for Writer when format of the object is changed with the area
         m_pClient->ViewChanged();
@@ -256,15 +255,13 @@ void SAL_CALL SfxInPlaceClient_Impl::saveObject()
         // set non-reschedule progress to prevent problems when asynchronous calls are made
         // during storing of the embedded object
         uno::Reference< lang::XInitialization > xInit(
-            xSrvMgr->createInstance(
-                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.framework.StatusIndicatorFactory" ))),
-            uno::UNO_QUERY_THROW );
+            xSrvMgr->createInstance( "com.sun.star.comp.framework.StatusIndicatorFactory" ), uno::UNO_QUERY_THROW );
         beans::PropertyValue aProperty;
         uno::Sequence< uno::Any > aArgs( 2 );
-        aProperty.Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DisableReschedule" ));
+        aProperty.Name  = "DisableReschedule";
         aProperty.Value = uno::makeAny( sal_True );
         aArgs[0] = uno::makeAny( aProperty );
-        aProperty.Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Frame" ));
+        aProperty.Name  = "Frame";
         aProperty.Value = uno::makeAny( xFrame );
         aArgs[1] = uno::makeAny( aProperty );
 
@@ -277,11 +274,11 @@ void SAL_CALL SfxInPlaceClient_Impl::saveObject()
             {
                 uno::Reference< task::XStatusIndicatorFactory > xStatusIndicatorFactory( xInit, uno::UNO_QUERY_THROW );
                 xStatusIndicator = xStatusIndicatorFactory->createStatusIndicator();
-                xPropSet->setPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "IndicatorInterception" )), uno::makeAny( xStatusIndicator ));
+                xPropSet->setPropertyValue( "IndicatorInterception" , uno::makeAny( xStatusIndicator ));
             }
-            catch ( uno::RuntimeException& e )
+            catch ( const uno::RuntimeException& )
             {
-                throw e;
+                throw;
             }
             catch ( uno::Exception& )
             {
@@ -306,12 +303,12 @@ void SAL_CALL SfxInPlaceClient_Impl::saveObject()
         if ( xPropSet.is() )
         {
             xStatusIndicator.clear();
-            xPropSet->setPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "IndicatorInterception" )), uno::makeAny( xStatusIndicator ));
+            xPropSet->setPropertyValue( "IndicatorInterception" , uno::makeAny( xStatusIndicator ));
         }
     }
-    catch ( uno::RuntimeException& e )
+    catch ( const uno::RuntimeException& )
     {
-        throw e;
+        throw;
     }
     catch ( uno::Exception& )
     {
@@ -421,7 +418,7 @@ uno::Reference< ::com::sun::star::frame::XLayoutManager > SAL_CALL SfxInPlaceCli
     uno::Reference< ::com::sun::star::frame::XLayoutManager > xMan;
     try
     {
-        uno::Any aAny = xFrame->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LayoutManager")) );
+        uno::Any aAny = xFrame->getPropertyValue( "LayoutManager" );
         aAny >>= xMan;
     }
     catch ( uno::Exception& )
@@ -618,7 +615,7 @@ void SfxInPlaceClient_Impl::SizeHasChanged()
 }
 
 //--------------------------------------------------------------------
-IMPL_LINK( SfxInPlaceClient_Impl, TimerHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(SfxInPlaceClient_Impl, TimerHdl)
 {
     if ( m_pClient && m_xObject.is() )
         m_pClient->GetViewShell()->CheckIPClient_Impl( m_pClient, m_pClient->GetViewShell()->GetObjectShell()->GetVisArea() );
@@ -733,7 +730,7 @@ void SfxInPlaceClient::SetObject( const uno::Reference < embed::XEmbeddedObject
 
     if ( rObject.is() )
     {
-        // as soon as an object was connected to a client it has to be checked wether the object wants
+        // as soon as an object was connected to a client it has to be checked whether the object wants
         // to be activated
         rObject->addStateChangeListener( uno::Reference < embed::XStateChangeListener >( m_pImp->m_xClient, uno::UNO_QUERY ) );
         rObject->addEventListener( uno::Reference < document::XEventListener >( m_pImp->m_xClient, uno::UNO_QUERY ) );
@@ -875,27 +872,6 @@ sal_Bool SfxInPlaceClient::IsObjectInPlaceActive() const
     return sal_False;
 }
 
-//--------------------------------------------------------------------
-sal_Bool SfxInPlaceClient::IsObjectActive() const
-{
-    try {
-        return ( m_pImp->m_xObject.is() && ( m_pImp->m_xObject->getCurrentState() == embed::EmbedStates::ACTIVE ) );
-    }
-    catch( uno::Exception& )
-    {}
-
-    return sal_False;
-}
-
-//--------------------------------------------------------------------
-Window* SfxInPlaceClient::GetActiveWindow( SfxObjectShell* pDoc, const com::sun::star::uno::Reference < com::sun::star::embed::XEmbeddedObject >& xObject )
-{
-    SfxInPlaceClient* pClient = GetClient( pDoc, xObject );
-    if ( pClient )
-        return pClient->GetEditWin();
-    return NULL;
-}
-
 //--------------------------------------------------------------------
 SfxInPlaceClient* SfxInPlaceClient::GetClient( SfxObjectShell* pDoc, const com::sun::star::uno::Reference < com::sun::star::embed::XEmbeddedObject >& xObject )
 {
@@ -939,16 +915,16 @@ ErrCode SfxInPlaceClient::DoVerb( long nVerb )
                     uno::Reference< lang::XMultiServiceFactory > xEmptyFactory;
                     SfxStoringHelper aHelper( xEmptyFactory );
                     uno::Sequence< beans::PropertyValue > aDispatchArgs( 1 );
-                    aDispatchArgs[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SaveTo" ) );
+                    aDispatchArgs[0].Name = "SaveTo";
                     aDispatchArgs[0].Value <<= (sal_Bool)sal_True;
 
                     aHelper.GUIStoreModel( xEmbModel,
-                                            ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SaveAs" ) ),
+                                            "SaveAs",
                                             aDispatchArgs,
                                             sal_False,
-                                            ::rtl::OUString() );
+                                            "" );
                 }
-                catch( task::ErrorCodeIOException& aErrorEx )
+                catch( const task::ErrorCodeIOException& aErrorEx )
                 {
                     nError = (sal_uInt32)aErrorEx.ErrCode;
                 }
