@@ -188,7 +188,7 @@ namespace slideshow
 
         bool ViewMediaShape::render( const ::basegfx::B2DRectangle& rBounds ) const
         {
-            ::cppcanvas::CanvasSharedPtr pCanvas = mpViewLayer->getCanvas();;
+            ::cppcanvas::CanvasSharedPtr pCanvas = mpViewLayer->getCanvas();
 
             if( !pCanvas )
                 return false;
@@ -208,7 +208,7 @@ namespace slideshow
         {
             maBounds = rNewBounds;
 
-            ::cppcanvas::CanvasSharedPtr pCanvas = mpViewLayer->getCanvas();;
+            ::cppcanvas::CanvasSharedPtr pCanvas = mpViewLayer->getCanvas();
 
             if( !pCanvas )
                 return false;
@@ -223,7 +223,7 @@ namespace slideshow
             if( xPropSet.is() &&
                 getPropertyValue( xParentWindow,
                                   xPropSet,
-                                  ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Window" ))) )
+                                  ::rtl::OUString("Window" )) )
             {
                 const awt::Rectangle aRect( xParentWindow->getPosSize() );
 
@@ -289,15 +289,13 @@ namespace slideshow
                         if (xPropSet.is())
                         {
                             if ((xPropSet->getPropertyValue(
-                                  ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                          "PrivateTempFileURL"))) >>= aURL)
-                                && aURL.getLength())
+                                  ::rtl::OUString( "PrivateTempFileURL")) >>= aURL)
+                                && !aURL.isEmpty())
                             {
                                 implInitializeMediaPlayer( aURL );
                             }
                             else if (xPropSet->getPropertyValue(
-                                  ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                          "MediaURL"))) >>= aURL)
+                                  ::rtl::OUString( "MediaURL")) >>= aURL)
                             {
                                 implInitializeMediaPlayer( aURL );
                             }
@@ -359,19 +357,19 @@ namespace slideshow
                     sal_Bool bLoop( false );
                     getPropertyValue( bLoop,
                                       rxProps,
-                                      ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Loop" )));
+                                      ::rtl::OUString( "Loop" ));
                     mxPlayer->setPlaybackLoop( bLoop );
 
                     sal_Bool bMute( false );
                     getPropertyValue( bMute,
                                       rxProps,
-                                      ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Mute" )));
+                                      ::rtl::OUString( "Mute" ));
                     mxPlayer->setMute( bMute || !mbIsSoundEnabled);
 
                     sal_Int16 nVolumeDB(0);
                     getPropertyValue( nVolumeDB,
                                       rxProps,
-                                      ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "VolumeDB" )));
+                                      ::rtl::OUString( "VolumeDB" ));
                     mxPlayer->setVolumeDB( nVolumeDB );
 
                     if( mxPlayerWindow.is() )
@@ -379,7 +377,7 @@ namespace slideshow
                         media::ZoomLevel eZoom(media::ZoomLevel_FIT_TO_WINDOW);
                         getPropertyValue( eZoom,
                                           rxProps,
-                                          ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Zoom" )));
+                                          ::rtl::OUString( "Zoom" ));
                         mxPlayerWindow->setZoomLevel( eZoom );
                     }
                 }
@@ -394,7 +392,7 @@ namespace slideshow
             {
                 try
                 {
-                    if( rMediaURL.getLength() )
+                    if( !rMediaURL.isEmpty() )
                     {
                         mxPlayer.set( avmedia::MediaWindow::createPlayer( rMediaURL ),
                             uno::UNO_QUERY );
@@ -407,8 +405,7 @@ namespace slideshow
                 catch( const uno::Exception& )
                 {
                     throw lang::NoSupportException(
-                        rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                           "No video support for ") ) + rMediaURL,
+                        rtl::OUString( "No video support for " ) + rMediaURL,
                         uno::Reference<uno::XInterface>() );
                 }
             }
@@ -449,7 +446,6 @@ namespace slideshow
 
                             mpMediaWindow = ::std::auto_ptr< SystemChildWindow >( new
                                                 SystemChildWindow( pWindow, WB_CLIPCHILDREN ) );
-                            mpMediaWindow = ::std::auto_ptr< SystemChildWindow >( new SystemChildWindow( pWindow, WB_CLIPCHILDREN ) );
                             mpMediaWindow->SetBackground( Color( COL_BLACK ) );
                             mpMediaWindow->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
                                                            Size( aAWTRect.Width, aAWTRect.Height ) );
