@@ -28,7 +28,6 @@
 package installer::windows::component;
 
 use installer::converter;
-use installer::existence;
 use installer::exiter;
 use installer::files;
 use installer::globals;
@@ -470,7 +469,7 @@ sub get_component_name_from_modulegid
             my $filemodules = $onefile->{'modules'};
             my $filemodulesarrayref = installer::converter::convert_stringlist_into_array_without_newline(\$filemodules, ",");
 
-            if (installer::existence::exists_in_array($modulegid, $filemodulesarrayref))
+            if (grep {$_ eq $modulegid} @{$filemodulesarrayref})
             {
                 $componentname = $onefile->{'componentname'};
                 last;
