@@ -316,7 +316,7 @@ void getINetPropsFromConfig(stoc_javavm::JVM * pjvm,
     {
         // read ftp proxy name
         css::uno::Reference<css::registry::XRegistryKey> ftpProxy_name = xRegistryRootKey->openKey(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Settings/ooInetFTPProxyName")));
-        if(ftpProxy_name.is() && ftpProxy_name->getStringValue().getLength()) {
+        if(ftpProxy_name.is() && !ftpProxy_name->getStringValue().isEmpty()) {
             rtl::OUString ftpHost = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ftp.proxyHost="));
             ftpHost += ftpProxy_name->getStringValue();
 
@@ -333,7 +333,7 @@ void getINetPropsFromConfig(stoc_javavm::JVM * pjvm,
 
         // read http proxy name
         css::uno::Reference<css::registry::XRegistryKey> httpProxy_name = xRegistryRootKey->openKey(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Settings/ooInetHTTPProxyName")));
-        if(httpProxy_name.is() && httpProxy_name->getStringValue().getLength()) {
+        if(httpProxy_name.is() && !httpProxy_name->getStringValue().isEmpty()) {
             rtl::OUString httpHost = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("http.proxyHost="));
             httpHost += httpProxy_name->getStringValue();
 
@@ -350,7 +350,7 @@ void getINetPropsFromConfig(stoc_javavm::JVM * pjvm,
 
         // read https proxy name
         css::uno::Reference<css::registry::XRegistryKey> httpsProxy_name = xRegistryRootKey->openKey(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Settings/ooInetHTTPSProxyName")));
-        if(httpsProxy_name.is() && httpsProxy_name->getStringValue().getLength()) {
+        if(httpsProxy_name.is() && !httpsProxy_name->getStringValue().isEmpty()) {
             rtl::OUString httpsHost = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("https.proxyHost="));
             httpsHost += httpsProxy_name->getStringValue();
 
@@ -367,7 +367,7 @@ void getINetPropsFromConfig(stoc_javavm::JVM * pjvm,
 
         // read  nonProxyHosts
         css::uno::Reference<css::registry::XRegistryKey> nonProxies_name = xRegistryRootKey->openKey(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Settings/ooInetNoProxy")));
-        if(nonProxies_name.is() && nonProxies_name->getStringValue().getLength()) {
+        if(nonProxies_name.is() && !nonProxies_name->getStringValue().isEmpty()) {
             rtl::OUString httpNonProxyHosts = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("http.nonProxyHosts="));
             rtl::OUString ftpNonProxyHosts= rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ftp.nonProxyHosts="));
             rtl::OUString value= nonProxies_name->getStringValue();
@@ -425,7 +425,7 @@ void getDefaultLocaleFromConfig(
 
     // read locale
     css::uno::Reference<css::registry::XRegistryKey> locale = xRegistryRootKey->openKey(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("L10N/ooLocale")));
-    if(locale.is() && locale->getStringValue().getLength()) {
+    if(locale.is() && !locale->getStringValue().isEmpty()) {
         rtl::OUString language;
         rtl::OUString country;
 
@@ -435,14 +435,14 @@ void getDefaultLocaleFromConfig(
             language = locale->getStringValue().copy(0, index);
             country = locale->getStringValue().copy(index + 1);
 
-            if(language.getLength()) {
+            if(!language.isEmpty()) {
                 rtl::OUString prop(RTL_CONSTASCII_USTRINGPARAM("user.language="));
                 prop += language;
 
                 pjvm->pushProp(prop);
             }
 
-            if(country.getLength()) {
+            if(!country.isEmpty()) {
                 rtl::OUString prop(RTL_CONSTASCII_USTRINGPARAM("user.country="));
                 prop += country;
 
@@ -549,7 +549,7 @@ void initVMConfiguration(
     try {
         getINetPropsFromConfig(&jvm, xSMgr, xCtx);
     }
-    catch(css::uno::Exception & exception) {
+    catch(const css::uno::Exception & exception) {
 #if OSL_DEBUG_LEVEL > 1
         rtl::OString message = rtl::OUStringToOString(exception.Message, RTL_TEXTENCODING_ASCII_US);
         OSL_TRACE("javavm.cxx: can not get INetProps cause of >%s<", message.getStr());
@@ -561,7 +561,7 @@ void initVMConfiguration(
     try {
         getDefaultLocaleFromConfig(&jvm, xSMgr,xCtx);
     }
-    catch(css::uno::Exception & exception) {
+    catch(const css::uno::Exception & exception) {
 #if OSL_DEBUG_LEVEL > 1
         rtl::OString message = rtl::OUStringToOString(exception.Message, RTL_TEXTENCODING_ASCII_US);
         OSL_TRACE("javavm.cxx: can not get locale cause of >%s<", message.getStr());
@@ -574,7 +574,7 @@ void initVMConfiguration(
     {
         getJavaPropsFromSafetySettings(&jvm, xSMgr, xCtx);
     }
-    catch(css::uno::Exception & exception) {
+    catch(const css::uno::Exception & exception) {
 #if OSL_DEBUG_LEVEL > 1
         rtl::OString message = rtl::OUStringToOString(exception.Message, RTL_TEXTENCODING_ASCII_US);
         OSL_TRACE("javavm.cxx: couldn't get safety settings because of >%s<", message.getStr());
@@ -643,9 +643,7 @@ JavaVirtualMachine::initialize(css::uno::Sequence< css::uno::Any > const &
                               "bad call to initialize")),
             static_cast< cppu::OWeakObject * >(this));
     css::beans::NamedValue val;
-    if (rArguments.getLength() == 1 && (rArguments[0] >>= val)
-        && val.Name.equalsAsciiL(
-            RTL_CONSTASCII_STRINGPARAM( "UnoVirtualMachine")))
+    if (rArguments.getLength() == 1 && (rArguments[0] >>= val) && val.Name == "UnoVirtualMachine" )
     {
         OSL_ENSURE(
             sizeof (sal_Int64) >= sizeof (jvmaccess::UnoVirtualMachine *),
@@ -782,8 +780,12 @@ JavaVirtualMachine::getJavaVM(css::uno::Sequence< sal_Int8 > const & rProcessId)
 
         JNIEnv * pMainThreadEnv = 0;
         javaFrameworkError errcode = JFW_E_NONE;
-        errcode = jfw_startVM(arOptions, index, & m_pJavaVm,
-                                & pMainThreadEnv);
+
+        if (getenv("STOC_FORCE_NO_JRE"))
+            errcode = JFW_E_NO_SELECT;
+        else
+            errcode = jfw_startVM(arOptions, index, & m_pJavaVm,
+                                  & pMainThreadEnv);
 
         bool bStarted = false;
         switch (errcode)
@@ -794,6 +796,8 @@ JavaVirtualMachine::getJavaVM(css::uno::Sequence< sal_Int8 > const & rProcessId)
             // No Java configured. We silenty run the java configuration
             // Java.
             javaFrameworkError errFind = jfw_findAndSelectJRE( NULL );
+            if (getenv("STOC_FORCE_NO_JRE"))
+                errFind = JFW_E_NO_JAVA_FOUND;
             if (errFind == JFW_E_NONE)
             {
                 continue;
@@ -1122,7 +1126,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
     rtl::OUString aPropertyName2;
     rtl::OUString aPropertyValue;
     bool bSecurityChanged = false;
-    if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("ooInetProxyType")))
+    if ( aAccessor == "ooInetProxyType" )
     {
         // Proxy none, manually
         sal_Int32 value = 0;
@@ -1130,15 +1134,13 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
         setINetSettingsInVM(value != 0);
         return;
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetHTTPProxyName")))
+    else if ( aAccessor == "ooInetHTTPProxyName" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "http.proxyHost"));
         rEvent.Element >>= aPropertyValue;
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetHTTPProxyPort")))
+    else if ( aAccessor == "ooInetHTTPProxyPort" )
     {
         aPropertyName
             = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("http.proxyPort"));
@@ -1146,15 +1148,13 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
         rEvent.Element >>= n;
         aPropertyValue = rtl::OUString::valueOf(n);
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetHTTPSProxyName")))
+    else if ( aAccessor == "ooInetHTTPSProxyName" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "https.proxyHost"));
         rEvent.Element >>= aPropertyValue;
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetHTTPSProxyPort")))
+    else if ( aAccessor == "ooInetHTTPSProxyPort" )
     {
         aPropertyName
             = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("https.proxyPort"));
@@ -1162,15 +1162,13 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
         rEvent.Element >>= n;
         aPropertyValue = rtl::OUString::valueOf(n);
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetFTPProxyName")))
+    else if ( aAccessor == "ooInetFTPProxyName" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "ftp.proxyHost"));
         rEvent.Element >>= aPropertyValue;
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetFTPProxyPort")))
+    else if ( aAccessor == "ooInetFTPProxyPort" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "ftp.proxyPort"));
@@ -1178,8 +1176,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
         rEvent.Element >>= n;
         aPropertyValue = rtl::OUString::valueOf(n);
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(
-                                        "ooInetNoProxy")))
+    else if ( aAccessor == "ooInetNoProxy" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "http.nonProxyHosts"));
@@ -1188,7 +1185,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
         rEvent.Element >>= aPropertyValue;
         aPropertyValue = aPropertyValue.replace(';', '|');
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("NetAccess")))
+    else if ( aAccessor == "NetAccess" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "appletviewer.security.mode"));
@@ -1213,7 +1210,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
             return;
         bSecurityChanged = true;
     }
-    else if (aAccessor.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Security")))
+    else if ( aAccessor == "Security" )
     {
         aPropertyName = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
                                           "stardiv.security.disableSecurity"));
@@ -1260,16 +1257,8 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
             // remove the property if it does not have a value ( user left the dialog field empty)
             // or if the port is set to 0
             aPropertyValue= aPropertyValue.trim();
-            if(
-               aPropertyValue.getLength() == 0 ||
-               (
-                (
-                 aPropertyName.equals( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ftp.proxyPort"))) ||
-                 aPropertyName.equals( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("http.proxyPort"))) /*||
-                 aPropertyName.equals( OUString( RTL_CONSTASCII_USTRINGPARAM("socksProxyPort")))*/
-                ) &&
-                aPropertyValue.equals(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("0")))
-               )
+            if( aPropertyValue.isEmpty() ||
+               ( ( aPropertyName == "ftp.proxyPort" || aPropertyName == "http.proxyPort" /*|| aPropertyName == "socksProxyPort"*/ ) && aPropertyValue == "0" )
               )
             {
                 // call java.lang.System.getProperties
@@ -1286,7 +1275,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
 
                 // special calse for ftp.nonProxyHosts and http.nonProxyHosts. The office only
                 // has a value for two java properties
-                if (aPropertyName2.getLength() > 0)
+                if (!aPropertyName2.isEmpty())
                 {
                     jstring jsPropName2= pJNIEnv->NewString( aPropertyName2.getStr(), aPropertyName2.getLength());
                     if(pJNIEnv->ExceptionOccurred()) throw css::uno::RuntimeException(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("JNI:NewString")), 0);
@@ -1303,7 +1292,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
 
                 // special calse for ftp.nonProxyHosts and http.nonProxyHosts. The office only
                 // has a value for two java properties
-                if (aPropertyName2.getLength() > 0)
+                if (!aPropertyName2.isEmpty())
                 {
                     jstring jsPropName2= pJNIEnv->NewString( aPropertyName2.getStr(), aPropertyName2.getLength());
                     if(pJNIEnv->ExceptionOccurred()) throw css::uno::RuntimeException(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("JNI:NewString")), 0);
@@ -1341,7 +1330,7 @@ void SAL_CALL JavaVirtualMachine::elementReplaced(
                     const jchar* jcharName= pJNIEnv->GetStringChars( jsClass, NULL);
                     rtl::OUString sName( jcharName);
                     jboolean bIsSandbox;
-                    if (sName == rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.lib.sandbox.SandboxSecurity")))
+                    if ( sName == "com.sun.star.lib.sandbox.SandboxSecurity" )
                         bIsSandbox= JNI_TRUE;
                     else
                         bIsSandbox= JNI_FALSE;
@@ -1480,7 +1469,7 @@ void JavaVirtualMachine::registerConfigChangesListener()
             if (m_xJavaConfiguration.is())
                 m_xJavaConfiguration->addContainerListener(this);
         }
-    }catch( css::uno::Exception & e)
+    }catch(const css::uno::Exception & e)
     {
 #if OSL_DEBUG_LEVEL > 1
         rtl::OString message = rtl::OUStringToOString(e.Message, RTL_TEXTENCODING_ASCII_US);
