@@ -28,7 +28,7 @@
 
 #include "svtools/toolpanel/paneltabbar.hxx"
 #include "svtools/toolpanel/toolpaneldeck.hxx"
-#include "svtools/svtdata.hxx"
+#include "svtools/svtresid.hxx"
 #include "svtools/svtools.hrc"
 
 #include "tabitemdescriptor.hxx"
@@ -101,8 +101,8 @@ namespace svt
         // target device, done in a normalized geometry, with operations on the window, done in a transformed geometry.
         // So, we should get rid of postRenderItem completely.
 
-    public:
-        virtual ~ITabBarRenderer() {}
+    protected:
+        ~ITabBarRenderer() {}
     };
     typedef ::boost::shared_ptr< ITabBarRenderer >  PTabBarRenderer;
 
@@ -116,6 +116,7 @@ namespace svt
             :m_rTargetDevice( i_rTargetDevice )
         {
         }
+        virtual ~VCLItemRenderer() {}
 
         // ITabBarRenderer
         virtual void        renderBackground() const;
@@ -190,6 +191,7 @@ namespace svt
             :m_rTargetDevice( i_rTargetDevice )
         {
         }
+        virtual ~NWFToolboxItemRenderer() {}
 
         // ITabBarRenderer
         virtual void        renderBackground() const;
@@ -593,7 +595,7 @@ namespace svt
         const bool bUseImage = !!aImage && ( i_eItemContent != TABITEM_TEXT_ONLY );
 
         const ::rtl::OUString sItemText( i_pPanel->GetDisplayName() );
-        const bool bUseText = ( sItemText.getLength() != 0 ) && ( i_eItemContent != TABITEM_IMAGE_ONLY );
+        const bool bUseText = ( !sItemText.isEmpty() ) && ( i_eItemContent != TABITEM_IMAGE_ONLY );
 
         Size aItemContentSize;
         if ( bUseImage )
@@ -664,7 +666,7 @@ namespace svt
         }
 
         const ::rtl::OUString sItemText( i_pPanel->GetDisplayName() );
-        const bool bUseText = ( sItemText.getLength() != 0 ) && ( i_eItemContent != TABITEM_IMAGE_ONLY );
+        const bool bUseText = ( !sItemText.isEmpty() ) && ( i_eItemContent != TABITEM_IMAGE_ONLY );
 
         if ( bUseText )
         {
