@@ -595,7 +595,7 @@ void ControlModelContainerBase::insertByName( const ::rtl::OUString& aName, cons
 
 
 
-    if ( !aName.getLength() || !xM.is() )
+    if ( aName.isEmpty() || !xM.is() )
         lcl_throwIllegalArgumentException();
 
     UnoControlModelHolderList::iterator aElementPos = ImplFindElement( aName );
@@ -1454,7 +1454,7 @@ void ControlContainerBase::ImplSetPosSize( Reference< XControl >& rxCtrl )
         FontDescriptor aFD;
         Any aVal = ImplGetPropertyValue( GetPropertyName( BASEPROPERTY_FONTDESCRIPTOR ) );
         aVal >>= aFD;
-        if ( aFD.StyleName.getLength() )
+        if ( !aFD.StyleName.isEmpty() )
         {
             Reference< XFont > xFont = xD->getFont( aFD );
             aFM = xFont->getFontMetric();
@@ -1856,31 +1856,6 @@ void ControlContainerBase::ImplUpdateResourceResolver()
     }
 }
 
-
-uno::Reference< graphic::XGraphic > ControlContainerBase::Impl_getGraphicFromURL_nothrow( const ::rtl::OUString& _rURL )
-{
-    uno::Reference< graphic::XGraphic > xGraphic;
-    if ( !_rURL.getLength() )
-        return xGraphic;
-
-    try
-    {
-        uno::Reference< graphic::XGraphicProvider > xProvider;
-        if ( maContext.createComponent( "com.sun.star.graphic.GraphicProvider", xProvider ) )
-        {
-            uno::Sequence< beans::PropertyValue > aMediaProperties(1);
-            aMediaProperties[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "URL" ) );
-            aMediaProperties[0].Value <<= _rURL;
-            xGraphic = xProvider->queryGraphic( aMediaProperties );
-        }
-    }
-    catch (const Exception&)
-    {
-        DBG_UNHANDLED_EXCEPTION();
-    }
-
-    return xGraphic;
-}
 ////    ----------------------------------------------------
 ////    Helper Method to convert relative url to physical location
 ////    ----------------------------------------------------
@@ -1895,7 +1870,7 @@ uno::Reference< graphic::XGraphic > ControlContainerBase::Impl_getGraphicFromURL
     rUrl  >>= url;
 
     ::rtl::OUString absoluteURL( url );
-    if ( url.getLength() > 0 )
+    if ( !url.isEmpty() )
     {
         INetURLObject urlObj(baseLocation);
         urlObj.removeSegment();
