@@ -307,8 +307,8 @@ XTYPEPROVIDER_IMPL_9( ResultSet,
 //=========================================================================
 
 XSERVICEINFO_NOFACTORY_IMPL_1( ResultSet,
-                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ResultSet")),
-                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( RESULTSET_SERVICE_NAME )) );
+                    rtl::OUString("ResultSet"),
+                    rtl::OUString(RESULTSET_SERVICE_NAME ) );
 
 //=========================================================================
 //
@@ -1352,17 +1352,17 @@ void SAL_CALL ResultSet::setPropertyValue( const rtl::OUString& aPropertyName,
            lang::WrappedTargetException,
            uno::RuntimeException )
 {
-    if ( !aPropertyName.getLength() )
+    if ( aPropertyName.isEmpty() )
         throw beans::UnknownPropertyException();
 
     if ( aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RowCount")) ) )
+                rtl::OUString("RowCount") ) )
     {
         // property is read-only.
         throw lang::IllegalArgumentException();
     }
     else if ( aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IsRowCountFinal")) ) )
+                rtl::OUString("IsRowCountFinal") ) )
     {
         // property is read-only.
         throw lang::IllegalArgumentException();
@@ -1381,18 +1381,18 @@ uno::Any SAL_CALL ResultSet::getPropertyValue(
            lang::WrappedTargetException,
            uno::RuntimeException )
 {
-    if ( !PropertyName.getLength() )
+    if ( PropertyName.isEmpty() )
         throw beans::UnknownPropertyException();
 
     uno::Any aValue;
 
     if ( PropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RowCount")) ) )
+                rtl::OUString("RowCount") ) )
     {
         aValue <<= m_pImpl->m_xDataSupplier->currentCount();
     }
     else if ( PropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IsRowCountFinal")) ) )
+                rtl::OUString("IsRowCountFinal") ) )
     {
         aValue <<= m_pImpl->m_xDataSupplier->isCountFinal();
     }
@@ -1417,11 +1417,11 @@ void SAL_CALL ResultSet::addPropertyChangeListener(
 
     osl::MutexGuard aGuard( m_pImpl->m_aMutex );
 
-    if ( aPropertyName.getLength() &&
+    if ( !aPropertyName.isEmpty() &&
          !aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RowCount")) ) &&
+                rtl::OUString("RowCount") ) &&
          !aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IsRowCountFinal")) ) )
+                rtl::OUString("IsRowCountFinal") ) )
         throw beans::UnknownPropertyException();
 
     if ( !m_pImpl->m_pPropertyChangeListeners )
@@ -1443,11 +1443,11 @@ void SAL_CALL ResultSet::removePropertyChangeListener(
 {
     osl::MutexGuard aGuard( m_pImpl->m_aMutex );
 
-    if ( aPropertyName.getLength() &&
+    if ( !aPropertyName.isEmpty() &&
          !aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RowCount")) ) &&
+                rtl::OUString("RowCount") ) &&
          !aPropertyName.equals(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IsRowCountFinal")) ) )
+                rtl::OUString("IsRowCountFinal") ) )
         throw beans::UnknownPropertyException();
 
     if ( m_pImpl->m_pPropertyChangeListeners )
@@ -1534,7 +1534,7 @@ void ResultSet::rowCountChanged( sal_uInt32 nOld, sal_uInt32 nNew )
     propertyChanged(
         beans::PropertyChangeEvent(
             static_cast< cppu::OWeakObject * >( this ),
-            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("RowCount")),
+            rtl::OUString("RowCount"),
             sal_False,
             1001,
             uno::makeAny( nOld ),     // old value
@@ -1550,7 +1550,7 @@ void ResultSet::rowCountFinal()
     propertyChanged(
         beans::PropertyChangeEvent(
             static_cast< cppu::OWeakObject * >( this ),
-            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IsRowCountFinal")),
+            rtl::OUString("IsRowCountFinal"),
             sal_False,
             1000,
             uno:: makeAny( sal_False ),   // old value
