@@ -37,19 +37,11 @@
 #include <rtl/logfile.hxx>
 #include "itemholder1.hxx"
 
-//_________________________________________________________________________________________________________________
-//  namespaces
-//_________________________________________________________________________________________________________________
-
 using namespace ::utl                   ;
 using namespace ::rtl                   ;
 using namespace ::osl                   ;
 using namespace ::com::sun::star::uno   ;
 
-//_________________________________________________________________________________________________________________
-//  const
-//_________________________________________________________________________________________________________________
-
 #define ROOTNODE_LOCALISATION           OUString(RTL_CONSTASCII_USTRINGPARAM("Office.Common/View/Localisation"))
 #define DEFAULT_AUTOMNEMONIC            sal_False
 #define DEFAULT_DIALOGSCALE             0
@@ -62,29 +54,13 @@ using namespace ::com::sun::star::uno   ;
 
 #define PROPERTYCOUNT                   2
 
-//_________________________________________________________________________________________________________________
-//  private declarations!
-//_________________________________________________________________________________________________________________
-
 class SvtLocalisationOptions_Impl : public ConfigItem
 {
-    //-------------------------------------------------------------------------------------------------------------
-    //  public methods
-    //-------------------------------------------------------------------------------------------------------------
-
     public:
 
-        //---------------------------------------------------------------------------------------------------------
-        //  constructor / destructor
-        //---------------------------------------------------------------------------------------------------------
-
          SvtLocalisationOptions_Impl();
         ~SvtLocalisationOptions_Impl();
 
-        //---------------------------------------------------------------------------------------------------------
-        //  overloaded methods of baseclass
-        //---------------------------------------------------------------------------------------------------------
-
         /*-****************************************************************************************************//**
             @short      called for notify of configmanager
             @descr      These method is called from the ConfigManager before application ends or from the
@@ -116,10 +92,6 @@ class SvtLocalisationOptions_Impl : public ConfigItem
 
         virtual void Commit();
 
-        //---------------------------------------------------------------------------------------------------------
-        //  public interface
-        //---------------------------------------------------------------------------------------------------------
-
         /*-****************************************************************************************************//**
             @short      access method to get internal values
             @descr      These method give us a chance to regulate acces to ouer internal values.
@@ -134,13 +106,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
         *//*-*****************************************************************************************************/
 
         sal_Bool    IsAutoMnemonic  (                   ) const ;
-        void        SetAutoMnemonic ( sal_Bool  bState  )       ;
         sal_Int32   GetDialogScale  (                   ) const ;
-        void        SetDialogScale  ( sal_Int32 nScale  )       ;
-
-    //-------------------------------------------------------------------------------------------------------------
-    //  private methods
-    //-------------------------------------------------------------------------------------------------------------
 
     private:
 
@@ -159,20 +125,12 @@ class SvtLocalisationOptions_Impl : public ConfigItem
 
         static Sequence< OUString > GetPropertyNames();
 
-    //-------------------------------------------------------------------------------------------------------------
-    //  private member
-    //-------------------------------------------------------------------------------------------------------------
-
     private:
 
         sal_Bool    m_bAutoMnemonic     ;
         sal_Int32   m_nDialogScale      ;
 };
 
-//_________________________________________________________________________________________________________________
-//  definitions
-//_________________________________________________________________________________________________________________
-
 //*****************************************************************************************************************
 //  constructor
 //*****************************************************************************************************************
@@ -300,15 +258,6 @@ sal_Bool SvtLocalisationOptions_Impl::IsAutoMnemonic() const
     return m_bAutoMnemonic;
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtLocalisationOptions_Impl::SetAutoMnemonic( sal_Bool bState )
-{
-    m_bAutoMnemonic = bState;
-    SetModified();
-}
-
 //*****************************************************************************************************************
 //  public method
 //*****************************************************************************************************************
@@ -317,15 +266,6 @@ sal_Int32 SvtLocalisationOptions_Impl::GetDialogScale() const
     return m_nDialogScale;
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtLocalisationOptions_Impl::SetDialogScale( sal_Int32 nScale )
-{
-    m_nDialogScale = nScale;
-    SetModified();
-}
-
 Sequence< OUString > SvtLocalisationOptions_Impl::GetPropertyNames()
 {
     // Build static list of configuration key names.
@@ -394,15 +334,6 @@ sal_Bool SvtLocalisationOptions::IsAutoMnemonic() const
     return m_pDataContainer->IsAutoMnemonic();
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtLocalisationOptions::SetAutoMnemonic( sal_Bool bState )
-{
-    MutexGuard aGuard( GetOwnStaticMutex() );
-    m_pDataContainer->SetAutoMnemonic( bState );
-}
-
 //*****************************************************************************************************************
 //  public method
 //*****************************************************************************************************************
@@ -412,15 +343,6 @@ sal_Int32 SvtLocalisationOptions::GetDialogScale() const
     return m_pDataContainer->GetDialogScale();
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtLocalisationOptions::SetDialogScale( sal_Int32 nScale )
-{
-    MutexGuard aGuard( GetOwnStaticMutex() );
-    m_pDataContainer->SetDialogScale( nScale );
-}
-
 namespace
 {
     class theLocalisationOptionsMutex : public rtl::Static<osl::Mutex, theLocalisationOptionsMutex>{};
