@@ -73,14 +73,18 @@
 //
 
 #ifdef GRLAYOUT_DEBUG
-static FILE * grLogFile = NULL;
 static FILE * grLog()
 {
 #ifdef WNT
-    std::string logFileName(getenv("TEMP"));
-    logFileName.append("/graphitelayout.log");
-    if (grLogFile == NULL) grLogFile = fopen(logFileName.c_str(),"w");
-    else fflush(grLogFile);
+    static FILE * grLogFile = NULL;
+    if (grLogFile == NULL)
+    {
+        std::string logFileName(getenv("TEMP"));
+        logFileName.append("/graphitelayout.log");
+        grLogFile = fopen(logFileName.c_str(),"w");
+    }
+    else
+        fflush(grLogFile);
     return grLogFile;
 #else
     fflush(stdout);
@@ -401,7 +405,7 @@ GraphiteLayout::fillFrom(gr_segment * pSegment, ImplLayoutArgs &rArgs, float fSc
             mvGlyphs[i].maLinearPos.X() -= nXOffset;
     }
 #ifdef GRLAYOUT_DEBUG
-    fprintf(grLog(), "fillFrom %d glyphs offset %ld width %d\n", mvGlyphs.size(), nXOffset, mnWidth);
+    fprintf(grLog(), "fillFrom %" SAL_PRI_SIZET "u glyphs offset %ld width %ld\n", mvGlyphs.size(), nXOffset, mnWidth);
 #endif
 }
 
@@ -612,7 +616,7 @@ gr_segment * GraphiteLayout::CreateSegment(ImplLayoutArgs& rArgs)
         if (pSegment != NULL)
         {
 #ifdef GRLAYOUT_DEBUG
-            fprintf(grLog(),"Gr::LayoutText %d-%d, context %d,len%d,numchars%d, rtl%d scaling %f:", rArgs.mnMinCharPos,
+            fprintf(grLog(),"Gr::LayoutText %d-%d, context %d, len %d, numchars %" SAL_PRI_SIZET "u, rtl %d scaling %f:", rArgs.mnMinCharPos,
                rArgs.mnEndCharPos, limit, rArgs.mnLength, numchars, bRtl, mfScaling);
             for (int i = mnSegCharOffset; i < limit; ++i)
                 fprintf(grLog(), " %04X", rArgs.mpStr[i]);
@@ -665,7 +669,7 @@ bool GraphiteLayout::LayoutGlyphs(ImplLayoutArgs& rArgs, gr_segment * pSegment)
                 mvCharDxs[mvCharDxs.size() - 1] = mnWidth;
             }
         }
-        catch (std::exception &e)
+        catch (const std::exception &e)
         {
 #ifdef GRLAYOUT_DEBUG
             fprintf(grLog(),"LayoutGlyphs failed %s\n", e.what());
@@ -845,11 +849,13 @@ void GraphiteLayout::expandOrCondense(ImplLayoutArgs &rArgs)
                     nOffset = static_cast<int>(fExtraPerCluster * nCluster);
                     int nCharIndex = mvGlyph2Char[i];
                     assert(nCharIndex > -1);
-                    if (static_cast<size_t>(nCharIndex-mnMinCharPos)
-                            < mvCharDxs.size())
+                    if (nCharIndex < mnMinCharPos ||
+                        static_cast<size_t>(nCharIndex-mnMinCharPos)
+                            >= mvCharDxs.size())
                     {
-                        mvCharDxs[nCharIndex-mnMinCharPos] += nOffset;
+                        continue;
                     }
+                    mvCharDxs[nCharIndex-mnMinCharPos] += nOffset;
                     // adjust char dxs for rest of characters in cluster
                     while (++nCharIndex - mnMinCharPos < static_cast<int>(mvChar2BaseGlyph.size()))
                     {
@@ -867,7 +873,7 @@ void GraphiteLayout::expandOrCondense(ImplLayoutArgs &rArgs)
     }
     else if (nDeltaWidth < 0)// condense - apply a factor to all glyph positions
     {
-        if (mvGlyphs.size() == 0) return;
+        if (mvGlyphs.empty()) return;
         Glyphs::iterator iLastGlyph = mvGlyphs.begin() + (mvGlyphs.size() - 1);
         // position last glyph using original width
         float fXFactor = static_cast<float>(rArgs.mnLayoutWidth - iLastGlyph->mnOrigWidth) / static_cast<float>(iLastGlyph->maLinearPos.X());
