@@ -212,7 +212,7 @@ Point XIMStatusWindow::updatePosition()
         XLIB_Window aChild;
         XTranslateCoordinates( (Display*)pParentEnvData->pDisplay,
                                (XLIB_Window)pParentEnvData->aShellWindow,
-                               GetGenericData()->GetSalDisplay()->GetRootWindow( GetGenericData()->GetSalDisplay()->GetDefaultScreenNumber() ),
+                               GetGenericData()->GetSalDisplay()->GetRootWindow( GetGenericData()->GetSalDisplay()->GetDefaultXScreen() ),
                                0, 0,
                                &x, &y,
                                &aChild );
@@ -267,7 +267,7 @@ void XIMStatusWindow::setPosition( SalFrame* pParent )
     }
 }
 
-IMPL_LINK( XIMStatusWindow, DelayedShowHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(XIMStatusWindow, DelayedShowHdl)
 {
     m_nDelayedEvent = 0;
     const SystemEnvData* pData = GetSystemData();
