@@ -33,6 +33,7 @@
 #include <math.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <fontconfig/fontconfig.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -45,7 +46,6 @@
 #include "osl/file.hxx"
 #include "osl/module.hxx"
 
-#include "tools/string.hxx"
 #include "tools/debug.hxx"
 #include "tools/stream.hxx"
 
@@ -415,9 +415,6 @@ void X11SalGraphics::DrawServerFontLayout( const ServerFontLayout& rLayout )
 
         cairo_matrix_init_identity(&m);
 
-        if (rFont.NeedsArtificialItalic())
-            m.xy = -m.xx * 0x6000L / 0x10000L;
-
         if (rLayout.GetOrientation())
             cairo_matrix_rotate(&m, toRadian(rLayout.GetOrientation()));
 
@@ -464,6 +461,14 @@ void X11SalGraphics::DrawServerFontLayout( const ServerFontLayout& rLayout )
             cairo_matrix_translate(&m, xdiff, ydiff);
         }
 
+        if (rFont.NeedsArtificialItalic())
+        {
+            cairo_matrix_t shear;
+            cairo_matrix_init_identity(&shear);
+            shear.xy = -shear.xx * 0x6000L / 0x10000L;
+            cairo_matrix_multiply(&m, &shear, &m);
+        }
+
         cairo_set_font_matrix(cr, &m);
         cairo_show_glyphs(cr, &cairo_glyphs[nStartIndex], nLen);
 
@@ -540,26 +545,28 @@ bool X11SalGraphics::AddTempDevFont( ImplDevFontList* pFontList,
     rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
     OString aOFileName( OUStringToOString( aUSystemPath, aEncoding ) );
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
-    int nFontId = rMgr.addFontFile( aOFileName, 0 );
-    if( !nFontId )
+    std::vector<psp::fontID> aFontIds = rMgr.addFontFile( aOFileName );
+    if( aFontIds.empty() )
         return false;
 
-    // prepare font data
-    psp::FastPrintFontInfo aInfo;
-    rMgr.getFontFastInfo( nFontId, aInfo );
-    aInfo.m_aFamilyName = rFontName;
-
-    // inform glyph cache of new font
-    ImplDevFontAttributes aDFA = GenPspGraphics::Info2DevFontAttributes( aInfo );
-    aDFA.mnQuality += 5800;
-
-    int nFaceNum = rMgr.getFontFaceNumber( aInfo.m_nID );
-    if( nFaceNum < 0 )
-        nFaceNum = 0;
-
     GlyphCache& rGC = X11GlyphCache::GetInstance();
-    const rtl::OString& rFileName = rMgr.getFontFileSysPath( aInfo.m_nID );
-    rGC.AddFontFile( rFileName, nFaceNum, aInfo.m_nID, aDFA );
+
+    for (std::vector<psp::fontID>::iterator aI = aFontIds.begin(), aEnd = aFontIds.end(); aI != aEnd; ++aI)
+    {
+        // prepare font data
+        psp::FastPrintFontInfo aInfo;
+        rMgr.getFontFastInfo( *aI, aInfo );
+        aInfo.m_aFamilyName = rFontName;
+
+        // inform glyph cache of new font
+        ImplDevFontAttributes aDFA = GenPspGraphics::Info2DevFontAttributes( aInfo );
+        aDFA.mnQuality += 5800;
+
+        int nFaceNum = rMgr.getFontFaceNumber( aInfo.m_nID );
+
+        const rtl::OString& rFileName = rMgr.getFontFileSysPath( aInfo.m_nID );
+        rGC.AddFontFile( rFileName, nFaceNum, aInfo.m_nID, aDFA );
+    }
 
     // announce new font to device's font list
     rGC.AnnounceFonts( pFontList );
@@ -590,8 +597,6 @@ void X11SalGraphics::GetDevFontList( ImplDevFontList *pList )
 
         // normalize face number to the GlyphCache
         int nFaceNum = rMgr.getFontFaceNumber( aInfo.m_nID );
-        if( nFaceNum < 0 )
-            nFaceNum = 0;
 
         // for fonts where extra kerning info can be provided on demand
         // an ExtraKernInfo object is supplied
@@ -610,10 +615,9 @@ void X11SalGraphics::GetDevFontList( ImplDevFontList *pList )
     rGC.AnnounceFonts( pList );
 
     // register platform specific font substitutions if available
-    if( rMgr.hasFontconfig() )
-        SalGenericInstance::RegisterFontSubstitutors( pList );
+    SalGenericInstance::RegisterFontSubstitutors( pList );
 
-    ImplGetSVData()->maGDIData.mbNativeFontConfig = rMgr.hasFontconfig();
+    ImplGetSVData()->maGDIData.mbNativeFontConfig = true;
 }
 
 // ----------------------------------------------------------------------------
@@ -697,7 +701,21 @@ sal_Bool X11SalGraphics::GetGlyphBoundRect( sal_GlyphId nGlyphIndex, Rectangle&
 
     nGlyphIndex &= GF_IDXMASK;
     const GlyphMetric& rGM = pSF->GetGlyphMetric( nGlyphIndex );
-    rRect = Rectangle( rGM.GetOffset(), rGM.GetSize() );
+    Rectangle aRect( rGM.GetOffset(), rGM.GetSize() );
+
+    if ( pSF->mnCos != 0x10000 && pSF->mnSin != 0 )
+    {
+        double nCos = pSF->mnCos / 65536.0;
+        double nSin = pSF->mnSin / 65536.0;
+        rRect.Left() =  nCos*aRect.Left() + nSin*aRect.Top();
+        rRect.Top()  = -nSin*aRect.Left() - nCos*aRect.Top();
+
+        rRect.Right()  =  nCos*aRect.Right() + nSin*aRect.Bottom();
+        rRect.Bottom() = -nSin*aRect.Right() - nCos*aRect.Bottom();
+    }
+    else
+        rRect = aRect;
+
     return sal_True;
 }
 
