@@ -36,7 +36,6 @@
 #include "SchXMLTools.hxx"
 #include "transporttypes.hxx"
 #include "XMLStringBufferImportContext.hxx"
-#include <tools/debug.hxx>
 #include <rtl/math.hxx>
 #include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmltoken.hxx>
@@ -69,8 +68,8 @@ using ::rtl::OUString;
 namespace
 {
 
-const OUString lcl_aLabelPrefix( RTL_CONSTASCII_USTRINGPARAM("label "));
-const OUString lcl_aCategoriesRange( RTL_CONSTASCII_USTRINGPARAM("categories"));
+const char aLabelPrefix[] = "label ";
+const char aCategoriesRange[] = "categories";
 
 typedef ::std::multimap< ::rtl::OUString, ::rtl::OUString >
     lcl_tOriginalRangeToInternalRangeMap;
@@ -117,6 +116,9 @@ void lcl_fillRangeMapping(
     sal_Int32 nRowOffset = ( rTable.bHasHeaderRow ? 1 : 0 );
     sal_Int32 nColOffset = ( rTable.bHasHeaderColumn ? 1 : 0 );
 
+    const OUString lcl_aCategoriesRange(aCategoriesRange);
+    const OUString lcl_aLabelPrefix(aLabelPrefix);
+
     // Fill range mapping
     const size_t nTableRowCount( rTable.aData.size());
     for( size_t nRow = 0; nRow < nTableRowCount; ++nRow )
@@ -125,8 +127,8 @@ void lcl_fillRangeMapping(
         const size_t nTableColCount( rRow.size());
         for( size_t nCol = 0; nCol < nTableColCount; ++nCol )
         {
-            OUString aRangeId( rRow[nCol].aRangeId );
-            if( aRangeId.getLength())
+            const OUString aRangeId( rRow[nCol].aRangeId );
+            if( !aRangeId.isEmpty())
             {
                 if( eDataRowSource == chart::ChartDataRowSource_COLUMNS )
                 {
@@ -204,8 +206,8 @@ bool lcl_tableOfRangeMatches(
     const ::rtl::OUString & rTableName )
 {
     // both strings are non-empty and the table name is part of the range
-    return ( (rRange.getLength() > 0) &&
-             (rTableName.getLength() > 0) &&
+    return ( !rRange.isEmpty() &&
+             !rTableName.isEmpty() &&
              (rRange.indexOf( rTableName ) != -1 ));
 }
 
@@ -492,7 +494,7 @@ void SchXMLTableColumnContext::StartElement( const uno::Reference< xml::sax::XAt
             IsXMLToken( aLocalName, XML_NUMBER_COLUMNS_REPEATED ) )
         {
             rtl::OUString aValue = xAttrList->getValueByIndex( i );
-            if( aValue.getLength())
+            if( !aValue.isEmpty())
                 nRepeated = aValue.toInt32();
         }
         else if( nPrefix == XML_NAMESPACE_TABLE &&
@@ -757,9 +759,9 @@ SvXMLImportContext* SchXMLTableCellContext::CreateChildContext(
 
 void SchXMLTableCellContext::EndElement()
 {
-    if( mbReadText && maCellContent.getLength() ) //apply text from <text:p> element
+    if( mbReadText && !maCellContent.isEmpty() ) //apply text from <text:p> element
         mrTable.aData[ mrTable.nRowIndex ][ mrTable.nColumnIndex ].aString = maCellContent;
-    if( maRangeId.getLength())
+    if( !maRangeId.isEmpty())
         mrTable.aData[ mrTable.nRowIndex ][ mrTable.nColumnIndex ].aRangeId = maRangeId;
 }
 
@@ -902,6 +904,8 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
 
     lcl_fillRangeMapping( rTable, aRangeMap, eDataRowSource );
 
+    const OUString lcl_aCategoriesRange(aCategoriesRange);
+
     bool bCategoriesApplied = false;
     // translate ranges (using the map created before)
     for( tSchXMLLSequencesPerIndex::const_iterator aLSeqIt( rLSequencesPerIndex.begin());
@@ -1098,7 +1102,7 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
                                     aRange = xLabel->getSourceRangeRepresentation();
                                     sal_Int32 nSearchIndex = 0;
                                     OUString aSecondToken = aRange.getToken( 1, ' ', nSearchIndex );
-                                    if( aSecondToken.getLength() )
+                                    if( !aSecondToken.isEmpty() )
                                         aUsageMap[aSecondToken.toInt32()] = true;
                                 }
                             }
@@ -1128,9 +1132,8 @@ void SchXMLTableHelper::switchRangesFromOuterToInternalIfNecessary(
                 }
             }
         }
-        catch( uno::Exception & ex )
+        catch( const uno::Exception & )
         {
-            (void)ex; // avoid warning for pro build
         }
     }
 }
