@@ -43,8 +43,6 @@
 #include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmltoken.hxx>
 #include "xmloff/xmlerror.hxx"
-#include <tools/debug.hxx>
-
 #include "xmloff/contextid.hxx"
 
 // STL includes
@@ -114,17 +112,6 @@ void SvXMLImportPropertyMapper::ChainImportMapper(
     }
 }
 
-void SvXMLImportPropertyMapper::importXML(
-        vector< XMLPropertyState >& rProperties,
-           Reference< XAttributeList > xAttrList,
-           const SvXMLUnitConverter& rUnitConverter,
-        const SvXMLNamespaceMap& rNamespaceMap,
-        sal_uInt32 nPropType ) const
-{
-    importXML( rProperties, xAttrList, rUnitConverter, rNamespaceMap,
-               nPropType,-1, -1 );
-}
-
 /** fills the given itemset with the attributes in the given list */
 void SvXMLImportPropertyMapper::importXML(
         vector< XMLPropertyState >& rProperties,
@@ -376,7 +363,7 @@ void SvXMLImportPropertyMapper::FillPropertySequence(
         if( nIdx == -1 )
             continue;
         pProps->Name = maPropMapper->GetEntryAPIName( nIdx );
-        if( pProps->Name.getLength() )
+        if( !pProps->Name.isEmpty() )
         {
             pProps->Value <<= rProp.maValue;
             ++pProps;
@@ -510,7 +497,7 @@ sal_Bool SvXMLImportPropertyMapper::_FillPropertySet(
                 rPropSet->setPropertyValue( rPropName, rProp.maValue );
                 bSet = sal_True;
             }
-            catch ( IllegalArgumentException& e )
+            catch ( const IllegalArgumentException& e )
             {
                 // illegal value: check whether this property is
                 // allowed to throw this exception
@@ -523,7 +510,7 @@ sal_Bool SvXMLImportPropertyMapper::_FillPropertySet(
                         aSeq, e.Message, NULL );
                 }
             }
-            catch ( UnknownPropertyException& e )
+            catch ( const UnknownPropertyException& e )
             {
                 // unknown property: This is always an error!
                 Sequence<OUString> aSeq(1);
@@ -532,7 +519,7 @@ sal_Bool SvXMLImportPropertyMapper::_FillPropertySet(
                     XMLERROR_STYLE_PROP_UNKNOWN | XMLERROR_FLAG_ERROR,
                     aSeq, e.Message, NULL );
             }
-            catch ( PropertyVetoException& e )
+            catch ( const PropertyVetoException& e )
             {
                 // property veto: this shouldn't happen
                 Sequence<OUString> aSeq(1);
@@ -541,7 +528,7 @@ sal_Bool SvXMLImportPropertyMapper::_FillPropertySet(
                     XMLERROR_STYLE_PROP_OTHER | XMLERROR_FLAG_ERROR,
                     aSeq, e.Message, NULL );
             }
-            catch ( WrappedTargetException& e )
+            catch ( const WrappedTargetException& e )
             {
                 // wrapped target: this shouldn't happen either
                 Sequence<OUString> aSeq(1);
