@@ -239,7 +239,7 @@ void SAL_CALL XMLTransformerBase::startElement( const OUString& rName,
 {
     SvXMLNamespaceMap *pRewindMap = 0;
 
-    bool bRect = rName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "presentation:show-shape" ) );
+    bool bRect = rName == "presentation:show-shape";
     (void)bRect;
 
     // Process namespace attributes. This must happen before creating the
@@ -279,7 +279,7 @@ void SAL_CALL XMLTransformerBase::startElement( const OUString& rName,
                 nKey = m_pNamespaceMap->Add( aPrefix, rAttrValue );
 
             const OUString& rRepName = m_pReplaceNamespaceMap->GetNameByKey( nKey );
-            if( rRepName.getLength() )
+            if( !rRepName.isEmpty() )
             {
                 if( !pMutableAttrList )
                 {
@@ -461,27 +461,27 @@ void SAL_CALL XMLTransformerBase::initialize( const Sequence< Any >& aArguments
         OUString sRelPath, sName;
         Reference< XPropertySetInfo > xPropSetInfo =
             m_xPropSet->getPropertySetInfo();
-        OUString sPropName( RTL_CONSTASCII_USTRINGPARAM("StreamRelPath" ) );
+        OUString sPropName( "StreamRelPath"  );
         if( xPropSetInfo->hasPropertyByName(sPropName) )
         {
             aAny = m_xPropSet->getPropertyValue(sPropName);
             aAny >>= sRelPath;
         }
-        sPropName = OUString( RTL_CONSTASCII_USTRINGPARAM("StreamName" ) );
+        sPropName = OUString( "StreamName"  );
         if( xPropSetInfo->hasPropertyByName(sPropName) )
         {
             aAny = m_xPropSet->getPropertyValue(sPropName);
             aAny >>= sName;
         }
-        if( sName.getLength() )
+        if( !sName.isEmpty() )
         {
-            m_aExtPathPrefix = OUString( RTL_CONSTASCII_USTRINGPARAM("../" ) );
+            m_aExtPathPrefix = OUString( "../"  );
 
             // If there is a rel path within a package, then append
             // additional '../'. If the rel path contains an ':', then it is
             // an absolute URI (or invalid URI, because zip files don't
             // permit ':'), and it will be ignored.
-            if( sRelPath.getLength() )
+            if( !sRelPath.isEmpty() )
             {
                 sal_Int32 nColPos = sRelPath.indexOf( ':' );
                 OSL_ENSURE( -1 == nColPos,
@@ -887,7 +887,7 @@ XMLMutableAttributeList *XMLTransformerBase::ProcessAttrList(
                     break;
                 case XML_ATACTION_SHAPEID:
                 {
-                    OUString sNewValue( RTL_CONSTASCII_USTRINGPARAM( "shape" ) );
+                    OUString sNewValue( "shape"  );
                     sNewValue += rAttrValue;
                     pMutableAttrList->SetValueByIndex( i, sNewValue );
                     break;
@@ -1074,8 +1074,8 @@ sal_Bool XMLTransformerBase::EncodeStyleName( OUString& rName ) const
                                 ->xCharClass =
                                     Reference < XCharacterClassification >(
                                 xFactory->createInstance(
-                                    OUString(RTL_CONSTASCII_USTRINGPARAM(
-                        "com.sun.star.i18n.CharacterClassification_Unicode")) ),
+                                    OUString(
+                        "com.sun.star.i18n.CharacterClassification_Unicode") ),
                                 UNO_QUERY );
 
                             OSL_ENSURE( xCharClass.is(),
@@ -1293,7 +1293,7 @@ sal_Bool XMLTransformerBase::ConvertURIToOASIS( ::rtl::OUString& rURI,
                                         sal_Bool bSupportPackage ) const
 {
     sal_Bool bRet = sal_False;
-    if( m_aExtPathPrefix.getLength() && rURI.getLength() )
+    if( !m_aExtPathPrefix.isEmpty() && !rURI.isEmpty() )
     {
         sal_Bool bRel = sal_False;
         switch( rURI[0] )
@@ -1363,7 +1363,7 @@ sal_Bool XMLTransformerBase::ConvertURIToOOo( ::rtl::OUString& rURI,
                                         sal_Bool bSupportPackage ) const
 {
     sal_Bool bRet = sal_False;
-    if( rURI.getLength() )
+    if( !rURI.isEmpty() )
     {
         sal_Bool bPackage = sal_False;
         switch( rURI[0] )
@@ -1441,7 +1441,7 @@ sal_Bool XMLTransformerBase::RenameAttributeValue(
 // static
 bool XMLTransformerBase::ConvertRNGDateTimeToISO( ::rtl::OUString& rDateTime )
 {
-    if( rDateTime.getLength() > 0 &&
+    if( !rDateTime.isEmpty() &&
         rDateTime.indexOf( sal_Unicode('.')) != -1 )
     {
         rDateTime = rDateTime.replace( sal_Unicode('.'), sal_Unicode(','));
@@ -1488,9 +1488,9 @@ bool XMLTransformerBase::isWriter() const
 {
     Reference< XServiceInfo > xSI( mxModel, UNO_QUERY );
     return  xSI.is() &&
-        (   xSI->supportsService( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.TextDocument" ) ) ) ||
-            xSI->supportsService( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.WebDocument" ) ) ) ||
-            xSI->supportsService( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.GlobalDocument" ) ) ) );
+        (   xSI->supportsService( OUString( "com.sun.star.text.TextDocument"  ) ) ||
+            xSI->supportsService( OUString( "com.sun.star.text.WebDocument"  ) ) ||
+            xSI->supportsService( OUString( "com.sun.star.text.GlobalDocument"  ) ) );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
