@@ -70,13 +70,12 @@ OUString getImplementationName_DocumentHandlerImpl()
 }
 
 typedef ::boost::unordered_map< OUString, sal_Int32, OUStringHash > t_OUString2LongMap;
-typedef ::boost::unordered_map< sal_Int32, OUString > t_Long2OUStringMap;
 
 struct PrefixEntry
 {
     ::std::vector< sal_Int32 > m_Uids;
 
-    inline PrefixEntry() SAL_THROW( () )
+    inline PrefixEntry() SAL_THROW(())
         { m_Uids.reserve( 4 ); }
 };
 
@@ -879,7 +878,7 @@ OUString ExtendedAttributes::getValueByUidName(
 Reference< xml::sax::XDocumentHandler > SAL_CALL createDocumentHandler(
     Reference< xml::input::XRoot > const & xRoot,
     bool bSingleThreadedUse )
-    SAL_THROW( () )
+    SAL_THROW(())
 {
     OSL_ASSERT( xRoot.is() );
     if (xRoot.is())
@@ -892,7 +891,7 @@ Reference< xml::sax::XDocumentHandler > SAL_CALL createDocumentHandler(
 
 //------------------------------------------------------------------------------
 Reference< XInterface > SAL_CALL create_DocumentHandlerImpl(
-    Reference< XComponentContext > const & )
+    SAL_UNUSED_PARAMETER Reference< XComponentContext > const & )
     SAL_THROW( (Exception) )
 {
     return static_cast< ::cppu::OWeakObject * >(
